(function(mod) {
  if (typeof exports == "object" && typeof module == "object") // CommonJS
    return mod(require("../lib/infer"), require("../lib/tern"));
  if (typeof define == "function" && define.amd) // AMD
    return define(["../lib/infer", "../lib/tern"], mod);
  mod(tern, tern);
})(function(infer, tern) {
  "use strict";

  function Component() {
    this.use = null;
  }

  function getComponent(data, name) {
    return data.components[name];// || (data.modules[name] = new infer.AVal);
  }

  function Module() {
    this.def = null;
    this.requires = null;
  }

  function getOrCreateModule(data, name) {
    var module = data.modules[name];
    if (!module) {
      module = new Module();
      data.modules[name] = module;
    }
    return module;
  }

  function getModule(data, name) {
    if (!data.initialized) {
      //infer.def.load(yuiOop);
      //infer.def.load(yuiEventAndNode);
      data.initialized = true;
    }
    return data.modules[name];// || (data.modules[name] = new infer.AVal);
  }

  function injectModule(Y, name) {
    var cx = infer.cx(), server = cx.parent, data = server._yui, module = getModule(data, name);
    if (module) {
      var def = module.def, requires = module.requires;
      if (def) {
        def.getType().propagate(Y);
      }
      if (requires) {
        for ( var i = 0; i < requires.length; i++) {
          var moduleName = requires[i];
          injectModule(Y, moduleName);
        }
      }
    } else {
      var component = getComponent(data, name);
      if (component && component.use) {
        for ( var i = 0; i < component.use.length; i++) {
          var moduleName = component.use[i];
          injectModule(Y, moduleName);
        }
      }
    }
  }

  function getFnIndex(argNodes) {
    for ( var i = 0; i < argNodes.length; i++) {
      if (argNodes[i].type == "FunctionExpression") {
        return i;
      }
    }
  }

  infer.registerFunction("yui_add", function(self, args, argNodes) {
    var yui = self.getType();
    if (yui && argNodes) {
      var index = getFnIndex(argNodes);
      if (index) {
        var fn = args[index];
        if (fn.argNames  && fn.argNames.length > 0) {
          var Y = fn.args[0];
          yui.getProp("prototype").getType().propagate(Y);
        }
      }
    }
  });

  infer.registerFunction("yui_use", function(self, args, argNodes) {
    var yui = self.getType();
    if (yui && argNodes) {
      var index = getFnIndex(argNodes);
      if (index) {
        var fn = args[index];
        if (fn.argNames  && fn.argNames.length > 0) {
          var Y = fn.args[0];
          yui.propagate(Y);

          var cx = infer.cx(), defs = cx.definitions["aui"];
		  for(var d in defs) {
			defs[d].getType().propagate(Y);
		  }
          //defs['event'].getType().propagate(Y);
          //defs['node'].getType().propagate(Y);

          for ( var i = 0; i < argNodes.length - 1; i++) {
            var node = argNodes[i];
            if (node.type == "Literal" && typeof node.value == "string") {
              injectModule(Y, node.value);
            } else if (node.type == "ArrayExpression") for (var i = 0; i < node.elements.length; ++i) {
              var elt = node.elements[i];
              if (elt.type == "Literal" && typeof elt.value == "string") {
                injectModule(Y, elt.value);
              }
            }
          }
        }
      }
    }
  });

  function preCondenseReach(state) {

  }

  function postLoadDef(json) {
    var cx = infer.cx(), defName = json["!name"], defs = cx.definitions[defName], server = cx.parent, _yui = server._yui, yuiModule = defName && defName.slice(0, 'yui-'.length) == 'yui-';
    if (defs && yuiModule) for (var name in defs) {
      var obj = defs[name].getType();
      if (obj.metaData) {
        // it's a component
        var metaData = obj.metaData, componentName = null;
        for ( componentName in metaData) {
          var c = metaData[componentName];
          for(var prop in c) {
            switch(prop) {
            case 'plugins':
              break;
            case 'submodules':
              var submodules = c[prop];
              for ( var submoduleName in submodules) {
                var submodule = submodules[submoduleName];
                var module = getOrCreateModule(_yui, submoduleName);
                module.requires = submodule.requires;
              }
              break;
            case 'use':
              var component = new Component();
              component.use = c[prop];
              _yui.components[componentName] = component;
              break;
            }
          }
        }
      } else {
        // it's a module
        var moduleName = name.replace(/_/g, '-')
        var module = getOrCreateModule(_yui, moduleName);
        module.def = obj;
      }
    }
  }

  tern.registerPlugin("aui", function(server, options) {
    server._yui = {
        components: Object.create(null),
        modules: Object.create(null)
    };

    server.on("reset", function() {
      this._yui.initialized = false;
      this._yui.modules = Object.create(null);
    });

    return {
      defs: defs,
      passes: {
        preCondenseReach: preCondenseReach,
        postLoadDef: postLoadDef
      },
    };
  });

  var defs = {
 "!name": "aui",
 "!define": {
  "aui_ace_editor": {
   "A.AutoCompleteBase": {
    "!type": "fn(config: Object) -> +aui_ace_editor.A.AutoCompleteBase",
    "!doc": "A base class for AutoCompleteBase.",
    "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html",
    "Base.FILL_MODE_INSERT": {
     "!type": "?",
     "!doc": "Exposes a constant for insert fill mode. See <code>fillMode</code> for more information.",
     "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html#property_Base.FILL_MODE_INSERT"
    },
    "Base.FILL_MODE_OVERWRITE": {
     "!type": "?",
     "!doc": "Exposes a constant for overwrite fill mode. See <code>fillMode</code> for more information.",
     "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html#property_Base.FILL_MODE_OVERWRITE"
    },
    "AutoCompleteBase.NAME": {
     "!type": "string",
     "!doc": "Static property which provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html#property_AutoCompleteBase.NAME"
    },
    "AutoCompleteBase.NS": {
     "!type": "string",
     "!doc": "Static property which provides a string to identify the namespace.",
     "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html#property_AutoCompleteBase.NS"
    },
    "AutoCompleteBase.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for AutoCompleteBase.",
     "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html#property_AutoCompleteBase.ATTRS"
    },
    "prototype": {
     "fillMode": {
      "!type": "fn()",
      "!doc": "The mode in which the AutoComplete should operate. Can be one of these:\nINSERT - value '0' or OVERWRITE - value '1'\nIn case of INSERT mode, when Editor adds a suggestion, it will be added next to the matched expression.\nIn case of OVERWRITE mode, the suggestion will overwrite the matched expression.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html#attribute_fillMode"
     },
     "filters": {
      "!type": "fn()",
      "!doc": "Provides an array of filter functions which will filter the results. By default there is one function which provides phrase match filtering.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html#attribute_filters"
     },
     "processor": {
      "!type": "fn()",
      "!doc": "The default processor which will be used to process matches.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html#attribute_processor"
     },
     "showListKey": {
      "!type": "fn()",
      "!doc": "The keyboard combination which should be used to show the list with found results.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html#attribute_showListKey"
     },
     "sorters": {
      "!type": "fn()",
      "!doc": "Provides an array of sorter functions which will sort the results. By default there is one function which sorts the results in ascending order.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteBase.html#attribute_sorters"
     }
    }
   },
   "A.Freemarker": {
    "!type": "fn(config: Object) -> +aui_ace_editor.A.Freemarker",
    "!proto": "A.AceEditor.TemplateProcessor",
    "!doc": "A base class for Freemarker plugin.",
    "!url": "http://alloyui.com/classes/A.Freemarker.html",
    "prototype": {
     "getMatch": {
      "!type": "fn(content: string) -> +Object",
      "!doc": "Checks if the provided content contains directive or variable.",
      "!url": "http://alloyui.com/classes/A.Freemarker.html#method_getMatch"
     },
     "directives": {
      "!type": "fn()",
      "!doc": "Contains the list of supported directives according to Freemarker specification.",
      "!url": "http://alloyui.com/classes/A.Freemarker.html#attribute_directives"
     },
     "directivesMatcher": {
      "!type": "fn()",
      "!doc": "Contains the regular expression which checks for directive presence.",
      "!url": "http://alloyui.com/classes/A.Freemarker.html#attribute_directivesMatcher"
     },
     "host": {
      "!type": "fn()",
      "!doc": "The Editor in which the current instance is plugged.",
      "!url": "http://alloyui.com/classes/A.Freemarker.html#attribute_host"
     },
     "variables": {
      "!type": "fn()",
      "!doc": "Contains the supported variables.",
      "!url": "http://alloyui.com/classes/A.Freemarker.html#attribute_variables"
     },
     "variablesMatcher": {
      "!type": "fn()",
      "!doc": "Contains the regular expression which will check for variable match.",
      "!url": "http://alloyui.com/classes/A.Freemarker.html#attribute_variablesMatcher"
     }
    },
    "Freemarker.NAME": {
     "!type": "string",
     "!doc": "Static property which provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Freemarker.html#property_Freemarker.NAME"
    },
    "Freemarker.NS": {
     "!type": "string",
     "!doc": "The namespace of the plugin.",
     "!url": "http://alloyui.com/classes/A.Freemarker.html#property_Freemarker.NS"
    },
    "Freemarker.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Freemarker.",
     "!url": "http://alloyui.com/classes/A.Freemarker.html#property_Freemarker.ATTRS"
    }
   },
   "A.AutoCompleteList": {
    "!type": "fn(config: Object) -> +aui_ace_editor.A.AutoCompleteList",
    "!proto": "A.Overlay",
    "!doc": "A base class for AutoCompleteList.",
    "!url": "http://alloyui.com/classes/A.AutoCompleteList.html",
    "AutoCompleteList.NAME": {
     "!type": "string",
     "!doc": "Static property which provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#property_AutoCompleteList.NAME"
    },
    "AutoCompleteList.NS": {
     "!type": "string",
     "!doc": "The namespace of the plugin.",
     "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#property_AutoCompleteList.NS"
    },
    "AutoCompleteList.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the AutoCompleteList.",
     "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#property_AutoCompleteList.ATTRS"
    },
    "prototype": {
     "host": {
      "!type": "fn()",
      "!doc": "The Editor in which the current instance is plugged.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#attribute_host"
     },
     "listNode": {
      "!type": "fn()",
      "!doc": "A Node in which results will be shown.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#attribute_listNode"
     },
     "loadingMessage": {
      "!type": "fn()",
      "!doc": "A string, representing the loading message.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#attribute_loadingMessage"
     },
     "results": {
      "!type": "fn()",
      "!doc": "Contains the current set of results in the list.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#attribute_results"
     },
     "selectedEntry": {
      "!type": "fn()",
      "!doc": "Provides the currently selected entry.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#attribute_selectedEntry"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "Collection of strings used to label elements of the UI.",
      "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#attribute_strings"
     }
    },
    "AutoCompleteList.CSS_PREFIX": {
     "!type": "string",
     "!doc": "The prefix of all CSS Classes.",
     "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#property_AutoCompleteList.CSS_PREFIX"
    },
    "AutoCompleteList.HTML_PARSER": {
     "!type": "?",
     "!doc": "Object hash, defining how attribute values are to be parsed from markup contained in the widget's content box.",
     "!url": "http://alloyui.com/classes/A.AutoCompleteList.html#property_AutoCompleteList.HTML_PARSER"
    }
   },
   "A.TemplateProcessor": {
    "!type": "fn(config: Object) -> +aui_ace_editor.A.TemplateProcessor",
    "!proto": "A.Base",
    "!doc": "A base class for TemplateProcessor.",
    "!url": "http://alloyui.com/classes/A.TemplateProcessor.html",
    "prototype": {
     "getResults": {
      "!type": "fn(match: Object, callbackSuccess: fn(), callbackError: fn())",
      "!doc": "Accepts match and depending on its type processes directives or variables.\nIn case of success, calls the provided success callback, or the error callback otherwise.",
      "!url": "http://alloyui.com/classes/A.TemplateProcessor.html#method_getResults"
     },
     "getSuggestion": {
      "!type": "fn(match: Object, selectedSuggestion: string) -> string",
      "!doc": "Formats the selected suggestion depending on the match type and currently selected editor mode.\nThe match type can be one of:\nMATCH_DIRECTOVES or MATCH_VARIABLES.\nThe selected editor mode can be one of the following:\nINSERT or OVERWRITE.\nSee {{#crossLink \"AceEditor.AutoCompleteBase/fillMode:attribute\"}}{{/crossLink}}",
      "!url": "http://alloyui.com/classes/A.TemplateProcessor.html#method_getSuggestion"
     },
     "directives": {
      "!type": "fn()",
      "!doc": "Contains an array of all possible directives for the corresponding language.",
      "!url": "http://alloyui.com/classes/A.TemplateProcessor.html#attribute_directives"
     },
     "host": {
      "!type": "fn()",
      "!doc": "The Editor in which the current instance is plugged.",
      "!url": "http://alloyui.com/classes/A.TemplateProcessor.html#attribute_host"
     },
     "variables": {
      "!type": "fn()",
      "!doc": "Contains the supported variables for the corresponding language.",
      "!url": "http://alloyui.com/classes/A.TemplateProcessor.html#attribute_variables"
     }
    },
    "TemplateProcessor.NAME": {
     "!type": "string",
     "!doc": "Static property which provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TemplateProcessor.html#property_TemplateProcessor.NAME"
    },
    "TemplateProcessor.NS": {
     "!type": "string",
     "!doc": "The namespace of the plugin.",
     "!url": "http://alloyui.com/classes/A.TemplateProcessor.html#property_TemplateProcessor.NS"
    },
    "TemplateProcessor.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TemplateProcessor.",
     "!url": "http://alloyui.com/classes/A.TemplateProcessor.html#property_TemplateProcessor.ATTRS"
    }
   },
   "A.Velocity": {
    "!type": "fn(config: Object) -> +aui_ace_editor.A.Velocity",
    "!proto": "A.AceEditor.TemplateProcessor",
    "!doc": "A base class for Velocity plugin.",
    "!url": "http://alloyui.com/classes/A.Velocity.html",
    "prototype": {
     "getMatch": {
      "!type": "fn(content: string) -> +Object",
      "!doc": "Checks if the provided content contains directive or variable.",
      "!url": "http://alloyui.com/classes/A.Velocity.html#method_getMatch"
     },
     "directives": {
      "!type": "fn()",
      "!doc": "Contains the list of supported directives according to Velocity specification.",
      "!url": "http://alloyui.com/classes/A.Velocity.html#attribute_directives"
     },
     "directivesMatcher": {
      "!type": "fn()",
      "!doc": "Contains the regular expression which checks for directive.",
      "!url": "http://alloyui.com/classes/A.Velocity.html#attribute_directivesMatcher"
     },
     "host": {
      "!type": "fn()",
      "!doc": "he Editor in which the current instance is plugged.",
      "!url": "http://alloyui.com/classes/A.Velocity.html#attribute_host"
     },
     "variables": {
      "!type": "fn()",
      "!doc": "Contains the supported variables.",
      "!url": "http://alloyui.com/classes/A.Velocity.html#attribute_variables"
     },
     "variablesMatcher": {
      "!type": "fn()",
      "!doc": "Contains the regular expression which will check for variable match.",
      "!url": "http://alloyui.com/classes/A.Velocity.html#attribute_variablesMatcher"
     }
    },
    "Velocity.NAME": {
     "!type": "string",
     "!doc": "Static property which provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Velocity.html#property_Velocity.NAME"
    },
    "Velocity.NS": {
     "!type": "string",
     "!doc": "The namespace of the plugin.",
     "!url": "http://alloyui.com/classes/A.Velocity.html#property_Velocity.NS"
    },
    "Velocity.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Velocity.",
     "!url": "http://alloyui.com/classes/A.Velocity.html#property_Velocity.ATTRS"
    }
   },
   "A.AceEditor": {
    "!type": "fn(config: Object) -> +aui_ace_editor.A.AceEditor",
    "!proto": "A.Widget",
    "!doc": "A base class for ACE Editor.\n\nCheck the [live demo](http://alloyui.com/examples/ace-editor/).",
    "!url": "http://alloyui.com/classes/A.AceEditor.html",
    "AceEditor.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.AceEditor.html#property_AceEditor.NAME"
    },
    "AceEditor.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.AceEditor.html#property_AceEditor.EXTENDS"
    },
    "AceEditor.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ACE Editor.",
     "!url": "http://alloyui.com/classes/A.AceEditor.html#property_AceEditor.ATTRS"
    },
    "prototype": {
     "height": {
      "!type": "fn()",
      "!doc": "The height of ACE Editor.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#attribute_height"
     },
     "highlightActiveLine": {
      "!type": "fn()",
      "!doc": "Determine if the active line of code\nwill be highlighted or not.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#attribute_highlightActiveLine"
     },
     "mode": {
      "!type": "fn()",
      "!doc": "Correspond to the language being typed.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#attribute_mode"
     },
     "readOnly": {
      "!type": "fn()",
      "!doc": "Determine if the code will be\neditable or not.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#attribute_readOnly"
     },
     "showPrintMargin": {
      "!type": "fn()",
      "!doc": "Determine if print margin will\nbe visible or not.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#attribute_showPrintMargin"
     },
     "tabSize": {
      "!type": "fn()",
      "!doc": "The indentation size of tab key.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#attribute_tabSize"
     },
     "useSoftTabs": {
      "!type": "fn()",
      "!doc": "Determine if the tab key will act as\nspace characters or tab characters.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#attribute_useSoftTabs"
     },
     "useWrapMode": {
      "!type": "fn()",
      "!doc": "Determine if the line will break\nwhen it reaches the end of the line.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#attribute_useWrapMode"
     },
     "value": {
      "!type": "fn()",
      "!doc": "Some predefined value on the editor.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#attribute_value"
     },
     "width": {
      "!type": "fn()",
      "!doc": "The width of ACE Editor.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#attribute_width"
     },
     "getEditor": {
      "!type": "fn()",
      "!doc": "Get editor.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#method_getEditor"
     },
     "getSelection": {
      "!type": "fn()",
      "!doc": "Get a text selection.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#method_getSelection"
     },
     "getSession": {
      "!type": "fn()",
      "!doc": "Get session.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#method_getSession"
     },
     "gotoLine": {
      "!type": "fn(line)",
      "!doc": "Go to a specific line of code.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#method_gotoLine"
     },
     "insert": {
      "!type": "fn(text)",
      "!doc": "Insert content into the editor.",
      "!url": "http://alloyui.com/classes/A.AceEditor.html#method_insert"
     }
    },
    "AceEditor.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.AceEditor.html#property_AceEditor.UI_ATTRS"
    }
   }
  },
  "aui_aria": {
   "A.Aria": {
    "!type": "fn(config: Object) -> +aui_aria.A.Aria",
    "!proto": "A.Plugin.Base",
    "!doc": "A base class for Aria.",
    "!url": "http://alloyui.com/classes/A.Aria.html",
    "Aria.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Aria.html#property_Aria.NAME"
    },
    "Aria.NS": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the namespace.",
     "!url": "http://alloyui.com/classes/A.Aria.html#property_Aria.NS"
    },
    "Aria.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Aria.",
     "!url": "http://alloyui.com/classes/A.Aria.html#property_Aria.ATTRS"
    },
    "prototype": {
     "attributes": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#attribute_attributes"
     },
     "attributeValueFormat": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#attribute_attributeValueFormat"
     },
     "attributeNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#attribute_attributeNode"
     },
     "roleName": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#attribute_roleName"
     },
     "roleNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#attribute_roleNode"
     },
     "validateW3C": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#attribute_validateW3C"
     },
     "isValidAttribute": {
      "!type": "fn(attrName)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#method_isValidAttribute"
     },
     "isValidRole": {
      "!type": "fn(roleName)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#method_isValidRole"
     },
     "setAttribute": {
      "!type": "fn(attrName, attrValue, node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#method_setAttribute"
     },
     "setAttributes": {
      "!type": "fn(attributes)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#method_setAttributes"
     },
     "setRole": {
      "!type": "fn(roleName, node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#method_setRole"
     },
     "setRoles": {
      "!type": "fn(roles)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Aria.html#method_setRoles"
     }
    },
    "Aria.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.Aria.html#property_Aria.EXTENDS"
    }
   }
  },
  "aui_arraysort": {
   "A.ArraySort": {
    "!type": "fn() -> +aui_arraysort.A.ArraySort",
    "!doc": "Augment the <a href=\"ArraySort.html\">YUI3 ArraySort</a> with more util methods.",
    "!url": "http://alloyui.com/classes/A.ArraySort.html",
    "prototype": {
     "compareIgnoreWhiteSpace": {
      "!type": "fn(a, b, desc, compareFn) -> ?",
      "!doc": "Compare two arrays ignoring white spaces.",
      "!url": "http://alloyui.com/classes/A.ArraySort.html#method_compareIgnoreWhiteSpace"
     },
     "stableSort": {
      "!type": "fn(array, compareFn)",
      "!doc": "Sorts an object array keeping the order of equal items. ECMA script\nstandard does not specify the behaviour when the compare function\nreturns the value 0;",
      "!url": "http://alloyui.com/classes/A.ArraySort.html#method_stableSort"
     }
    }
   }
  },
  "aui_audio": {
   "A.Audio": {
    "!type": "fn(config: Object) -> +aui_audio.A.Audio",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for Audio.\n\nCheck the [live demo](http://alloyui.com/examples/audio/).",
    "!url": "http://alloyui.com/classes/A.Audio.html",
    "Audio.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Audio.html#property_Audio.NAME"
    },
    "Audio.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Audio.",
     "!url": "http://alloyui.com/classes/A.Audio.html#property_Audio.ATTRS"
    },
    "prototype": {
     "url": {
      "!type": "fn()",
      "!doc": "URL used by Audio to play.",
      "!url": "http://alloyui.com/classes/A.Audio.html#attribute_url"
     },
     "oggUrl": {
      "!type": "fn()",
      "!doc": "URL (on .ogg format) used by Audio to play.",
      "!url": "http://alloyui.com/classes/A.Audio.html#attribute_oggUrl"
     },
     "type": {
      "!type": "fn()",
      "!doc": "The type of audio.",
      "!url": "http://alloyui.com/classes/A.Audio.html#attribute_type"
     },
     "swfWidth": {
      "!type": "fn()",
      "!doc": "The width of Audio's fallback using Flash.",
      "!url": "http://alloyui.com/classes/A.Audio.html#attribute_swfWidth"
     },
     "swfHeight": {
      "!type": "fn()",
      "!doc": "The height of Audio's fallback using Flash.",
      "!url": "http://alloyui.com/classes/A.Audio.html#attribute_swfHeight"
     },
     "swfUrl": {
      "!type": "fn()",
      "!doc": "URL (on .swf format) used by Audio to create\na fallback player with Flash.",
      "!url": "http://alloyui.com/classes/A.Audio.html#attribute_swfUrl"
     },
     "fixedAttributes": {
      "!type": "fn()",
      "!doc": "An additional list of attributes.",
      "!url": "http://alloyui.com/classes/A.Audio.html#attribute_fixedAttributes"
     },
     "flashVars": {
      "!type": "fn()",
      "!doc": "Variables used by Flash player.",
      "!url": "http://alloyui.com/classes/A.Audio.html#attribute_flashVars"
     },
     "render": {
      "!type": "fn()",
      "!doc": "If <code>true</code> the render phase will be automatically invoked\npreventing the <code>.render()</code> manual call.",
      "!url": "http://alloyui.com/classes/A.Audio.html#attribute_render"
     },
     "load": {
      "!type": "fn()",
      "!doc": "Load audio track.",
      "!url": "http://alloyui.com/classes/A.Audio.html#method_load"
     },
     "pause": {
      "!type": "fn()",
      "!doc": "Pause audio track.",
      "!url": "http://alloyui.com/classes/A.Audio.html#method_pause"
     },
     "play": {
      "!type": "fn()",
      "!doc": "Play audio track.",
      "!url": "http://alloyui.com/classes/A.Audio.html#method_play"
     }
    },
    "Audio.BIND_UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the attributes\nfor the bindUI lifecycle phase.",
     "!url": "http://alloyui.com/classes/A.Audio.html#property_Audio.BIND_UI_ATTRS"
    },
    "Audio.SYNC_UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the attributes\nfor the syncUI lifecycle phase.",
     "!url": "http://alloyui.com/classes/A.Audio.html#property_Audio.SYNC_UI_ATTRS"
    }
   }
  },
  "aui_autocomplete": {
   "AutoComplete": {
    "!type": "fn(config: Object) -> +aui_autocomplete.AutoComplete",
    "!proto": "Component",
    "!doc": "<p><img src=\"assets/images/aui-autocomplete/main.png\"/></p>\n\nA base class for AutoComplete, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Presenting users choices based on their input</li>\n   <li>Separating selected items</li>\n   <li>Keyboard interaction for selecting items</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var instance = new A.AutoCompleteDeprecated({\n\tdataSource: [['AL', 'Alabama', 'The Heart of Dixie'],\n\t['AK', 'Alaska', 'The Land of the Midnight Sun'],\n\t['AZ', 'Arizona', 'The Grand Canyon State']],\n\tschema: {\n\t\tresultFields: ['key', 'name', 'description']\n\t},\n\tmatchKey: 'name',\n\tdelimChar: ',',\n\ttypeAhead: true,\n\tcontentBox: '#myAutoComplete'\n}).render();\n</code></pre>\n\nCheck the list of <a href=\"AutoComplete.html#configattributes\">Configuration Attributes</a> available for\nAutoComplete.",
    "!url": "http://alloyui.com/classes/AutoComplete.html",
    "AutoComplete.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/AutoComplete.html#property_AutoComplete.NAME"
    },
    "AutoComplete.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the AutoComplete.",
     "!url": "http://alloyui.com/classes/AutoComplete.html#property_AutoComplete.ATTRS"
    },
    "prototype": {
     "alwaysShowContainer": {
      "!type": "fn()",
      "!doc": "Always show the results container, instead of only showing when the\nuser is requesting them.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_alwaysShowContainer"
     },
     "autoHighlight": {
      "!type": "fn()",
      "!doc": "Automatically highlight the first item in the list when the results are\nmade visible.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_autoHighlight"
     },
     "applyLocalFilter": {
      "!type": "fn()",
      "!doc": "If set to true, the <a href=\"AutoComplete.html#method_filterResults\">filterResults</a>\nmethod will be run on the response from the data source.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_applyLocalFilter"
     },
     "button": {
      "!type": "fn()",
      "!doc": "To use a button",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_button"
     },
     "dataSource": {
      "!type": "fn()",
      "!doc": "The data source that results will be read from. This can either be\nan existing <a href=\"DataSource.html\">DataSource</a> object, or it can be a\nvalue that would be passed to <a href=\"DataSource.html\">DataSource</a>.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_dataSource"
     },
     "dataSourceType": {
      "!type": "fn()",
      "!doc": "The type of the data source passed into <a href=\"AutoComplete.html#config_dataSource\">dataSource</a>.\nThis can be used to explicitly declare what kind of <a href=\"DataSource.html\">DataSource</a> object will\nbe created.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_dataSourceType"
     },
     "delimChar": {
      "!type": "fn()",
      "!doc": "The character used to indicate the beginning or ending of a new value. Most commonly used\nis a \",\".",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_delimChar"
     },
     "forceSelection": {
      "!type": "fn()",
      "!doc": "If <a href=\"AutoComplete.html#config_typeAhead\">typeAhead</a> is true, this\nwill clear a selection when the overlay closes unless a user explicitly selects an item.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_forceSelection"
     },
     "input": {
      "!type": "fn()",
      "!doc": "The input field which will recieve the users input.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_input"
     },
     "matchKey": {
      "!type": "fn()",
      "!doc": "The key or numeric index in the schema to match the result against.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_matchKey"
     },
     "maxResultsDisplayed": {
      "!type": "fn()",
      "!doc": "The maximum number of results to display.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_maxResultsDisplayed"
     },
     "minQueryLength": {
      "!type": "fn()",
      "!doc": "The minimum number of characters required to query the data source.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_minQueryLength"
     },
     "queryDelay": {
      "!type": "fn()",
      "!doc": "The amount of time in seconds to delay before submitting the query.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_queryDelay"
     },
     "queryInterval": {
      "!type": "fn()",
      "!doc": "When IME usage is detected or interval detection is explicitly enabled,\nAutoComplete will detect the input value at the given interval and send a\nquery if the value has changed.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_queryInterval"
     },
     "queryMatchCase": {
      "!type": "fn()",
      "!doc": "When <a href=\"AutoComplete.html#config_applyLocalFilter\">applyLocalFilter</a> is true,\nsetting this to true will match only results with the same case.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_queryMatchCase"
     },
     "queryMatchContains": {
      "!type": "fn()",
      "!doc": "When <a href=\"AutoComplete.html#config_applyLocalFilter\">applyLocalFilter</a> is true,\nsetting this to true will match results which contain the query anywhere in the text,\ninstead of just matching just items that start with the query.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_queryMatchContains"
     },
     "queryQuestionMark": {
      "!type": "fn()",
      "!doc": "For IO DataSources, AutoComplete will automatically insert a \"?\" between the server URI and\nthe encoded query string. To prevent this behavior, you can\nset this value to false. If you need to customize this even further, you\ncan override the <a href=\"AutoComplete.html#method_generateRequest\">generateRequest</a> method.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_queryQuestionMark"
     },
     "schema": {
      "!type": "fn()",
      "!doc": "A valid configuration object for any of <a href=\"module_datasource.html\">DataSource</a> schema plugins.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_schema"
     },
     "schemaType": {
      "!type": "fn()",
      "!doc": "A valid type of <a href=\"module_datasource.html\">DataSource</a> schema plugin, such as array, json, xml, etc.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_schemaType"
     },
     "suppressInputUpdate": {
      "!type": "fn()",
      "!doc": "Whether or not the input field should be updated with selections.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_suppressInputUpdate"
     },
     "typeAhead": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the typeAhead event. Fired when the input element has been pre-filled by the type-ahead feature.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_typeAhead"
     },
     "typeAheadDelay": {
      "!type": "fn()",
      "!doc": "If <a href=\"AutoComplete.html#config_typeAhead\">typeAhead</a> is true, number of seconds\nto delay before updating the input. In order to prevent certain race conditions, this value must\nalways be greater than the <a href=\"AutoComplete.html#config_queryDelay\">queryDelay</a>.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_typeAheadDelay"
     },
     "uniqueName": {
      "!type": "fn()",
      "!doc": "The unique ID of the input element.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#attribute_uniqueName"
     },
     "containerCollapse": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the containerCollapse event. Fired when the container is hidden.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_containerCollapse"
     },
     "containerExpand": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the containerExpand event. Fired when the container is shown.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_containerExpand"
     },
     "containerPopulate": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the containerPopulate event. Fired when the container is populated.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_containerPopulate"
     },
     "dataError": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the dataError event. Fired when there is an error accessing the data.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_dataError"
     },
     "dataRequest": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the dataRequest event. Fired when ever a query is sent to the data source.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_dataRequest"
     },
     "dataReturn": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the dataReturn event. Fired when data successfully comes back from the data request.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_dataReturn"
     },
     "itemArrowFrom": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the itemArrowFrom event. Fired when the user navigates via the keyboard away from\na selected item.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_itemArrowFrom"
     },
     "itemArrowTo": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the itemArrowTo event. Fired when the user navigates via the keyboard to a selected item.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_itemArrowTo"
     },
     "itemMouseOut": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the itemMouseOut event. Fired when the user mouses away from an item.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_itemMouseOut"
     },
     "itemMouseOver": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the itemMouseOver event. Fired when the user mouses over an item.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_itemMouseOver"
     },
     "itemSelect": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the itemSelect event. Fired when an item in the list is selected.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_itemSelect"
     },
     "selectionEnforce": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the selectionEnforce event. Fired if <a href=\"Autocomplete.html#config_forceSelection\">forceSelection</a>\nis enabled and the users input element has been cleared because it did not match one of the results.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_selectionEnforce"
     },
     "textboxBlur": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the textboxBlur event. Fired when the user leaves the input element.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_textboxBlur"
     },
     "textboxChange": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the textboxChange event. Fired when the value in the input element is changed.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_textboxChange"
     },
     "textboxFocus": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the textboxFocus event. Fired when user moves focus to the input element.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_textboxFocus"
     },
     "textboxKey": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the textboxKey event. Fired when the input element receives key input.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_textboxKey"
     },
     "unmatchedItemSelect": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the unmatchedItemSelect event. Fired when a user selects something that does\nnot match any of the displayed results.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#event_unmatchedItemSelect"
     },
     "doBeforeExpandContainer": {
      "!type": "fn(query: string, allResults: Object) -> bool",
      "!doc": "An overridable method that is executed before the result container is shown.\nThe method can return false to prevent the container from being shown.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#method_doBeforeExpandContainer"
     },
     "doBeforeLoadData": {
      "!type": "fn(event: EventFacade) -> bool",
      "!doc": "An overridable method that is executed before the result overlay is loaded with results.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#method_doBeforeLoadData"
     },
     "filterResults": {
      "!type": "fn(event: EventFacade) -> +Object",
      "!doc": "Executed by the data source as a mechanism to do simple client-side\nfiltering of the results.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#method_filterResults"
     },
     "formatResult": {
      "!type": "fn(result: Object, request: string, resultMatch: string) -> string",
      "!doc": "An overridable method for formatting the result of the query before it's displayed in the overlay.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#method_formatResult"
     },
     "generateRequest": {
      "!type": "fn(query: string) -> +Object",
      "!doc": "An overridable method that creates an object to be passed to the sendRequest\nmethod of the data source object. Useful to overwrite if you wish to create\na custom request object before it's sent.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#method_generateRequest"
     },
     "handleResponse": {
      "!type": "fn(event: EventFacade)",
      "!doc": "Handles the response for the display of the results. This is a callback method\nthat is fired by the sendRequest method so that results are ready to be accessed.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#method_handleResponse"
     },
     "sendQuery": {
      "!type": "fn(query: string)",
      "!doc": "Sends a query request to the data source object.",
      "!url": "http://alloyui.com/classes/AutoComplete.html#method_sendQuery"
     }
    }
   }
  },
  "aui_autosize_iframe": {
   "A.AutosizeIframe": {
    "!type": "fn(config: Object) -> +aui_autosize_iframe.A.AutosizeIframe",
    "!proto": "A.Plugin.Base",
    "!doc": "A base class for AutosizeIframe.",
    "!url": "http://alloyui.com/classes/A.AutosizeIframe.html",
    "AutosizeIframe.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.AutosizeIframe.html#property_AutosizeIframe.NAME"
    },
    "AutosizeIframe.NS": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the namespace.",
     "!url": "http://alloyui.com/classes/A.AutosizeIframe.html#property_AutosizeIframe.NS"
    },
    "AutosizeIframe.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.AutosizeIframe.html#property_AutosizeIframe.EXTENDS"
    },
    "AutosizeIframe.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the AutosizeIframe.",
     "!url": "http://alloyui.com/classes/A.AutosizeIframe.html#property_AutosizeIframe.ATTRS"
    },
    "prototype": {
     "height": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AutosizeIframe.html#attribute_height"
     },
     "monitorHeight": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AutosizeIframe.html#attribute_monitorHeight"
     },
     "width": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AutosizeIframe.html#attribute_width"
     },
     "pauseMonitor": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AutosizeIframe.html#method_pauseMonitor"
     },
     "restartMonitor": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AutosizeIframe.html#method_restartMonitor"
     },
     "getContentHeight": {
      "!type": "fn(iframeWin)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AutosizeIframe.html#method_getContentHeight"
     }
    }
   },
   "ButtonExt": {
    "!type": "fn(config: Object) -> +aui_button.ButtonExt",
    "!doc": "A base class for ButtonExt.",
    "!url": "http://alloyui.com/classes/ButtonExt.html",
    "prototype": {
     "undefined": {
      "!type": "fn()",
      "!doc": "Maps an array or object to a resulting array, using the return value of\nfn as the values for the new array. Like A.each, this function can accept\nan object or an array.",
      "!url": "http://alloyui.com/classes/ButtonExt.html"
     }
    }
   }
  },
  "aui_button": {
   "ButtonExt": {
    "!type": "fn(config: Object) -> +aui_button.ButtonExt",
    "!doc": "A base class for ButtonExt.",
    "!url": "http://alloyui.com/classes/ButtonExt.html",
    "ButtonExt.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ButtonExt.",
     "!url": "http://alloyui.com/classes/ButtonExt.html#property_ButtonExt.ATTRS"
    },
    "prototype": {
     "icon": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/ButtonExt.html#attribute_icon"
     },
     "iconElement": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/ButtonExt.html#attribute_iconElement"
     },
     "iconAlign": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/ButtonExt.html#attribute_iconAlign"
     },
     "primary": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/ButtonExt.html#attribute_primary"
     },
     "syncButtonExtUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/ButtonExt.html#method_syncButtonExtUI"
     }
    },
    "ButtonExt.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/ButtonExt.html#property_ButtonExt.HTML_PARSER"
    },
    "getTypedButtonTemplate": {
     "!type": "fn(type)",
     "!doc": "Get typed buttons template.",
     "!url": "http://alloyui.com/classes/ButtonExt.html#method_getTypedButtonTemplate"
    }
   },
   "A.ButtonCore": {
    "!type": "fn() -> +aui_button.A.ButtonCore",
    "!doc": "A base class for ButtonCore.",
    "!url": "http://alloyui.com/classes/A.ButtonCore.html",
    "ButtonCore.CLASS_NAMES": {
     "!type": "?",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.ButtonCore.html#property_ButtonCore.CLASS_NAMES"
    },
    "prototype": {
     "_uiSetLabel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ButtonCore.html#method__uiSetLabel"
     }
    },
    "Button.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ButtonCore.html#property_Button.NAME"
    },
    "Button.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.ButtonCore.html#property_Button.CSS_PREFIX"
    },
    "Button.CLASS_NAMES": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.ButtonCore.html#property_Button.CLASS_NAMES"
    }
   },
   "A.Button": {
    "!type": "fn() -> +aui_button.A.Button",
    "!proto": "Button",
    "!doc": "A base class for Button.",
    "!url": "http://alloyui.com/classes/A.Button.html",
    "Button.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.Button.html#property_Button.CSS_PREFIX"
    },
    "prototype": {
     "getWidgetLazyConstructorFromNodeData": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Button.html#method_getWidgetLazyConstructorFromNodeData"
     },
     "hasWidgetLazyConstructorData": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Button.html#method_hasWidgetLazyConstructorData"
     },
     "setWidgetLazyConstructorNodeData": {
      "!type": "fn(node, config)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Button.html#method_setWidgetLazyConstructorNodeData"
     },
     "syncIconUI": {
      "!type": "fn(buttonElement, iconElement, iconAlign)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Button.html#method_syncIconUI"
     }
    },
    "ToggleButton.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Button.html#property_ToggleButton.NAME"
    },
    "ToggleButton.CSS_PREFIX": {
     "!type": "+typeName",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.Button.html#property_ToggleButton.CSS_PREFIX"
    },
    "ToggleButton.CLASS_NAMES": {
     "!type": "+typeName",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.Button.html#property_ToggleButton.CLASS_NAMES"
    }
   },
   "A.ToggleButton": {
    "!type": "fn(config: Object) -> +aui_button.A.ToggleButton",
    "!doc": "A base class for ToggleButton.",
    "!url": "http://alloyui.com/classes/A.ToggleButton.html",
    "ButtonGroup.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ToggleButton.html#property_ButtonGroup.NAME"
    },
    "ButtonGroup.CSS_PREFIX": {
     "!type": "+typeName",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.ToggleButton.html#property_ButtonGroup.CSS_PREFIX"
    },
    "ButtonGroup.CLASS_NAMES": {
     "!type": "+typeName",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.ToggleButton.html#property_ButtonGroup.CLASS_NAMES"
    }
   },
   "A.ButtonGroup": {
    "!type": "fn() -> +aui_button.A.ButtonGroup",
    "!doc": "A base class for ButtonGroup.",
    "!url": "http://alloyui.com/classes/A.ButtonGroup.html",
    "prototype": {
     "item": {
      "!type": "fn(index)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ButtonGroup.html#method_item"
     },
     "select": {
      "!type": "fn(items)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ButtonGroup.html#method_select"
     },
     "toggleSelect": {
      "!type": "fn(items, forceSelection)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ButtonGroup.html#method_toggleSelect"
     },
     "unselect": {
      "!type": "fn(items)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ButtonGroup.html#method_unselect"
     }
    }
   },
   "A.ButtonSearchCancel": {
    "!type": "fn(config: Object) -> +aui_button.A.ButtonSearchCancel",
    "!proto": "A.Base",
    "!doc": "A base class for ButtonSearchCancel, providing:\n <ul>\n    <li>Adds a button search cancel icon in order to clear the text on inputs\n    and textareas. Similar behavior of the HTML5 search input that contains a\n    cancel button to clear the current element value.</li>\n </ul>",
    "!url": "http://alloyui.com/classes/A.ButtonSearchCancel.html",
    "prototype": {
     "initializer": {
      "!type": "fn()",
      "!doc": "Construction logic executed during CharCounter instantiation.\nLifecycle.",
      "!url": "http://alloyui.com/classes/A.ButtonSearchCancel.html#method_initializer"
     },
     "destroy": {
      "!type": "fn()",
      "!doc": "Destructor lifecycle implementation for the AutosizeIframe class.\nLifecycle.",
      "!url": "http://alloyui.com/classes/A.ButtonSearchCancel.html#method_destroy"
     },
     "bindDelegateUI": {
      "!type": "fn()",
      "!doc": "Delegate events on the UI. Lifecycle.",
      "!url": "http://alloyui.com/classes/A.ButtonSearchCancel.html#method_bindDelegateUI"
     },
     "getButtonForElement": {
      "!type": "fn(element: aui_node.Node) -> +aui_node.Node",
      "!doc": "Delegate events on the UI. Lifecycle.",
      "!url": "http://alloyui.com/classes/A.ButtonSearchCancel.html#method_getButtonForElement"
     },
     "container": {
      "!type": "fn()",
      "!doc": "The container of Toggler Delegate instance.",
      "!url": "http://alloyui.com/classes/A.ButtonSearchCancel.html#attribute_container"
     },
     "gutter": {
      "!type": "fn()",
      "!doc": "Gutter values are added to the x and y alignment values of the\nbutton search cancel. They can be utilized as a padding in case\nthe user needs a different alignment.",
      "!url": "http://alloyui.com/classes/A.ButtonSearchCancel.html#attribute_gutter"
     },
     "iconClass": {
      "!type": "fn()",
      "!doc": "Icon css class to be used on the search cancel button.",
      "!url": "http://alloyui.com/classes/A.ButtonSearchCancel.html#attribute_iconClass"
     },
     "trigger": {
      "!type": "fn()",
      "!doc": "Selector to the button search cancel be applied. Supports single\nor multiple node selector.",
      "!url": "http://alloyui.com/classes/A.ButtonSearchCancel.html#attribute_trigger"
     },
     "zIndex": {
      "!type": "fn()",
      "!doc": "Button search cancel z-index.",
      "!url": "http://alloyui.com/classes/A.ButtonSearchCancel.html#attribute_zIndex"
     }
    }
   }
  },
  "aui_button_item": {
   "ButtonItem": {
    "!type": "fn(config: Object) -> +aui_button_item.ButtonItem",
    "!proto": "Component",
    "!doc": "A base class for ButtonItem, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>An optional icon or label</li>\n   <li>Managed user interaction states (default, active, hover)</li>\n   <li>Keyboard accessible</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var instance = new A.ButtonItem({\n\ticon: 'gear',\nlabel: 'Configuration'\n}).render();\n</code></pre>\n\nCheck the list of <a href=\"ButtonItem.html#configattributes\">Configuration Attributes</a> available for\nButtonItem.",
    "!url": "http://alloyui.com/classes/ButtonItem.html",
    "ButtonItem.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/ButtonItem.html#property_ButtonItem.NAME"
    },
    "ButtonItem.AUGMENTS": {
     "!type": "+array",
     "!doc": "Static property provides an array to specify which classes augment this one.",
     "!url": "http://alloyui.com/classes/ButtonItem.html#property_ButtonItem.AUGMENTS"
    },
    "ButtonItem.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ButtonItem.",
     "!url": "http://alloyui.com/classes/ButtonItem.html#property_ButtonItem.ATTRS"
    },
    "prototype": {
     "activeState": {
      "!type": "fn()",
      "!doc": "Whether to track the active state of the button.",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_activeState"
     },
     "classNames": {
      "!type": "fn()",
      "!doc": "An object map of the CSS class names to use for the different interaction states.",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_classNames"
     },
     "defaultState": {
      "!type": "fn()",
      "!doc": "Whether to apply the default interaction state to the button",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_defaultState"
     },
     "handler": {
      "!type": "fn()",
      "!doc": "An event callback to handle when a user interacts with the button.\nThis can either be a function that will be attached on click, or\nan object map that accepts the following keys:\n<code>{fn: // The function to execute\ncontext: // The context to execute the function in\ntype: // The type of event to listen for (defaults to \"click\")\n}</code>",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_handler"
     },
     "hoverState": {
      "!type": "fn()",
      "!doc": "An id that can be used to identify a button.",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_hoverState"
     },
     "icon": {
      "!type": "fn()",
      "!doc": "The icon to use inside of the button. Possible values are:",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_icon"
     },
     "iconNode": {
      "!type": "fn()",
      "!doc": "DOM Node to display the icon of the ButtonItem. If not\nspecified try to query using HTML_PARSER an element inside\nboundingBox which matches <code>aui-button-icon</code>.",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_iconNode"
     },
     "label": {
      "!type": "fn()",
      "!doc": "Text to use inside of the button.",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_label"
     },
     "labelNode": {
      "!type": "fn()",
      "!doc": "DOM Node to display the text of the ButtonItem. If not\nspecified try to query using HTML_PARSER an element inside\nboundingBox which matches <code>aui-button-label</code>.",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_labelNode"
     },
     "title": {
      "!type": "fn()",
      "!doc": "Text to use as the title attribute of the button.",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_title"
     },
     "type": {
      "!type": "fn()",
      "!doc": "Button type.",
      "!url": "http://alloyui.com/classes/ButtonItem.html#attribute_type"
     }
    },
    "ButtonItem.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "Object hash, defining how attribute values are to be parsed from\nmarkup contained in the widget's content box.",
     "!url": "http://alloyui.com/classes/ButtonItem.html#property_ButtonItem.HTML_PARSER"
    }
   }
  },
  "aui_carousel": {
   "A.Carousel": {
    "!type": "fn(config: Object) -> +aui_carousel.A.Carousel",
    "!doc": "A base class for Carousel.\n\nCheck the [live demo](http://alloyui.com/examples/carousel/).",
    "!url": "http://alloyui.com/classes/A.Carousel.html",
    "Carousel.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Carousel.html#property_Carousel.NAME"
    },
    "Carousel.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Carousel.",
     "!url": "http://alloyui.com/classes/A.Carousel.html#property_Carousel.ATTRS"
    },
    "prototype": {
     "activeIndex": {
      "!type": "fn()",
      "!doc": "Index of the first visible item of the carousel.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#attribute_activeIndex"
     },
     "animationTime": {
      "!type": "fn()",
      "!doc": "Duration of the animation in seconds when change index on\nCarousel.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#attribute_animationTime"
     },
     "intervalTime": {
      "!type": "fn()",
      "!doc": "Interval time in seconds between an item transition.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#attribute_intervalTime"
     },
     "itemSelector": {
      "!type": "fn()",
      "!doc": "CSS Selector whitch determines the items to be loaded to the\nCarousel.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#attribute_itemSelector"
     },
     "nodeMenu": {
      "!type": "fn()",
      "!doc": "Node container of the navigation items.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#attribute_nodeMenu"
     },
     "nodeMenuItemSelector": {
      "!type": "fn()",
      "!doc": "CSS selector to match the navigation items.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#attribute_nodeMenuItemSelector"
     },
     "playing": {
      "!type": "fn()",
      "!doc": "Attributes that determines the status of transitions between\nitems.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#attribute_playing"
     },
     "item": {
      "!type": "fn(val)",
      "!doc": "Set the <code>activeIndex</code> attribute which\nactivates a certain item on Carousel based on its index.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#method_item"
     },
     "next": {
      "!type": "fn()",
      "!doc": "Go to the next index.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#method_next"
     },
     "pause": {
      "!type": "fn()",
      "!doc": "Set the <code>playing</code> attribute\nto false which pauses the animation.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#method_pause"
     },
     "play": {
      "!type": "fn()",
      "!doc": "Set the <code>playing</code> attribute\nto true which starts the animation.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#method_play"
     },
     "prev": {
      "!type": "fn()",
      "!doc": "Go to previous index.",
      "!url": "http://alloyui.com/classes/A.Carousel.html#method_prev"
     }
    }
   }
  },
  "aui_char_counter": {
   "A.CharCounter": {
    "!type": "fn(config: Object) -> +aui_char_counter.A.CharCounter",
    "!proto": "A.Base",
    "!doc": "A base class for CharCounter, providing:\n <ul>\n    <li>Limit the number of characters allowed in an input box</li>\n    <li>Display the number of characters left</li>\n </ul>\nCheck the [live demo](http://alloyui.com/examples/char-counter/).",
    "!url": "http://alloyui.com/classes/A.CharCounter.html",
    "CharCounter.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.CharCounter.html#property_CharCounter.NAME"
    },
    "CharCounter.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the CharCounter.",
     "!url": "http://alloyui.com/classes/A.CharCounter.html#property_CharCounter.ATTRS"
    },
    "prototype": {
     "counter": {
      "!type": "fn()",
      "!doc": "Node or Selector to display the information of the counter.",
      "!url": "http://alloyui.com/classes/A.CharCounter.html#attribute_counter"
     },
     "maxLength": {
      "!type": "fn()",
      "!doc": "Max number of characters the <a\nhref=\"CharCounter.html#config_input\">input</a> can have.",
      "!url": "http://alloyui.com/classes/A.CharCounter.html#attribute_maxLength"
     },
     "input": {
      "!type": "fn()",
      "!doc": "Node or Selector for the input field. Required.",
      "!url": "http://alloyui.com/classes/A.CharCounter.html#attribute_input"
     },
     "checkLength": {
      "!type": "fn()",
      "!doc": "Check the current value of the <a\nhref=\"CharCounter.html#config_input\">input</a>, truncate the data if\nneeded, and re-sync the UI. Fired from <a\n href=\"CharCounter.html#method__onInputChange\">_onInputChange</a>.",
      "!url": "http://alloyui.com/classes/A.CharCounter.html#method_checkLength"
     }
    },
    "CharCounter.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.CharCounter.html#property_CharCounter.EXTENDS"
    }
   }
  },
  "aui_collection": {
   "A.LinkedSet": {
    "!type": "fn(config: Object) -> +aui_collection.A.LinkedSet",
    "!proto": "A.Set",
    "!doc": "A base class for LinkedSet.",
    "!url": "http://alloyui.com/classes/A.LinkedSet.html",
    "prototype": {
     "values": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.LinkedSet.html#method_values"
     }
    }
   },
   "A.HashMap": {
    "!type": "fn(config: Object) -> +aui_collection.A.HashMap",
    "!proto": "A.Base",
    "!doc": "A base class for HashMap.",
    "!url": "http://alloyui.com/classes/A.HashMap.html",
    "prototype": {
     "clear": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_clear"
     },
     "getValue": {
      "!type": "fn(key)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_getValue"
     },
     "has": {
      "!type": "fn(key, opt_hash)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_has"
     },
     "hasValue": {
      "!type": "fn(value)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_hasValue"
     },
     "keys": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_keys"
     },
     "isEmpty": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_isEmpty"
     },
     "put": {
      "!type": "fn(key, value, opt_hash)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_put"
     },
     "putAll": {
      "!type": "fn(map)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_putAll"
     },
     "remove": {
      "!type": "fn(key, opt_hash)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_remove"
     },
     "size": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_size"
     },
     "values": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashMap.html#method_values"
     }
    }
   },
   "A.HashSet": {
    "!type": "fn(config: Object) -> +aui_collection.A.HashSet",
    "!proto": "A.Base",
    "!doc": "A base class for HashSet.",
    "!url": "http://alloyui.com/classes/A.HashSet.html",
    "prototype": {
     "add": {
      "!type": "fn(value)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashSet.html#method_add"
     },
     "clear": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashSet.html#method_clear"
     },
     "has": {
      "!type": "fn(value)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashSet.html#method_has"
     },
     "isEmpty": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashSet.html#method_isEmpty"
     },
     "remove": {
      "!type": "fn(value)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashSet.html#method_remove"
     },
     "size": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashSet.html#method_size"
     },
     "values": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HashSet.html#method_values"
     }
    }
   }
  },
  "aui_color_picker": {
   "A.ColorPalette": {
    "!type": "fn(config: Object) -> +aui_color_picker.A.ColorPalette",
    "!proto": "A.Widget",
    "!doc": "A base class for ColorPalette.",
    "!url": "http://alloyui.com/classes/A.ColorPalette.html",
    "ColorPalette.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.ColorPalette.html#property_ColorPalette.CSS_PREFIX"
    },
    "ColorPalette.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ColorPalette.html#property_ColorPalette.NAME"
    },
    "ColorPalette.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ColorPalette.",
     "!url": "http://alloyui.com/classes/A.ColorPalette.html#property_ColorPalette.ATTRS"
    },
    "prototype": {
     "items": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPalette.html#attribute_items"
     }
    }
   },
   "A.ColorPickerBase": {
    "!type": "fn(config: Object) -> +aui_color_picker.A.ColorPickerBase",
    "!doc": "A base class for ColorPickerBase.",
    "!url": "http://alloyui.com/classes/A.ColorPickerBase.html",
    "prototype": {
     "reset": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#method_reset"
     },
     "bodyContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_bodyContent"
     },
     "color": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_color"
     },
     "colorPalette": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_colorPalette"
     },
     "currentTrigger": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_currentTrigger"
     },
     "defaultColor": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_defaultColor"
     },
     "hsvPalette": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_hsvPalette"
     },
     "recentColors": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_recentColors"
     },
     "renderColorPalette": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_renderColorPalette"
     },
     "renderHSVPalette": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_renderHSVPalette"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_strings"
     },
     "trigger": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_trigger"
     },
     "triggerEvent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#attribute_triggerEvent"
     }
    },
    "ColorPickerBase.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ColorPickerBase.",
     "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#property_ColorPickerBase.ATTRS"
    },
    "ColorPickerBase.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#property_ColorPickerBase.CSS_PREFIX"
    },
    "ColorPickerBase.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ColorPickerBase.html#property_ColorPickerBase.NAME"
    }
   },
   "A.ColorPickerPopover": {
    "!type": "fn(config: Object) -> +aui_color_picker.A.ColorPickerPopover",
    "!proto": "A.Popover",
    "!doc": "A base class for ColorPickerPopover.",
    "!url": "http://alloyui.com/classes/A.ColorPickerPopover.html",
    "ColorPickerPopover.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ColorPickerPopover.",
     "!url": "http://alloyui.com/classes/A.ColorPickerPopover.html#property_ColorPickerPopover.ATTRS"
    },
    "prototype": {
     "align": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerPopover.html#attribute_align"
     },
     "visible": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.ColorPickerPopover.html#attribute_visible"
     }
    },
    "ColorPickerPopover.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ColorPickerPopover.html#property_ColorPickerPopover.NAME"
    },
    "ColorPickerPopover.NS": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.ColorPickerPopover.html#property_ColorPickerPopover.NS"
    }
   },
   "A.HSVPalette": {
    "!type": "fn(config: Object) -> +aui_color_picker.A.HSVPalette",
    "!proto": "Widget",
    "!doc": "A base class for `HSVPalette`.",
    "!url": "http://alloyui.com/classes/A.HSVPalette.html",
    "CSS_PREFIX": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the CSS prefix.",
     "!url": "http://alloyui.com/classes/A.HSVPalette.html#property_CSS_PREFIX"
    },
    "ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the `HSVPalette`.",
     "!url": "http://alloyui.com/classes/A.HSVPalette.html#property_ATTRS"
    },
    "prototype": {
     "controls": {
      "!type": "fn()",
      "!doc": "Determines if HSVA and RGB input `controls` are visible.",
      "!url": "http://alloyui.com/classes/A.HSVPalette.html#attribute_controls"
     },
     "fieldValidator": {
      "!type": "fn()",
      "!doc": "Collection of regular expressions used to validate field values.",
      "!url": "http://alloyui.com/classes/A.HSVPalette.html#attribute_fieldValidator"
     },
     "selected": {
      "!type": "fn()",
      "!doc": "Currently `selected` color value.",
      "!url": "http://alloyui.com/classes/A.HSVPalette.html#attribute_selected"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "Collection of strings used to label elements of the UI.",
      "!url": "http://alloyui.com/classes/A.HSVPalette.html#attribute_strings"
     }
    },
    "NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.HSVPalette.html#property_NAME"
    },
    "NS": {
     "!type": "string",
     "!doc": "The namespace of the plugin.",
     "!url": "http://alloyui.com/classes/A.HSVPalette.html#property_NS"
    }
   },
   "A.HSVAPaletteModal": {
    "!type": "fn(config: Object) -> +aui_color_picker.A.HSVAPaletteModal",
    "!proto": "aui_modal.A.Modal",
    "!doc": "A base class for HSVAPaletteModal.",
    "!url": "http://alloyui.com/classes/A.HSVAPaletteModal.html",
    "HSVAPaletteModal.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the HSVAPaletteModal.",
     "!url": "http://alloyui.com/classes/A.HSVAPaletteModal.html#property_HSVAPaletteModal.ATTRS"
    },
    "prototype": {
     "hsv": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HSVAPaletteModal.html#attribute_hsv"
     },
     "selected": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HSVAPaletteModal.html#attribute_selected"
     }
    },
    "HSVAPaletteModal.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.HSVAPaletteModal.html#property_HSVAPaletteModal.CSS_PREFIX"
    },
    "HSVAPaletteModal.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.HSVAPaletteModal.html#property_HSVAPaletteModal.NAME"
    },
    "HSVAPaletteModal.NS": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.HSVAPaletteModal.html#property_HSVAPaletteModal.NS"
    }
   },
   "A.HSVAPalette": {
    "!type": "fn(config: Object) -> +aui_color_picker.A.HSVAPalette",
    "!proto": "aui_color_picker.A.HSVPalette",
    "!doc": "A base class for HSVAPalette.",
    "!url": "http://alloyui.com/classes/A.HSVAPalette.html",
    "HSVAPalette.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.HSVAPalette.html#property_HSVAPalette.NAME"
    },
    "HSVAPalette.NS": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.HSVAPalette.html#property_HSVAPalette.NS"
    }
   },
   "ColorPicker": {
    "!type": "fn(config: Object) -> +aui_color_picker.ColorPicker",
    "!proto": "aui_overlay.OverlayContext",
    "!doc": "A base class for ColorPicker, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>ColorPicker utility</li>\n</ul>\n\nCheck the list of <a href=\"ColorPicker.html#configattributes\">Configuration Attributes</a> available for\nColorPicker.",
    "!url": "http://alloyui.com/classes/ColorPicker.html",
    "prototype": {
     "undefined": {
      "!type": "fn()",
      "!url": "http://alloyui.com/classes/ColorPicker.html"
     }
    },
    "ColorPicker.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/ColorPicker.html#property_ColorPicker.NAME"
    },
    "ColorPicker.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ColorPicker.",
     "!url": "http://alloyui.com/classes/ColorPicker.html#property_ColorPicker.ATTRS"
    }
   }
  },
  "aui_component": {
   "A.Component": {
    "!type": "fn(config: Object) -> +aui_component.A.Component",
    "!proto": "A.Widget",
    "!doc": "A base class for Component, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n</ul>",
    "!url": "http://alloyui.com/classes/A.Component.html",
    "prototype": {
     "clone": {
      "!type": "fn(config: Object) -> +Widget",
      "!doc": "Clone the current Component.",
      "!url": "http://alloyui.com/classes/A.Component.html#method_clone"
     },
     "useARIA": {
      "!type": "fn()",
      "!doc": "Boolean indicating if use of the WAI-ARIA Roles and States should be\nenabled for the Widget.",
      "!url": "http://alloyui.com/classes/A.Component.html#attribute_useARIA"
     },
     "hideClass": {
      "!type": "fn()",
      "!doc": "CSS class added to hide the <code>boundingBox</code> when\n<a href=\"Component.html#config_visible\">visible</a> is set to\n<code>false</code>.",
      "!url": "http://alloyui.com/classes/A.Component.html#attribute_hideClass"
     },
     "render": {
      "!type": "fn()",
      "!doc": "If <code>true</code> the render phase will be autimatically invoked\npreventing the <code>.render()</code> manual call.",
      "!url": "http://alloyui.com/classes/A.Component.html#attribute_render"
     },
     "getById": {
      "!type": "fn(id)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Component.html#method_getById"
     },
     "create": {
      "!type": "fn(config)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Component.html#method_create"
     },
     "build": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Component.html#method_build"
     }
    },
    "Component.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Component.",
     "!url": "http://alloyui.com/classes/A.Component.html#property_Component.ATTRS"
    },
    "Component._INSTANCES": {
     "!type": "+Object",
     "!doc": "Static property used to define the map to store Component instances by id.",
     "!url": "http://alloyui.com/classes/A.Component.html#property_Component._INSTANCES"
    },
    "Component.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.Component.html#property_Component.CSS_PREFIX"
    }
   },
   "A.CellEditorSupport": {
    "!type": "fn(config: Object) -> +aui_datatable.A.CellEditorSupport",
    "!doc": "An extension for A.DataTable to support Cell Editing.",
    "!url": "http://alloyui.com/classes/A.CellEditorSupport.html",
    "prototype": {
     "dataSource": {
      "!type": "fn()",
      "!doc": "The data source that results will be read from. This can either be\nan existing <a href=\"DataSource.html\">DataSource</a> object, or it can be a\nvalue that would be passed to <a href=\"DataSource.html\">DataSource</a>.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_dataSource"
     },
     "dataSourceType": {
      "!type": "fn()",
      "!doc": "The type of the data source passed into <a href=\"AutoComplete.html#config_dataSource\">dataSource</a>.\nThis can be used to explicitly declare what kind of <a href=\"DataSource.html\">DataSource</a> object will\nbe created.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_dataSourceType"
     },
     "schema": {
      "!type": "fn()",
      "!doc": "A valid configuration object for any of <a href=\"module_datasource.html\">DataSource</a> schema plugins.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_schema"
     },
     "schemaType": {
      "!type": "fn()",
      "!doc": "A valid type of <a href=\"module_datasource.html\">DataSource</a> schema plugin, such as array, json, xml, etc.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_schemaType"
     },
     "dataError": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the dataError event. Fired when there is an error accessing the data.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_dataError"
     },
     "dataRequest": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the dataRequest event. Fired when ever a query is sent to the data source.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_dataRequest"
     },
     "dataReturn": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the dataReturn event. Fired when data successfully comes back from the data request.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_dataReturn"
     },
     "button": {
      "!type": "fn()",
      "!doc": "To use a button",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_button"
     },
     "delimChar": {
      "!type": "fn()",
      "!doc": "The character used to indicate the beginning or ending of a new value. Most commonly used\nis a \",\".",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_delimChar"
     },
     "forceSelection": {
      "!type": "fn()",
      "!doc": "If <a href=\"AutoComplete.html#config_typeAhead\">typeAhead</a> is true, this\nwill clear a selection when the overlay closes unless a user explicitly selects an item.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_forceSelection"
     },
     "input": {
      "!type": "fn()",
      "!doc": "The input field which will recieve the users input.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_input"
     },
     "matchKey": {
      "!type": "fn()",
      "!doc": "The key or numeric index in the schema to match the result against.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_matchKey"
     },
     "minQueryLength": {
      "!type": "fn()",
      "!doc": "The minimum number of characters required to query the data source.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_minQueryLength"
     },
     "queryDelay": {
      "!type": "fn()",
      "!doc": "The amount of time in seconds to delay before submitting the query.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_queryDelay"
     },
     "queryInterval": {
      "!type": "fn()",
      "!doc": "When IME usage is detected or interval detection is explicitly enabled,\nAutoComplete will detect the input value at the given interval and send a\nquery if the value has changed.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_queryInterval"
     },
     "queryMatchCase": {
      "!type": "fn()",
      "!doc": "When <a href=\"AutoComplete.html#config_applyLocalFilter\">applyLocalFilter</a> is true,\nsetting this to true will match only results with the same case.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_queryMatchCase"
     },
     "queryMatchContains": {
      "!type": "fn()",
      "!doc": "When <a href=\"AutoComplete.html#config_applyLocalFilter\">applyLocalFilter</a> is true,\nsetting this to true will match results which contain the query anywhere in the text,\ninstead of just matching just items that start with the query.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_queryMatchContains"
     },
     "queryQuestionMark": {
      "!type": "fn()",
      "!doc": "For IO DataSources, AutoComplete will automatically insert a \"?\" between the server URI and\nthe encoded query string. To prevent this behavior, you can\nset this value to false. If you need to customize this even further, you\ncan override the <a href=\"AutoComplete.html#method_generateRequest\">generateRequest</a> method.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_queryQuestionMark"
     },
     "suppressInputUpdate": {
      "!type": "fn()",
      "!doc": "Whether or not the input field should be updated with selections.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_suppressInputUpdate"
     },
     "typeAhead": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the typeAhead event. Fired when the input element has been pre-filled by the type-ahead feature.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_typeAhead"
     },
     "typeAheadDelay": {
      "!type": "fn()",
      "!doc": "If <a href=\"AutoComplete.html#config_typeAhead\">typeAhead</a> is true, number of seconds\nto delay before updating the input. In order to prevent certain race conditions, this value must\nalways be greater than the <a href=\"AutoComplete.html#config_queryDelay\">queryDelay</a>.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_typeAheadDelay"
     },
     "uniqueName": {
      "!type": "fn()",
      "!doc": "The unique ID of the input element.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_uniqueName"
     },
     "containerCollapse": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the containerCollapse event. Fired when the container is hidden.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_containerCollapse"
     },
     "containerExpand": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the containerExpand event. Fired when the container is shown.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_containerExpand"
     },
     "containerPopulate": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the containerPopulate event. Fired when the container is populated.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_containerPopulate"
     },
     "itemArrowFrom": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the itemArrowFrom event. Fired when the user navigates via the keyboard away from\na selected item.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_itemArrowFrom"
     },
     "itemArrowTo": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the itemArrowTo event. Fired when the user navigates via the keyboard to a selected item.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_itemArrowTo"
     },
     "itemMouseOut": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the itemMouseOut event. Fired when the user mouses away from an item.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_itemMouseOut"
     },
     "itemMouseOver": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the itemMouseOver event. Fired when the user mouses over an item.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_itemMouseOver"
     },
     "itemSelect": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the itemSelect event. Fired when an item in the list is selected.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_itemSelect"
     },
     "selectionEnforce": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the selectionEnforce event. Fired if <a href=\"Autocomplete.html#config_forceSelection\">forceSelection</a>\nis enabled and the users input element has been cleared because it did not match one of the results.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_selectionEnforce"
     },
     "textboxBlur": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the textboxBlur event. Fired when the user leaves the input element.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_textboxBlur"
     },
     "textboxChange": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the textboxChange event. Fired when the value in the input element is changed.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_textboxChange"
     },
     "textboxFocus": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the textboxFocus event. Fired when user moves focus to the input element.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_textboxFocus"
     },
     "textboxKey": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the textboxKey event. Fired when the input element receives key input.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_textboxKey"
     },
     "unmatchedItemSelect": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the unmatchedItemSelect event. Fired when a user selects something that does\nnot match any of the displayed results.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#event_unmatchedItemSelect"
     },
     "doBeforeLoadData": {
      "!type": "fn(event: EventFacade) -> bool",
      "!doc": "An overridable method that is executed before the result overlay is loaded with results.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#method_doBeforeLoadData"
     },
     "formatResult": {
      "!type": "fn(result: Object, request: string, resultMatch: string) -> string",
      "!doc": "An overridable method for formatting the result of the query before it's displayed in the overlay.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#method_formatResult"
     },
     "generateRequest": {
      "!type": "fn(query: string) -> +Object",
      "!doc": "An overridable method that creates an object to be passed to the sendRequest\nmethod of the data source object. Useful to overwrite if you wish to create\na custom request object before it's sent.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#method_generateRequest"
     },
     "handleResponse": {
      "!type": "fn(event: EventFacade)",
      "!doc": "Handles the response for the display of the results. This is a callback method\nthat is fired by the sendRequest method so that results are ready to be accessed.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#method_handleResponse"
     }
    },
    "AutoComplete.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the AutoComplete.",
     "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#property_AutoComplete.ATTRS"
    }
   }
  },
  "aui_datatable": {
   "A.CellEditorSupport": {
    "!type": "fn(config: Object) -> +aui_datatable.A.CellEditorSupport",
    "!doc": "An extension for A.DataTable to support Cell Editing.",
    "!url": "http://alloyui.com/classes/A.CellEditorSupport.html",
    "CellEditorSupport.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#property_CellEditorSupport.NAME"
    },
    "CellEditorSupport.EDITOR_ZINDEX": {
     "!type": "number",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#property_CellEditorSupport.EDITOR_ZINDEX"
    },
    "CellEditorSupport.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the CellEditorSupport.",
     "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#property_CellEditorSupport.ATTRS"
    },
    "prototype": {
     "editEvent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#attribute_editEvent"
     },
     "getEditor": {
      "!type": "fn(record)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#method_getEditor"
     },
     "getCellEditor": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#method_getCellEditor"
     },
     "getRecordColumnValue": {
      "!type": "fn(record)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.CellEditorSupport.html#method_getRecordColumnValue"
     }
    }
   },
   "A.BaseCellEditor": {
    "!type": "fn(config: Object)",
    "!proto": "A.Overlay",
    "!doc": "Abstract class BaseCellEditor.",
    "!url": "http://alloyui.com/classes/A.BaseCellEditor.html",
    "BaseCellEditor.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#property_BaseCellEditor.NAME"
    },
    "BaseCellEditor.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the BaseCellEditor.",
     "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#property_BaseCellEditor.ATTRS"
    },
    "prototype": {
     "editable": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_editable"
     },
     "elementName": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_elementName"
     },
     "footerContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_footerContent"
     },
     "hideOnSave": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_hideOnSave"
     },
     "inputFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_inputFormatter"
     },
     "outputFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_outputFormatter"
     },
     "showToolbar": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_showToolbar"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_strings"
     },
     "tabIndex": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_tabIndex"
     },
     "toolbar": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_toolbar"
     },
     "unescapeValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_unescapeValue"
     },
     "validator": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_validator"
     },
     "value": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_value"
     },
     "visible": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#attribute_visible"
     },
     "formatValue": {
      "!type": "fn(formatter)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#method_formatValue"
     },
     "getValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#method_getValue"
     },
     "getElementsValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.\n\nNOTE FOR DEVELOPERS: Yoy *may* want to replace the methods from\nthis section on your implementation.",
      "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#method_getElementsValue"
     }
    },
    "BaseCellEditor.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#property_BaseCellEditor.EXTENDS"
    },
    "BaseCellEditor.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.BaseCellEditor.html#property_BaseCellEditor.UI_ATTRS"
    }
   },
   "A.BaseOptionsCellEditor": {
    "!type": "fn(config: Object)",
    "!proto": "aui_datatable.A.BaseCellEditor",
    "!doc": "Abstract class BaseOptionsCellEditor for options attribute support.",
    "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html",
    "BaseOptionsCellEditor.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#property_BaseOptionsCellEditor.NAME"
    },
    "BaseOptionsCellEditor.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the BaseOptionsCellEditor.",
     "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#property_BaseOptionsCellEditor.ATTRS"
    },
    "prototype": {
     "inputFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#attribute_inputFormatter"
     },
     "options": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#attribute_options"
     },
     "outputFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#attribute_outputFormatter"
     },
     "selectedAttrName": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#attribute_selectedAttrName"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#attribute_strings"
     },
     "addNewOption": {
      "!type": "fn(name)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#method_addNewOption"
     },
     "removeOption": {
      "!type": "fn(optionRow)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#method_removeOption"
     },
     "saveOptions": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#method_saveOptions"
     },
     "toggleEdit": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#method_toggleEdit"
     }
    },
    "BaseOptionsCellEditor.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#property_BaseOptionsCellEditor.EXTENDS"
    },
    "BaseOptionsCellEditor.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.BaseOptionsCellEditor.html#property_BaseOptionsCellEditor.UI_ATTRS"
    }
   },
   "A.TextCellEditor": {
    "!type": "fn(config: Object) -> +aui_datatable.A.TextCellEditor",
    "!proto": "aui_datatable.A.BaseCellEditor",
    "!doc": "TextCellEditor class.",
    "!url": "http://alloyui.com/classes/A.TextCellEditor.html",
    "TextCellEditor.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TextCellEditor.html#property_TextCellEditor.NAME"
    },
    "TextCellEditor.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.TextCellEditor.html#property_TextCellEditor.EXTENDS"
    }
   },
   "A.TextAreaCellEditor": {
    "!type": "fn(config: Object) -> +aui_datatable.A.TextAreaCellEditor",
    "!doc": "TextAreaCellEditor class.",
    "!url": "http://alloyui.com/classes/A.TextAreaCellEditor.html",
    "TextAreaCellEditor.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TextAreaCellEditor.html#property_TextAreaCellEditor.NAME"
    },
    "TextAreaCellEditor.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.TextAreaCellEditor.html#property_TextAreaCellEditor.EXTENDS"
    }
   },
   "A.DropDownCellEditor": {
    "!type": "fn(config: Object) -> +aui_datatable.A.DropDownCellEditor",
    "!doc": "DropDownCellEditor class.",
    "!url": "http://alloyui.com/classes/A.DropDownCellEditor.html",
    "DropDownCellEditor.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DropDownCellEditor.html#property_DropDownCellEditor.NAME"
    },
    "DropDownCellEditor.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DropDownCellEditor.",
     "!url": "http://alloyui.com/classes/A.DropDownCellEditor.html#property_DropDownCellEditor.ATTRS"
    },
    "prototype": {
     "multiple": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DropDownCellEditor.html#attribute_multiple"
     },
     "getElementsValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DropDownCellEditor.html#method_getElementsValue"
     }
    },
    "DropDownCellEditor.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DropDownCellEditor.html#property_DropDownCellEditor.EXTENDS"
    },
    "DropDownCellEditor.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DropDownCellEditor.html#property_DropDownCellEditor.UI_ATTRS"
    }
   },
   "A.CheckboxCellEditor": {
    "!type": "fn(config: Object) -> +aui_datatable.A.CheckboxCellEditor",
    "!doc": "CheckboxCellEditor class.",
    "!url": "http://alloyui.com/classes/A.CheckboxCellEditor.html",
    "CheckboxCellEditor.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.CheckboxCellEditor.html#property_CheckboxCellEditor.NAME"
    },
    "CheckboxCellEditor.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the CheckboxCellEditor.",
     "!url": "http://alloyui.com/classes/A.CheckboxCellEditor.html#property_CheckboxCellEditor.ATTRS"
    },
    "prototype": {
     "selectedAttrName": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.CheckboxCellEditor.html#attribute_selectedAttrName"
     },
     "getElementsValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.CheckboxCellEditor.html#method_getElementsValue"
     }
    },
    "CheckboxCellEditor.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.CheckboxCellEditor.html#property_CheckboxCellEditor.EXTENDS"
    }
   },
   "A.RadioCellEditor": {
    "!type": "fn(config: Object) -> +aui_datatable.A.RadioCellEditor",
    "!doc": "RadioCellEditor class.",
    "!url": "http://alloyui.com/classes/A.RadioCellEditor.html",
    "RadioCellEditor.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.RadioCellEditor.html#property_RadioCellEditor.NAME"
    },
    "RadioCellEditor.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.RadioCellEditor.html#property_RadioCellEditor.EXTENDS"
    },
    "prototype": {
     "getElementsValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.RadioCellEditor.html#method_getElementsValue"
     }
    }
   },
   "A.DateCellEditor": {
    "!type": "fn(config: Object) -> +aui_datatable.A.DateCellEditor",
    "!doc": "DateCellEditor class.",
    "!url": "http://alloyui.com/classes/A.DateCellEditor.html",
    "DateCellEditor.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DateCellEditor.html#property_DateCellEditor.NAME"
    },
    "DateCellEditor.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DateCellEditor.html#property_DateCellEditor.EXTENDS"
    },
    "DateCellEditor.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DateCellEditor.",
     "!url": "http://alloyui.com/classes/A.DateCellEditor.html#property_DateCellEditor.ATTRS"
    },
    "prototype": {
     "bodyContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DateCellEditor.html#attribute_bodyContent"
     },
     "calendar": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DateCellEditor.html#attribute_calendar"
     },
     "dateFormat": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DateCellEditor.html#attribute_dateFormat"
     },
     "inputFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DateCellEditor.html#attribute_inputFormatter"
     },
     "outputFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DateCellEditor.html#attribute_outputFormatter"
     },
     "getElementsValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DateCellEditor.html#method_getElementsValue"
     },
     "formatDate": {
      "!type": "fn(date)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DateCellEditor.html#method_formatDate"
     }
    }
   },
   "A.DataTableHighlight": {
    "!type": "fn(config: Object) -> +aui_datatable.A.DataTableHighlight",
    "!proto": "A.Plugin.Base",
    "!doc": "A base class for DataTableHighlight.",
    "!url": "http://alloyui.com/classes/A.DataTableHighlight.html",
    "prototype": {
     "clear": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#method_clear"
     },
     "getActiveRegion": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#method_getActiveRegion"
     },
     "getSelectionRegion": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#method_getSelectionRegion"
     },
     "activeBorderWidth": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#attribute_activeBorderWidth"
     },
     "overlayActiveNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#attribute_overlayActiveNode"
     },
     "overlayNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#attribute_overlayNode"
     },
     "highlightRange": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#attribute_highlightRange"
     },
     "rangeBorderWidth": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#attribute_rangeBorderWidth"
     },
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#attribute_type"
     }
    },
    "DataTableHighlight.NS": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#property_DataTableHighlight.NS"
    },
    "DataTableHighlight.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#property_DataTableHighlight.NAME"
    },
    "DataTableHighlight.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DataTableHighlight.",
     "!url": "http://alloyui.com/classes/A.DataTableHighlight.html#property_DataTableHighlight.ATTRS"
    }
   },
   "A.PropertyList": {
    "!type": "fn(config: Object) -> +aui_datatable.A.PropertyList",
    "!proto": "A.DataTable",
    "!doc": "A base class for PropertyList.",
    "!url": "http://alloyui.com/classes/A.PropertyList.html",
    "prototype": {
     "getDefaultEditor": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.PropertyList.html#method_getDefaultEditor"
     },
     "columns": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.PropertyList.html#attribute_columns"
     },
     "scrollable": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.PropertyList.html#attribute_scrollable"
     },
     "editEvent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.PropertyList.html#attribute_editEvent"
     },
     "width": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.\n\nDataTable scroll breaks when width value is a number\nSee http://yuilibrary.com/projects/yui3/ticket/2532600",
      "!url": "http://alloyui.com/classes/A.PropertyList.html#attribute_width"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.PropertyList.html#attribute_strings"
     }
    },
    "PropertyList.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.PropertyList.html#property_PropertyList.CSS_PREFIX"
    },
    "PropertyList.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the PropertyList.",
     "!url": "http://alloyui.com/classes/A.PropertyList.html#property_PropertyList.ATTRS"
    }
   },
   "A.DataTableSelection": {
    "!type": "fn(config: Object) -> +aui_datatable.A.DataTableSelection",
    "!doc": "A base class for DataTableSelection.",
    "!url": "http://alloyui.com/classes/A.DataTableSelection.html",
    "DataTableSelection.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DataTableSelection.",
     "!url": "http://alloyui.com/classes/A.DataTableSelection.html#property_DataTableSelection.ATTRS"
    },
    "prototype": {
     "activeCell": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#attribute_activeCell"
     },
     "activeCoord": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#attribute_activeCoord"
     },
     "activeRow": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#attribute_activeRow"
     },
     "selection": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#attribute_selection"
     },
     "tabIndex": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#attribute_tabIndex"
     },
     "captureSelection": {
      "!type": "fn(coords)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#method_captureSelection"
     },
     "getActiveColumn": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#method_getActiveColumn"
     },
     "getActiveRecord": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#method_getActiveRecord"
     },
     "getCoord": {
      "!type": "fn(seed)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#method_getCoord"
     },
     "getColumn": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#method_getColumn"
     },
     "getRow": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.\n\nAdd support to get a row by seed on DataTable getRow\nSee http://yuilibrary.com/projects/yui3/ticket/2532605",
      "!url": "http://alloyui.com/classes/A.DataTableSelection.html#method_getRow"
     }
    }
   }
  },
  "aui_datatype_date_parse": {
   "A.DateParser": {
    "!type": "fn(opt_pattern: string) -> +aui_datatype_date_parse.A.DateParser",
    "!doc": "A base class for DateParser.",
    "!url": "http://alloyui.com/classes/A.DateParser.html",
    "DateParser.TOKEN_PREFIX": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the token prefix, e.g. %A.",
     "!url": "http://alloyui.com/classes/A.DateParser.html#property_DateParser.TOKEN_PREFIX"
    },
    "DateParser.TWO_DIGIT_YEAR_BASE": {
     "!type": "number",
     "!doc": "Static property provides a base year to sum two digit years, e.g. For the\nmask %Y, \"13\" will be parsed to 2013.",
     "!url": "http://alloyui.com/classes/A.DateParser.html#property_DateParser.TWO_DIGIT_YEAR_BASE"
    },
    "prototype": {
     "compilePattern": {
      "!type": "fn(pattern: string)",
      "!doc": "\"Compiles\" the strftime pattern. The same DateParser instance can be\nreused to other \"compiled\" masks.",
      "!url": "http://alloyui.com/classes/A.DateParser.html#method_compilePattern"
     }
    }
   },
   "Date": {
    "!type": "fn()",
    "!url": "http://alloyui.com/classes/Date.html",
    "prototype": {
     "parse": {
      "!type": "fn(mask: string, text: string, opt_date: aui_datatype_date_parse.Date) -> +aui_datatype_date_parse.Date",
      "!doc": "Takes a string mask and a text as input and parses it as a native JavaScript Date.",
      "!url": "http://alloyui.com/classes/Date.html#method_parse"
     }
    },
    "DateParser.HINTS": {
     "!type": "+Object",
     "!doc": "Static property provides an object that contains hints information for\npossible token values, e.g. year, month, day etc.",
     "!url": "http://alloyui.com/classes/Date.html#property_DateParser.HINTS"
    },
    "DateParser.HINTS.AGGREGATES": {
     "!type": "+Object",
     "!doc": "Static property provides an object that contains hints information for\naggregates tokens.",
     "!url": "http://alloyui.com/classes/Date.html#property_DateParser.HINTS.AGGREGATES"
    },
    "DateParser.HINTS.AMPM": {
     "!type": "+Object",
     "!doc": "Static property provides an object that contains hints information for\nampm tokens.",
     "!url": "http://alloyui.com/classes/Date.html#property_DateParser.HINTS.AMPM"
    },
    "DateParser.HINTS.YEAR": {
     "!type": "+Object",
     "!doc": "Static property provides an object that contains hints information for\nyear tokens.",
     "!url": "http://alloyui.com/classes/Date.html#property_DateParser.HINTS.YEAR"
    },
    "DateParser.HINTS.MONTH": {
     "!type": "+Object",
     "!doc": "Static property provides an object that contains hints information for\nmonth tokens.",
     "!url": "http://alloyui.com/classes/Date.html#property_DateParser.HINTS.MONTH"
    },
    "DateParser.HINTS.DAY": {
     "!type": "+Object",
     "!doc": "Static property provides an object that contains hints information for\nday tokens.",
     "!url": "http://alloyui.com/classes/Date.html#property_DateParser.HINTS.DAY"
    },
    "DateParser.HINTS.HOURS": {
     "!type": "+Object",
     "!doc": "Static property provides an object that contains hints information for\nhours tokens.",
     "!url": "http://alloyui.com/classes/Date.html#property_DateParser.HINTS.HOURS"
    },
    "DateParser.HINTS.MINUTES": {
     "!type": "+Object",
     "!doc": "Static property provides an object that contains hints information for\nminutes tokens.",
     "!url": "http://alloyui.com/classes/Date.html#property_DateParser.HINTS.MINUTES"
    },
    "DateParser.HINTS.SECONDS": {
     "!type": "+Object",
     "!doc": "Static property provides an object that contains hints information for\nseconds tokens.",
     "!url": "http://alloyui.com/classes/Date.html#property_DateParser.HINTS.SECONDS"
    },
    "DateParser.HINTS.TZ": {
     "!type": "+Object",
     "!doc": "Static property provides an object that contains hints information for\ntimezone tokens.",
     "!url": "http://alloyui.com/classes/Date.html#property_DateParser.HINTS.TZ"
    }
   },
   "A.Date": {
    "!type": "fn()",
    "!url": "http://alloyui.com/classes/A.Date.html",
    "parse": {
     "!type": "fn(mask: string, text: string, opt_date: aui_datatype_date_parse.Date) -> +aui_datatype_date_parse.Date",
     "!doc": "Takes a string mask and a text as input and parses it as a native JavaScript Date.\n**If only one argument is passed**, the YUI parser will be called for backwards compatibility.",
     "!url": "http://alloyui.com/classes/A.Date.html#method_parse"
    }
   }
  },
  "aui_datatype": {
   "DataType.Boolean": {
    "!type": "fn()",
    "!doc": "DataType.Boolean provides a set of utility to parse <code>falsey</code>\nvalue to <code>false</code> and <code>non-falsey</code> to\n<code>true</code>.",
    "!url": "http://alloyui.com/classes/DataType.Boolean.html",
    "prototype": {
     "parse": {
      "!type": "fn(data: ?) -> bool",
      "!doc": "Parses any <code>falsey</code> value to <code>false</code> and\n<code>non-falsey</code> to <code>true</code>.",
      "!url": "http://alloyui.com/classes/DataType.Boolean.html#method_parse"
     }
    }
   },
   "DataType.String": {
    "!type": "fn()",
    "!doc": "DataType.String provides a set of utility to provides a simple function\nthat evaluates a string to a primitive value (if possible). Supports\n<code>true</code> and <code>false</code> also.",
    "!url": "http://alloyui.com/classes/DataType.String.html",
    "prototype": {
     "evaluate": {
      "!type": "fn(data: ?) -> bool",
      "!doc": "Evaluates a string to a primitive value (if possible). Supports\n<code>true</code> and <code>false</code> also. Unrecognized strings are\nreturned without any modification.",
      "!url": "http://alloyui.com/classes/DataType.String.html#method_evaluate"
     }
    }
   },
   "A.DataType.DateMath": {
    "!type": "fn()",
    "!doc": "A.DataType.DateMath is used for simple date manipulation. The class is a static utility\nused for adding, subtracting, and comparing dates. Based on YAHOO.widget.DateMath.",
    "!url": "http://alloyui.com/classes/A.DataType.DateMath.html",
    "DAY": {
     "!type": "string",
     "!doc": "Constant field representing Day.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_DAY"
    },
    "WEEK": {
     "!type": "string",
     "!doc": "Constant field representing Week.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_WEEK"
    },
    "YEAR": {
     "!type": "string",
     "!doc": "Constant field representing Year.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_YEAR"
    },
    "MONTH": {
     "!type": "string",
     "!doc": "Constant field representing Month.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_MONTH"
    },
    "MINUTES": {
     "!type": "string",
     "!doc": "Constant field representing Minutes.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_MINUTES"
    },
    "HOUR": {
     "!type": "string",
     "!doc": "Constant field representing Hour.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_HOUR"
    },
    "SECONDS": {
     "!type": "string",
     "!doc": "Constant field representing Seconds.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_SECONDS"
    },
    "MAX_MONTH_LENGTH": {
     "!type": "number",
     "!doc": "Constant field representing the number of maximum days in a month.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_MAX_MONTH_LENGTH"
    },
    "WEEK_LENGTH": {
     "!type": "number",
     "!doc": "Constant field representing the number of maximum days in a week.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_WEEK_LENGTH"
    },
    "ONE_DAY_MS": {
     "!type": "number",
     "!doc": "Constant field representing one day, in milliseconds.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_ONE_DAY_MS"
    },
    "ONE_HOUR_MS": {
     "!type": "number",
     "!doc": "Constant field representing one hour, in milliseconds.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_ONE_HOUR_MS"
    },
    "ONE_MINUTE_MS": {
     "!type": "number",
     "!doc": "Constant field representing one minute, in milliseconds.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_ONE_MINUTE_MS"
    },
    "ONE_SECOND_MS": {
     "!type": "number",
     "!doc": "Constant field representing one second, in milliseconds.",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_ONE_SECOND_MS"
    },
    "WEEK_ONE_JAN_DATE": {
     "!type": "number",
     "!doc": "Constant field representing the date in first week of January\nwhich identifies the first week of the year.\n<p>\nIn the U.S, Jan 1st is normally used based on a Sunday start of week.\nISO 8601, used widely throughout Europe, uses Jan 4th, based on a Monday start of week.\n</p>",
     "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#property_WEEK_ONE_JAN_DATE"
    },
    "prototype": {
     "add": {
      "!type": "fn(date: aui_datatype_date_parse.Date, field: string, amount: number) -> +aui_datatype_date_parse.Date",
      "!doc": "Adds the specified amount of time to the this instance.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_add"
     },
     "compare": {
      "!type": "fn(d1: aui_datatype_date_parse.Date, d2: aui_datatype_date_parse.Date) -> bool",
      "!doc": "Compare dates.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_compare"
     },
     "copyHours": {
      "!type": "fn(d1, d2)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_copyHours"
     },
     "subtract": {
      "!type": "fn(date: aui_datatype_date_parse.Date, field: number, amount: number) -> +aui_datatype_date_parse.Date",
      "!doc": "Subtract the specified amount of time from the this instance.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_subtract"
     },
     "before": {
      "!type": "fn(date: aui_datatype_date_parse.Date, compareTo: aui_datatype_date_parse.Date) -> bool",
      "!doc": "Determine whether a given date is before another date on the calendar.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_before"
     },
     "after": {
      "!type": "fn(date: aui_datatype_date_parse.Date, compareTo: aui_datatype_date_parse.Date) -> bool",
      "!doc": "Determine whether a given date is after another date on the calendar.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_after"
     },
     "between": {
      "!type": "fn(date: aui_datatype_date_parse.Date, dateBegin: aui_datatype_date_parse.Date, dateEnd: aui_datatype_date_parse.Date) -> bool",
      "!doc": "Determine whether a given date is between two other dates on the calendar.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_between"
     },
     "getJan1": {
      "!type": "fn(calendarYear: number) -> +aui_datatype_date_parse.Date",
      "!doc": "Retrieve a JavaScript Date object representing January 1 of any given year.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_getJan1"
     },
     "getDayOffset": {
      "!type": "fn(d1: aui_datatype_date_parse.Date, d2: aui_datatype_date_parse.Date) -> number",
      "!doc": "Calculate the number of days between the specified dates.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_getDayOffset"
     },
     "getHoursOffset": {
      "!type": "fn(d1: aui_datatype_date_parse.Date, d2: aui_datatype_date_parse.Date) -> number",
      "!doc": "Calculate the number of hours between the specified dates.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_getHoursOffset"
     },
     "getMinutesOffset": {
      "!type": "fn(d1: aui_datatype_date_parse.Date, d2: aui_datatype_date_parse.Date) -> number",
      "!doc": "Calculate the number of minutes between the specified dates.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_getMinutesOffset"
     },
     "getSecondsOffset": {
      "!type": "fn(d1: aui_datatype_date_parse.Date, d2: aui_datatype_date_parse.Date) -> number",
      "!doc": "Calculate the number of seconds between the specified dates.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_getSecondsOffset"
     },
     "getOffset": {
      "!type": "fn(d1, d2, constantAmount)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_getOffset"
     },
     "getWeekNumber": {
      "!type": "fn(date: aui_datatype_date_parse.Date, firstDayOfWeek: number, janDate: number) -> number",
      "!doc": "Calculate the week number for the given date. Can currently support standard\nU.S. week numbers, based on Jan 1st defining the 1st week of the year, and\nISO8601 week numbers, based on Jan 4th defining the 1st week of the year.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_getWeekNumber"
     },
     "getFirstDayOfWeek": {
      "!type": "fn(dt: aui_datatype_date_parse.Date, startOfWeek: number) -> +aui_datatype_date_parse.Date",
      "!doc": "Get the first day of the week, for the give date.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_getFirstDayOfWeek"
     },
     "isWeekDay": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> ?",
      "!doc": "Check if the passed date is a week day.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_isWeekDay"
     },
     "isTueOrThu": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> ?",
      "!doc": "Check if the passed date is a Tuesday or Thursday.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_isTueOrThu"
     },
     "isMonWedOrFri": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> ?",
      "!doc": "Check if the passed date is a Monday, Wednesday or Friday.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_isMonWedOrFri"
     },
     "isNextDay": {
      "!type": "fn(date1: aui_datatype_date_parse.Date, date2: aui_datatype_date_parse.Date) -> ?",
      "!doc": "Check if the {date2} is the next day.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_isNextDay"
     },
     "isNextDayBoundary": {
      "!type": "fn(date1: aui_datatype_date_parse.Date, date2: aui_datatype_date_parse.Date) -> ?",
      "!doc": "Check if the {date2} is the next day at 00:00:00.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_isNextDayBoundary"
     },
     "isDayOverlap": {
      "!type": "fn(date1: aui_datatype_date_parse.Date, date2: aui_datatype_date_parse.Date) -> ?",
      "!doc": "Check if the passed date is between two days.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_isDayOverlap"
     },
     "isToday": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> ?",
      "!doc": "Check if the passed date is today.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_isToday"
     },
     "isSameMonth": {
      "!type": "fn(d1: aui_datatype_date_parse.Date, d2: aui_datatype_date_parse.Date) -> ?",
      "!doc": "Check if the passed dates are in the same month.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_isSameMonth"
     },
     "isYearOverlapWeek": {
      "!type": "fn(weekBeginDate: aui_datatype_date_parse.Date) -> bool",
      "!doc": "Determine if a given week overlaps two different years.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_isYearOverlapWeek"
     },
     "isMonthOverlapWeek": {
      "!type": "fn(weekBeginDate: aui_datatype_date_parse.Date) -> bool",
      "!doc": "Determine if a given week overlaps two different months.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_isMonthOverlapWeek"
     },
     "findMonthStart": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> +aui_datatype_date_parse.Date",
      "!doc": "Get the first day of a month containing a given date.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_findMonthStart"
     },
     "findMonthEnd": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> +aui_datatype_date_parse.Date",
      "!doc": "Get the last day of a month containing a given date.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_findMonthEnd"
     },
     "clearTime": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> +aui_datatype_date_parse.Date",
      "!doc": "Clear the time fields from a given date, effectively setting the time to 12 noon.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_clearTime"
     },
     "safeClearTime": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> +aui_datatype_date_parse.Date",
      "!doc": "Clear the time fields from a given date, effectively setting the time to\n12 noon. This is \"safe\" because clones the date before clear, not affecting\nthe passed reference.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_safeClearTime"
     },
     "toLastHour": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> +aui_datatype_date_parse.Date",
      "!doc": "Set the time fields from a given date to the last possible hour.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_toLastHour"
     },
     "toMidnight": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> +aui_datatype_date_parse.Date",
      "!doc": "Set the time fields from a given date to midnight.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_toMidnight"
     },
     "clone": {
      "!type": "fn(date: aui_datatype_date_parse.Date) -> +aui_datatype_date_parse.Date",
      "!doc": "Clone the passed date object.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_clone"
     },
     "getDate": {
      "!type": "fn(y: number, m: number, d: number) -> +aui_datatype_date_parse.Date",
      "!doc": "Return a new JavaScript Date object, representing the given year,\nmonth and date.Time fields (hr, min, sec, ms) on the new Date object\nare set to 0. The method allows Date instances to be created with the a\nyear less than 100. \"new Date(year, month, date)\" implementations\nset the year to 19xx if a year (xx) which is less than 100 is provided.\n\n<em>NOTE:</em>Validation on argument values is not performed. It is the\ncaller's responsibility to ensure arguments are valid as per the\nECMAScript-262 Date object specification for the\nnew Date(year, month[, date]) constructor.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_getDate"
     },
     "getDaysInMonth": {
      "!type": "fn(year, month)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_getDaysInMonth"
     },
     "toUsTimeString": {
      "!type": "fn(date, padHours, omitMinutes, hideAmPm)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_toUsTimeString"
     },
     "toIsoTimeString": {
      "!type": "fn(date, showSeconds)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DataType.DateMath.html#method_toIsoTimeString"
     }
    }
   }
  },
  "aui_datepicker": {
   "A.DatePickerDelegate": {
    "!type": "fn(config: Object) -> +aui_datepicker.A.DatePickerDelegate",
    "!doc": "A base class for DatePickerDelegate.",
    "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html",
    "prototype": {
     "getSelectedDates": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#method_getSelectedDates"
     },
     "getParsedDatesFromInputValue": {
      "!type": "fn(opt_value)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#method_getParsedDatesFromInputValue"
     },
     "useInputNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#method_useInputNode"
     },
     "useInputNodeOnce": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#method_useInputNodeOnce"
     },
     "activeInput": {
      "!type": "fn()",
      "!doc": "The active input element that holds the calendar instance.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#attribute_activeInput"
     },
     "container": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#attribute_container"
     },
     "dateSeparator": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#attribute_dateSeparator"
     },
     "mask": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#attribute_mask"
     },
     "content": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#attribute_content"
     },
     "valueExtractor": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#attribute_valueExtractor"
     },
     "valueFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#attribute_valueFormatter"
     }
    },
    "DatePickerDelegate.ATTRS": {
     "!type": "+Object",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DatePickerDelegate.html#property_DatePickerDelegate.ATTRS"
    }
   },
   "A.DatePickerNativeBase": {
    "!type": "fn(config: Object) -> +aui_datepicker.A.DatePickerNativeBase",
    "!doc": "A base class for DatePickerNativeBase.",
    "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html",
    "DatePickerNativeBase.ATTRS": {
     "!type": "+Object",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html#property_DatePickerNativeBase.ATTRS"
    },
    "prototype": {
     "nativeMask": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html#attribute_nativeMask"
     },
     "nativeType": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html#attribute_nativeType"
     },
     "bindNativeUI": {
      "!type": "fn()",
      "!doc": "Bind the events on the DatePickerNativeBase UI. Lifecycle.",
      "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html#method_bindNativeUI"
     },
     "clearSelection": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html#method_clearSelection"
     },
     "deselectDates": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html#method_deselectDates"
     },
     "hide": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html#method_hide"
     },
     "show": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html#method_show"
     },
     "selectDates": {
      "!type": "fn(dates)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html#method_selectDates"
     },
     "useInputNode": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerNativeBase.html#method_useInputNode"
     }
    }
   },
   "A.DatePickerPopover": {
    "!type": "fn(config: Object) -> +aui_datepicker.A.DatePickerPopover",
    "!doc": "A base class for DatePickerPopover.",
    "!url": "http://alloyui.com/classes/A.DatePickerPopover.html",
    "DatePickerPopover.ATTRS": {
     "!type": "+Object",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DatePickerPopover.html#property_DatePickerPopover.ATTRS"
    },
    "prototype": {
     "autoHide": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerPopover.html#attribute_autoHide"
     },
     "popover": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerPopover.html#attribute_popover"
     },
     "popoverCssClass": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerPopover.html#attribute_popoverCssClass"
     },
     "alignTo": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerPopover.html#method_alignTo"
     },
     "getPopover": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerPopover.html#method_getPopover"
     },
     "hide": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerPopover.html#method_hide"
     },
     "show": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerPopover.html#method_show"
     }
    }
   },
   "A.DatePickerBase": {
    "!type": "fn(config: Object) -> +aui_datepicker.A.DatePickerBase",
    "!doc": "A base class for DatePickerBase.",
    "!url": "http://alloyui.com/classes/A.DatePickerBase.html",
    "DatePickerBase.PANES": {
     "!type": "+Array",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DatePickerBase.",
     "!url": "http://alloyui.com/classes/A.DatePickerBase.html#property_DatePickerBase.PANES"
    },
    "DatePickerBase.ATTRS": {
     "!type": "+Object",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DatePickerBase.html#property_DatePickerBase.ATTRS"
    },
    "prototype": {
     "calendar": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerBase.html#attribute_calendar"
     },
     "autoHide": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerBase.html#attribute_autoHide"
     },
     "panes": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerBase.html#attribute_panes"
     },
     "clearSelection": {
      "!type": "fn(silent)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerBase.html#method_clearSelection"
     },
     "deselectDates": {
      "!type": "fn(dates)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerBase.html#method_deselectDates"
     },
     "getCalendar": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerBase.html#method_getCalendar"
     },
     "selectDates": {
      "!type": "fn(dates)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerBase.html#method_selectDates"
     },
     "useInputNode": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DatePickerBase.html#method_useInputNode"
     }
    }
   },
   "DatepickerManager": {
    "!type": "fn(config: Object) -> +aui_datepicker.DatepickerManager",
    "!proto": "aui_overlay.OverlayManager",
    "!doc": "A base class for DatepickerManager:",
    "!url": "http://alloyui.com/classes/DatepickerManager.html",
    "prototype": {
     "calendar": {
      "!type": "fn()",
      "!doc": "<a href=\"Calendar.html\">Calendar</a> configuration Object.</a>",
      "!url": "http://alloyui.com/classes/DatepickerManager.html#attribute_calendar"
     },
     "formatter": {
      "!type": "fn()",
      "!doc": "Function to format the array of the selected dates before set the\nvalue of the input.",
      "!url": "http://alloyui.com/classes/DatepickerManager.html#attribute_formatter"
     },
     "setValue": {
      "!type": "fn()",
      "!doc": "If true set the selected date with the correct\ndateFormat to the value of the input field\nwhich is hosting the Calendar.",
      "!url": "http://alloyui.com/classes/DatepickerManager.html#attribute_setValue"
     },
     "stack": {
      "!type": "fn()",
      "!doc": "If true is able to do stacking with another overlays.",
      "!url": "http://alloyui.com/classes/DatepickerManager.html#attribute_stack"
     },
     "zIndexBase": {
      "!type": "fn()",
      "!doc": "ZIndex default value passed to the\n<a href=\"OverlayManager.html#config_zIndexBase\">zIndexBase</a> of\n<a href=\"OverlayManager.html\">OverlayManager</a>.",
      "!url": "http://alloyui.com/classes/DatepickerManager.html#attribute_zIndexBase"
     },
     "dateFormat": {
      "!type": "fn()",
      "!doc": "The default date format string which can be overriden for\nlocalization support. The format must be valid according to\n<a href=\"DataType.Date.html\">A.DataType.Date.format</a>.",
      "!url": "http://alloyui.com/classes/DatepickerManager.html#attribute_dateFormat"
     }
    }
   },
   "DatePickerSelect": {
    "!type": "fn(config: Object) -> +aui_datepicker.DatePickerSelect",
    "!proto": "Component",
    "!doc": "<p><img src=\"assets/images/aui-calendar-datepicker-select/main.png\"/></p>\n\nA base class for DatePickerSelect, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Select a date from Calendar to select elements</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var instance = new A.DatePickerSelect({\n srcNode: '#srcNodeId',\n calendar: {\n     // locale: 'pt-br',\n     dateFormat: '%m/%d/%y',\n     yearRange: [ 1970, 2009 ]\n\t}\n}).render();\n</code></pre>\n\nCheck the list of <a href=\"DatePickerSelect.html#configattributes\">Configuration Attributes</a> available for\nDatePickerSelect.",
    "!url": "http://alloyui.com/classes/DatePickerSelect.html",
    "DatePickerSelect.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/DatePickerSelect.html#property_DatePickerSelect.NAME"
    },
    "DatePickerSelect.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DatePickerSelect.",
     "!url": "http://alloyui.com/classes/DatePickerSelect.html#property_DatePickerSelect.ATTRS"
    },
    "prototype": {
     "appendOrder": {
      "!type": "fn()",
      "!doc": "The order the selects elements are appended to the\n<a href=\"DatePickerSelect.html#config_srcNode\">srcNode</a>.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_appendOrder"
     },
     "buttonNode": {
      "!type": "fn()",
      "!doc": "DOM Node to display the button of the DatePickerSelect. If not\nspecified try to query using HTML_PARSER an element inside\ncontentBox which matches <code>aui-buttonitem</code>.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_buttonNode"
     },
     "calendar": {
      "!type": "fn()",
      "!doc": "<a href=\"Calendar.html\">Calendar</a> configuration Object.</a>",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_calendar"
     },
     "dayNode": {
      "!type": "fn()",
      "!doc": "DOM Node to display the day of the DatePickerSelect. If not\nspecified try to query using HTML_PARSER an element inside\ncontentBox which matches <code>aui-datepicker-year</code>.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_dayNode"
     },
     "dayNodeName": {
      "!type": "fn()",
      "!doc": "Name attribute used on the\n<a href=\"DatePickerSelect.html#config_dayNode\">dayNode</a>.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_dayNodeName"
     },
     "locale": {
      "!type": "fn()",
      "!doc": "Current locale",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_locale"
     },
     "monthNode": {
      "!type": "fn()",
      "!doc": "DOM Node to display the month of the DatePickerSelect. If not\nspecified try to query using HTML_PARSER an element inside\ncontentBox which matches <code>aui-datepicker-year</code>.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_monthNode"
     },
     "monthNodeName": {
      "!type": "fn()",
      "!doc": "Name attribute used on the\n<a href=\"DatePickerSelect.html#config_monthNode\">monthNode</a>.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_monthNodeName"
     },
     "nullableDay": {
      "!type": "fn()",
      "!doc": "If true the select element for the day will be nullable",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_nullableDay"
     },
     "nullableMonth": {
      "!type": "fn()",
      "!doc": "If true the select element for the month will be nullable",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_nullableMonth"
     },
     "nullableYear": {
      "!type": "fn()",
      "!doc": "If true the select element for the year will be nullable",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_nullableYear"
     },
     "populateDay": {
      "!type": "fn()",
      "!doc": "If true the select element for the days will be automatic\npopulated.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_populateDay"
     },
     "populateMonth": {
      "!type": "fn()",
      "!doc": "If true the select element for the month will be automatic\npopulated.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_populateMonth"
     },
     "populateYear": {
      "!type": "fn()",
      "!doc": "If true the select element for the year will be automatic\npopulated.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_populateYear"
     },
     "selectWrapperNode": {
      "!type": "fn()",
      "!doc": "DOM Node to display the selects of the DatePickerSelect. If not\nspecified try to query using HTML_PARSER an element inside\ncontentBox which matches <code>aui-datepicker-select-wrapper</code>.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_selectWrapperNode"
     },
     "trigger": {
      "!type": "fn()",
      "!doc": "Trigger element to open the calendar. Inherited from\n<a href=\"OverlayContext.html#config_trigger\">OverlayContext</a>.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_trigger"
     },
     "yearNode": {
      "!type": "fn()",
      "!doc": "DOM Node to display the year of the DatePickerSelect. If not\nspecified try to query using HTML_PARSER an element inside\ncontentBox which matches <code>aui-datepicker-year</code>.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_yearNode"
     },
     "yearNodeName": {
      "!type": "fn()",
      "!doc": "Name attribute used on the\n<a href=\"DatePickerSelect.html#config_yearNode\">yearNode</a>.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_yearNodeName"
     },
     "yearRange": {
      "!type": "fn()",
      "!doc": "Year range to be displayed on the year select element. By default\nit displays from -10 to +10 years from the current year.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#attribute_yearRange"
     },
     "getCurrentDate": {
      "!type": "fn() -> +aui_datatype_date_parse.Date",
      "!doc": "Get current date.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#method_getCurrentDate"
     },
     "getDaysInMonth": {
      "!type": "fn(year: number, month: number) -> number",
      "!doc": "Get the number of days in the passed year and month.",
      "!url": "http://alloyui.com/classes/DatePickerSelect.html#method_getDaysInMonth"
     }
    },
    "DatePickerSelect.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "Object hash, defining how attribute values are to be parsed from\nmarkup contained in the widget's content box.",
     "!url": "http://alloyui.com/classes/DatePickerSelect.html#property_DatePickerSelect.HTML_PARSER"
    }
   }
  },
  "aui_delayed_task": {
   "DelayedTask": {
    "!type": "fn(config: Object, fn: fn(), scope: Object, args) -> +aui_delayed_task.DelayedTask",
    "!doc": "A base class for DelayedTask, providing:\n<ul>\n   <li>Executes the supplied function in the context of the supplied object 'when' milliseconds later</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var delayed = new A.DelayedTask({\n\t function() {\n    // This callback will be executed when the <code>DelayedTask</code> be invoked\n\t },\n\t scope\n });\n\n\t// executes after 1000ms the callback\n delayed.delay(1000);\n</code></pre>\n\nCheck the list of <a href=\"DelayedTask.html#configattributes\">Configuration Attributes</a> available for\nDelayedTask.",
    "!url": "http://alloyui.com/classes/DelayedTask.html",
    "prototype": {
     "delay": {
      "!type": "fn(delay: number, newFn: fn(), newScope: Object, newArgs)",
      "!doc": "<p>This function is responsible to execute the user callback, passed in\nthe <code>constructor</code> after <code>delay</code> milliseconds.</p>\n\nExample:\n\n<pre><code>// executes after 1000ms the callback\ndelayed.delay(1000);</code></pre>",
      "!url": "http://alloyui.com/classes/DelayedTask.html#method_delay"
     },
     "cancel": {
      "!type": "fn()",
      "!doc": "Cancel the delayed task in case it's running (i.e., clearInterval from\nthe current running <a href=\"DelayedTask.html#property__id\">_id</a>).",
      "!url": "http://alloyui.com/classes/DelayedTask.html#method_cancel"
     }
    }
   }
  },
  "aui_diagram_builder": {
   "A.AvailableField": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.AvailableField",
    "!proto": "A.Base",
    "!doc": "A base class for AvailableField.",
    "!url": "http://alloyui.com/classes/A.AvailableField.html",
    "AvailableField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.AvailableField.html#property_AvailableField.NAME"
    },
    "AvailableField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the AvailableField.",
     "!url": "http://alloyui.com/classes/A.AvailableField.html#property_AvailableField.ATTRS"
    },
    "prototype": {
     "draggable": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AvailableField.html#attribute_draggable"
     },
     "label": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AvailableField.html#attribute_label"
     },
     "iconClass": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AvailableField.html#attribute_iconClass"
     },
     "id": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AvailableField.html#attribute_id"
     },
     "node": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AvailableField.html#attribute_node"
     },
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.AvailableField.html#attribute_type"
     }
    },
    "AvailableField.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.AvailableField.html#property_AvailableField.EXTENDS"
    }
   },
   "A.FieldSupport": {
    "!type": "fn() -> +aui_diagram_builder.A.FieldSupport",
    "!doc": "A base class for FieldSupport.",
    "!url": "http://alloyui.com/classes/A.FieldSupport.html",
    "FieldSupport.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FieldSupport.",
     "!url": "http://alloyui.com/classes/A.FieldSupport.html#property_FieldSupport.ATTRS"
    },
    "prototype": {
     "fields": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FieldSupport.html#attribute_fields"
     },
     "maxFields": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FieldSupport.html#attribute_maxFields"
     },
     "addField": {
      "!type": "fn(field, index)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FieldSupport.html#method_addField"
     },
     "createFields": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FieldSupport.html#method_createFields"
     },
     "removeField": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FieldSupport.html#method_removeField"
     },
     "createField": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.\n\nNOTE FOR DEVELOPERS: Yoy *may* want to replace the\nmethods from this section on your implementation.",
      "!url": "http://alloyui.com/classes/A.FieldSupport.html#method_createField"
     }
    }
   },
   "A.DiagramBuilderBase": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramBuilderBase",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for DiagramBuilderBase.",
    "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html",
    "DiagramBuilderBase.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#property_DiagramBuilderBase.NAME"
    },
    "DiagramBuilderBase.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DiagramBuilderBase.",
     "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#property_DiagramBuilderBase.ATTRS"
    },
    "prototype": {
     "availableFields": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_availableFields"
     },
     "availableFieldsDragConfig": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_availableFieldsDragConfig"
     },
     "canvas": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_canvas"
     },
     "dropConfig": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_dropConfig"
     },
     "contentContainer": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_contentContainer"
     },
     "dropContainer": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_dropContainer"
     },
     "fieldsContainer": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_fieldsContainer"
     },
     "propertyList": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_propertyList"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_strings"
     },
     "tabView": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_tabView"
     },
     "toolbar": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_toolbar"
     },
     "toolbarContainer": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#attribute_toolbarContainer"
     },
     "isAvailableFieldsDrag": {
      "!type": "fn(drag)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#method_isAvailableFieldsDrag"
     },
     "plotFields": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#method_plotFields"
     }
    },
    "DiagramBuilderBase.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#property_DiagramBuilderBase.HTML_PARSER"
    },
    "DiagramBuilderBase.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#property_DiagramBuilderBase.UI_ATTRS"
    },
    "DiagramBuilderBase.AUGMENTS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DiagramBuilderBase.html#property_DiagramBuilderBase.AUGMENTS"
    }
   },
   "A.Connector": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.Connector",
    "!proto": "A.Base",
    "!doc": "A base class for Connector.",
    "!url": "http://alloyui.com/classes/A.Connector.html",
    "prototype": {
     "draw": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#method_draw"
     },
     "getProperties": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#method_getProperties"
     },
     "getPropertyModel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#method_getPropertyModel"
     },
     "getStrings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#method_getStrings"
     },
     "hide": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#method_hide"
     },
     "show": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#method_show"
     },
     "coord": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_coord"
     },
     "toJSON": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#method_toJSON"
     },
     "arrowPoints": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_arrowPoints"
     },
     "builder": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_builder"
     },
     "color": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_color"
     },
     "graphic": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_graphic"
     },
     "lazyDraw": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_lazyDraw"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_name"
     },
     "nodeName": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_nodeName"
     },
     "p1": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_p1"
     },
     "p2": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_p2"
     },
     "selected": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_selected"
     },
     "shape": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_shape"
     },
     "shapeArrow": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_shapeArrow"
     },
     "shapeArrowHover": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_shapeArrowHover"
     },
     "shapeArrowSelected": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_shapeArrowSelected"
     },
     "shapeHover": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_shapeHover"
     },
     "shapeSelected": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_shapeSelected"
     },
     "showName": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_showName"
     },
     "transition": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_transition"
     },
     "visible": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Connector.html#attribute_visible"
     }
    },
    "Connector.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Connector.",
     "!url": "http://alloyui.com/classes/A.Connector.html#property_Connector.ATTRS"
    },
    "Connector.STRINGS": {
     "!type": "+Object",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.Connector.html#property_Connector.STRINGS"
    }
   },
   "A.DiagramBuilder": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramBuilder",
    "!proto": "aui_diagram_builder.A.DiagramBuilderBase",
    "!doc": "A base class for Diagram Builder.\n\nCheck the [live demo](http://alloyui.com/examples/diagram-builder/).",
    "!url": "http://alloyui.com/classes/A.DiagramBuilder.html",
    "DiagramBuilder.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#property_DiagramBuilder.NAME"
    },
    "DiagramBuilder.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DiagramBuilder.",
     "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#property_DiagramBuilder.ATTRS"
    },
    "prototype": {
     "connector": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#attribute_connector"
     },
     "fieldsDragConfig": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#attribute_fieldsDragConfig"
     },
     "graphic": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#attribute_graphic"
     },
     "highlightDropZones": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#attribute_highlightDropZones"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#attribute_strings"
     },
     "showSuggestConnector": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#attribute_showSuggestConnector"
     },
     "suggestConnectorOverlay": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#attribute_suggestConnectorOverlay"
     },
     "syncConnectionsUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_syncConnectionsUI"
     },
     "clearFields": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_clearFields"
     },
     "closeEditProperties": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_closeEditProperties"
     },
     "connect": {
      "!type": "fn(diagramNode1, diagramNode2, optConnector)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_connect"
     },
     "connectAll": {
      "!type": "fn(nodes)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_connectAll"
     },
     "createField": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_createField"
     },
     "deleteSelectedConnectors": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_deleteSelectedConnectors"
     },
     "deleteSelectedNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_deleteSelectedNode"
     },
     "eachConnector": {
      "!type": "fn(fn)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_eachConnector"
     },
     "editConnector": {
      "!type": "fn(connector)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_editConnector"
     },
     "editNode": {
      "!type": "fn(diagramNode)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_editNode"
     },
     "getFieldClass": {
      "!type": "fn(type)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_getFieldClass"
     },
     "getNodesByTransitionProperty": {
      "!type": "fn(property, value)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_getNodesByTransitionProperty"
     },
     "getSelectedConnectors": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_getSelectedConnectors"
     },
     "getSourceNodes": {
      "!type": "fn(diagramNode)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_getSourceNodes"
     },
     "hideSuggestConnetorOverlay": {
      "!type": "fn(diagramNode, drag)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_hideSuggestConnetorOverlay"
     },
     "isAbleToConnect": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_isAbleToConnect"
     },
     "isFieldsDrag": {
      "!type": "fn(drag)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_isFieldsDrag"
     },
     "plotField": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_plotField"
     },
     "select": {
      "!type": "fn(diagramNode)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_select"
     },
     "showSuggestConnetorOverlay": {
      "!type": "fn(xy)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_showSuggestConnetorOverlay"
     },
     "stopEditing": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_stopEditing"
     },
     "toJSON": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_toJSON"
     },
     "unselectConnectors": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_unselectConnectors"
     },
     "unselectNodes": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#method_unselectNodes"
     }
    },
    "DiagramBuilder.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#property_DiagramBuilder.EXTENDS"
    },
    "DiagramBuilder.FIELDS_TAB": {
     "!type": "number",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#property_DiagramBuilder.FIELDS_TAB"
    },
    "DiagramBuilder.SETTINGS_TAB": {
     "!type": "number",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DiagramBuilder.html#property_DiagramBuilder.SETTINGS_TAB"
    }
   },
   "A.DiagramNodeManagerBase": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramNodeManagerBase",
    "!proto": "A.Base",
    "!doc": "A base class for DiagramNodeManagerBase.",
    "!url": "http://alloyui.com/classes/A.DiagramNodeManagerBase.html",
    "DiagramNodeManagerBase.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeManagerBase.html#property_DiagramNodeManagerBase.NAME"
    },
    "DiagramNodeManagerBase.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeManagerBase.html#property_DiagramNodeManagerBase.EXTENDS"
    }
   },
   "A.DiagramNode": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramNode",
    "!proto": "A.Overlay",
    "!doc": "A base class for DiagramNode.",
    "!url": "http://alloyui.com/classes/A.DiagramNode.html",
    "DiagramNode.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramNode.html#property_DiagramNode.NAME"
    },
    "DiagramNode.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.DiagramNode.html#property_DiagramNode.UI_ATTRS"
    },
    "DiagramNode.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DiagramNode.",
     "!url": "http://alloyui.com/classes/A.DiagramNode.html#property_DiagramNode.ATTRS"
    },
    "prototype": {
     "builder": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_builder"
     },
     "connectors": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_connectors"
     },
     "controlsToolbar": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_controlsToolbar"
     },
     "description": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_description"
     },
     "graphic": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_graphic"
     },
     "height": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_height"
     },
     "highlighted": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_highlighted"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_name"
     },
     "required": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_required"
     },
     "selected": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_selected"
     },
     "shapeBoundary": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_shapeBoundary"
     },
     "highlightBoundaryStroke": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_highlightBoundaryStroke"
     },
     "shapeInvite": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_shapeInvite"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_strings"
     },
     "tabIndex": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_tabIndex"
     },
     "transitions": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_transitions"
     },
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_type"
     },
     "width": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_width"
     },
     "zIndex": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#attribute_zIndex"
     },
     "addTransition": {
      "!type": "fn(transition)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_addTransition"
     },
     "alignTransition": {
      "!type": "fn(transition)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_alignTransition"
     },
     "alignTransitions": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_alignTransitions"
     },
     "close": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_close"
     },
     "connect": {
      "!type": "fn(transition, optConnector)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_connect"
     },
     "connectDrop": {
      "!type": "fn(event)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_connectDrop"
     },
     "connectEnd": {
      "!type": "fn(event)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_connectEnd"
     },
     "connectMove": {
      "!type": "fn(event)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_connectMove"
     },
     "connectNode": {
      "!type": "fn(diagramNode)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_connectNode"
     },
     "connectOutTarget": {
      "!type": "fn(event)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_connectOutTarget"
     },
     "connectOverTarget": {
      "!type": "fn(event)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_connectOverTarget"
     },
     "connectStart": {
      "!type": "fn(event)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_connectStart"
     },
     "disconnect": {
      "!type": "fn(transition)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_disconnect"
     },
     "eachConnector": {
      "!type": "fn(fn)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_eachConnector"
     },
     "getConnector": {
      "!type": "fn(transition)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_getConnector"
     },
     "getContainer": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_getContainer"
     },
     "getLeftTop": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_getLeftTop"
     },
     "getProperties": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_getProperties"
     },
     "getPropertyModel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_getPropertyModel"
     },
     "isBoundaryDrag": {
      "!type": "fn(drag)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_isBoundaryDrag"
     },
     "isTransitionConnected": {
      "!type": "fn(transition)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_isTransitionConnected"
     },
     "prepareTransition": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_prepareTransition"
     },
     "removeTransition": {
      "!type": "fn(transition)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_removeTransition"
     },
     "renderShapeBoundary": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_renderShapeBoundary"
     },
     "renderShapeInvite": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_renderShapeInvite"
     },
     "syncConnectionsUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNode.html#method_syncConnectionsUI"
     }
    },
    "DiagramNode.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DiagramNode.html#property_DiagramNode.EXTENDS"
    },
    "DiagramNode.CIRCLE_POINTS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DiagramNode.html#property_DiagramNode.CIRCLE_POINTS"
    },
    "DiagramNode.DIAMOND_POINTS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DiagramNode.html#property_DiagramNode.DIAMOND_POINTS"
    },
    "DiagramNode.SQUARE_POINTS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.DiagramNode.html#property_DiagramNode.SQUARE_POINTS"
    }
   },
   "A.DiagramNodeState": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramNodeState",
    "!proto": "aui_diagram_builder.A.DiagramNode",
    "!doc": "A base class for DiagramNodeState.",
    "!url": "http://alloyui.com/classes/A.DiagramNodeState.html",
    "DiagramNodeState.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeState.html#property_DiagramNodeState.NAME"
    },
    "DiagramNodeState.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DiagramNodeState.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeState.html#property_DiagramNodeState.ATTRS"
    },
    "prototype": {
     "height": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeState.html#attribute_height"
     },
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeState.html#attribute_type"
     },
     "width": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeState.html#attribute_width"
     },
     "renderShapeBoundary": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeState.html#method_renderShapeBoundary"
     }
    },
    "DiagramNodeState.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeState.html#property_DiagramNodeState.EXTENDS"
    }
   },
   "A.DiagramNodeCondition": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramNodeCondition",
    "!proto": "aui_diagram_builder.A.DiagramNodeState",
    "!doc": "A base class for DiagramNodeCondition.",
    "!url": "http://alloyui.com/classes/A.DiagramNodeCondition.html",
    "DiagramNodeCondition.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeCondition.html#property_DiagramNodeCondition.NAME"
    },
    "DiagramNodeCondition.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DiagramNodeCondition.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeCondition.html#property_DiagramNodeCondition.ATTRS"
    },
    "prototype": {
     "height": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeCondition.html#attribute_height"
     },
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeCondition.html#attribute_type"
     },
     "width": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeCondition.html#attribute_width"
     },
     "renderShapeBoundary": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeCondition.html#method_renderShapeBoundary"
     }
    },
    "DiagramNodeCondition.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeCondition.html#property_DiagramNodeCondition.EXTENDS"
    }
   },
   "A.DiagramNodeStart": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramNodeStart",
    "!proto": "aui_diagram_builder.A.DiagramNodeState",
    "!doc": "A base class for DiagramNodeStart.",
    "!url": "http://alloyui.com/classes/A.DiagramNodeStart.html",
    "DiagramNodeStart.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeStart.html#property_DiagramNodeStart.NAME"
    },
    "DiagramNodeStart.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DiagramNodeStart.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeStart.html#property_DiagramNodeStart.ATTRS"
    },
    "prototype": {
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeStart.html#attribute_type"
     }
    },
    "DiagramNodeStart.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeStart.html#property_DiagramNodeStart.EXTENDS"
    }
   },
   "A.DiagramNodeEnd": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramNodeEnd",
    "!proto": "aui_diagram_builder.A.DiagramNodeState",
    "!doc": "A base class for DiagramNodeEnd.",
    "!url": "http://alloyui.com/classes/A.DiagramNodeEnd.html",
    "DiagramNodeEnd.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeEnd.html#property_DiagramNodeEnd.NAME"
    },
    "DiagramNodeEnd.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DiagramNodeEnd.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeEnd.html#property_DiagramNodeEnd.ATTRS"
    },
    "prototype": {
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeEnd.html#attribute_type"
     }
    },
    "DiagramNodeEnd.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeEnd.html#property_DiagramNodeEnd.EXTENDS"
    }
   },
   "A.DiagramNodeJoin": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramNodeJoin",
    "!proto": "aui_diagram_builder.A.DiagramNodeState",
    "!doc": "A base class for DiagramNodeJoin.",
    "!url": "http://alloyui.com/classes/A.DiagramNodeJoin.html",
    "DiagramNodeJoin.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeJoin.html#property_DiagramNodeJoin.NAME"
    },
    "DiagramNodeJoin.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DiagramNodeJoin.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeJoin.html#property_DiagramNodeJoin.ATTRS"
    },
    "prototype": {
     "height": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeJoin.html#attribute_height"
     },
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeJoin.html#attribute_type"
     },
     "width": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeJoin.html#attribute_width"
     }
    },
    "DiagramNodeJoin.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeJoin.html#property_DiagramNodeJoin.EXTENDS"
    }
   },
   "A.DiagramNodeFork": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramNodeFork",
    "!proto": "aui_diagram_builder.A.DiagramNodeState",
    "!doc": "A base class for DiagramNodeFork.",
    "!url": "http://alloyui.com/classes/A.DiagramNodeFork.html",
    "DiagramNodeFork.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeFork.html#property_DiagramNodeFork.NAME"
    },
    "DiagramNodeFork.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DiagramNodeFork.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeFork.html#property_DiagramNodeFork.ATTRS"
    },
    "prototype": {
     "height": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeFork.html#attribute_height"
     },
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeFork.html#attribute_type"
     },
     "width": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeFork.html#attribute_width"
     }
    },
    "DiagramNodeFork.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeFork.html#property_DiagramNodeFork.EXTENDS"
    }
   },
   "A.DiagramNodeTask": {
    "!type": "fn(config: Object) -> +aui_diagram_builder.A.DiagramNodeTask",
    "!proto": "aui_diagram_builder.A.DiagramNodeState",
    "!doc": "A base class for DiagramNodeTask.",
    "!url": "http://alloyui.com/classes/A.DiagramNodeTask.html",
    "DiagramNodeTask.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeTask.html#property_DiagramNodeTask.NAME"
    },
    "DiagramNodeTask.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the DiagramNodeTask.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeTask.html#property_DiagramNodeTask.ATTRS"
    },
    "prototype": {
     "height": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeTask.html#attribute_height"
     },
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeTask.html#attribute_type"
     },
     "width": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeTask.html#attribute_width"
     },
     "renderShapeBoundary": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.DiagramNodeTask.html#method_renderShapeBoundary"
     }
    },
    "DiagramNodeTask.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.DiagramNodeTask.html#property_DiagramNodeTask.EXTENDS"
    }
   },
   "Editable": {
    "!type": "fn(config: Object) -> +aui_editable.Editable",
    "!proto": "Component",
    "!doc": "<p><img src=\"assets/images/aui-editable/main.png\"/></p>\n\nA base class for Editable, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Edit in place elements</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var instance = new A.Editable({\n  node: '#editor'\n}).render();\n</code></pre>\n\nCheck the list of <a href=\"Editable.html#configattributes\">Configuration Attributes</a> available for\nEditable.",
    "!url": "http://alloyui.com/classes/Editable.html",
    "prototype": {
     "undefined": {
      "!type": "fn()",
      "!url": "http://alloyui.com/classes/Editable.html"
     }
    }
   }
  },
  "aui_editable": {
   "Editable": {
    "!type": "fn(config: Object) -> +aui_editable.Editable",
    "!proto": "Component",
    "!doc": "<p><img src=\"assets/images/aui-editable/main.png\"/></p>\n\nA base class for Editable, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Edit in place elements</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var instance = new A.Editable({\n  node: '#editor'\n}).render();\n</code></pre>\n\nCheck the list of <a href=\"Editable.html#configattributes\">Configuration Attributes</a> available for\nEditable.",
    "!url": "http://alloyui.com/classes/Editable.html",
    "Editable.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/Editable.html#property_Editable.NAME"
    },
    "Editable.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Editable.",
     "!url": "http://alloyui.com/classes/Editable.html#property_Editable.ATTRS"
    },
    "prototype": {
     "cancelButton": {
      "!type": "fn()",
      "!doc": "<a href=\"ButtonItem.html\">ButtonItem</a> constructor Object for the\ncancelButton.",
      "!url": "http://alloyui.com/classes/Editable.html#attribute_cancelButton"
     },
     "contentText": {
      "!type": "fn()",
      "!doc": "Content text.",
      "!url": "http://alloyui.com/classes/Editable.html#attribute_contentText"
     },
     "eventType": {
      "!type": "fn()",
      "!doc": "Event type to initialize the editable.",
      "!url": "http://alloyui.com/classes/Editable.html#attribute_eventType"
     },
     "formatInput": {
      "!type": "fn()",
      "!doc": "Function to format the input text displayed on the input.",
      "!url": "http://alloyui.com/classes/Editable.html#attribute_formatInput"
     },
     "formatOutput": {
      "!type": "fn()",
      "!doc": "Function to format the output text displayed on the input.",
      "!url": "http://alloyui.com/classes/Editable.html#attribute_formatOutput"
     },
     "icons": {
      "!type": "fn()",
      "!doc": "Array with icons for the <a href=\"Toolbar.html\">Toolbar</a>.",
      "!url": "http://alloyui.com/classes/Editable.html#attribute_icons"
     },
     "inputType": {
      "!type": "fn()",
      "!doc": "Type of the input used to edit the <a\nhref=\"Editable.html#config_node\">node</a>.",
      "!url": "http://alloyui.com/classes/Editable.html#attribute_inputType"
     },
     "node": {
      "!type": "fn()",
      "!doc": "Node to setup the editable.",
      "!url": "http://alloyui.com/classes/Editable.html#attribute_node"
     },
     "renderTo": {
      "!type": "fn()",
      "!doc": "Node to render the editable.",
      "!url": "http://alloyui.com/classes/Editable.html#attribute_renderTo"
     },
     "saveButton": {
      "!type": "fn()",
      "!doc": "<a href=\"ButtonItem.html\">ButtonItem</a> constructor Object for the\nsaveButton.",
      "!url": "http://alloyui.com/classes/Editable.html#attribute_saveButton"
     },
     "cancel": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the cancel event.",
      "!url": "http://alloyui.com/classes/Editable.html#event_cancel"
     },
     "save": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the save event.",
      "!url": "http://alloyui.com/classes/Editable.html#event_save"
     },
     "startEditing": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the startEditing event.",
      "!url": "http://alloyui.com/classes/Editable.html#event_startEditing"
     },
     "stopEditing": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the stopEditing event.",
      "!url": "http://alloyui.com/classes/Editable.html#event_stopEditing"
     }
    }
   }
  },
  "aui_event": {
   "A.FormBuilderAvailableField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderAvailableField",
    "!proto": "aui_diagram_builder.A.AvailableField",
    "!doc": "A base class for FormBuilderAvailableField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html",
    "prototype": {
     "hasModifier": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#method_hasModifier"
     },
     "isKey": {
      "!type": "fn(name)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#method_isKey"
     },
     "isKeyInRange": {
      "!type": "fn(start, end)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#method_isKeyInRange"
     },
     "isKeyInSet": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#method_isKeyInSet"
     },
     "isNavKey": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#method_isNavKey"
     },
     "isSpecialKey": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#method_isSpecialKey"
     },
     "change": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#event_change"
     },
     "delegate": {
      "!type": "fn(node, subscription, notifier, filter)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#method_delegate"
     },
     "detach": {
      "!type": "fn(node, subscription, notifier)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#method_detach"
     },
     "detachDelegate": {
      "!type": "fn(node, subscription, notifier)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#method_detachDelegate"
     },
     "on": {
      "!type": "fn(node, subscription, notifier)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#method_on"
     },
     "submit": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#event_submit"
     },
     "input": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#event_input"
     }
    }
   }
  },
  "aui_form_builder": {
   "A.FormBuilderAvailableField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderAvailableField",
    "!proto": "aui_diagram_builder.A.AvailableField",
    "!doc": "A base class for FormBuilderAvailableField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html",
    "FormBuilderAvailableField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#property_FormBuilderAvailableField.NAME"
    },
    "FormBuilderAvailableField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ModuleName.",
     "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#property_FormBuilderAvailableField.ATTRS"
    },
    "prototype": {
     "hiddenAttributes": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#attribute_hiddenAttributes"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#attribute_name"
     },
     "options": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#attribute_options"
     },
     "predefinedValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#attribute_predefinedValue"
     },
     "readOnlyAttributes": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#attribute_readOnlyAttributes"
     },
     "required": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#attribute_required"
     },
     "showLabel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#attribute_showLabel"
     },
     "tip": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#attribute_tip"
     },
     "unique": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#attribute_unique"
     },
     "width": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#attribute_width"
     }
    },
    "FormBuilderAvailableField.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderAvailableField.html#property_FormBuilderAvailableField.EXTENDS"
    }
   },
   "A.FormBuilder": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilder",
    "!proto": "aui_diagram_builder.A.DiagramBuilderBase",
    "!doc": "A base class for FormBuilder.",
    "!url": "http://alloyui.com/classes/A.FormBuilder.html",
    "FormBuilder.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilder.html#property_FormBuilder.NAME"
    },
    "FormBuilder.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilder.",
     "!url": "http://alloyui.com/classes/A.FormBuilder.html#property_FormBuilder.ATTRS"
    },
    "prototype": {
     "allowRemoveRequiredFields": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#attribute_allowRemoveRequiredFields"
     },
     "enableEditing": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#attribute_enableEditing"
     },
     "fieldsSortableListConfig": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#attribute_fieldsSortableListConfig"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#attribute_strings"
     },
     "closeEditProperties": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_closeEditProperties"
     },
     "createField": {
      "!type": "fn(config)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_createField"
     },
     "duplicateField": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_duplicateField"
     },
     "editField": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_editField"
     },
     "getFieldClass": {
      "!type": "fn(type)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_getFieldClass"
     },
     "getFieldProperties": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_getFieldProperties"
     },
     "insertField": {
      "!type": "fn(field, index, parent)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_insertField"
     },
     "openEditProperties": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_openEditProperties"
     },
     "plotField": {
      "!type": "fn(field, container)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_plotField"
     },
     "plotFields": {
      "!type": "fn(fields, container)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_plotFields"
     },
     "selectFields": {
      "!type": "fn(fields)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_selectFields"
     },
     "simulateFocusField": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_simulateFocusField"
     },
     "unselectFields": {
      "!type": "fn(fields)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilder.html#method_unselectFields"
     }
    },
    "FormBuilder.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilder.html#property_FormBuilder.UI_ATTRS"
    },
    "FormBuilder.EXTENDS": {
     "!type": "string",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilder.html#property_FormBuilder.EXTENDS"
    },
    "FormBuilder.FIELDS_TAB": {
     "!type": "number",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilder.html#property_FormBuilder.FIELDS_TAB"
    },
    "FormBuilder.SETTINGS_TAB": {
     "!type": "number",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilder.html#property_FormBuilder.SETTINGS_TAB"
    }
   },
   "A.FormBuilderFieldBase": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderFieldBase",
    "!proto": "Component",
    "!doc": "A base class for FormBuilderFieldBase.",
    "!url": "http://alloyui.com/classes/A.FormBuilderFieldBase.html",
    "FormBuilderFieldBase.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFieldBase.html#property_FormBuilderFieldBase.NAME"
    },
    "FormBuilderFieldBase.AUGMENTS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFieldBase.html#property_FormBuilderFieldBase.AUGMENTS"
    }
   },
   "A.FormBuilderField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderField",
    "!proto": "aui_form_builder.A.FormBuilderFieldBase",
    "!doc": "A base class for FormBuilderField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderField.html",
    "FormBuilderField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderField.html#property_FormBuilderField.NAME"
    },
    "FormBuilderField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilderField.",
     "!url": "http://alloyui.com/classes/A.FormBuilderField.html#property_FormBuilderField.ATTRS"
    },
    "prototype": {
     "acceptChildren": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_acceptChildren"
     },
     "builder": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_builder"
     },
     "controlsToolbar": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_controlsToolbar"
     },
     "dataType": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_dataType"
     },
     "disabled": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_disabled"
     },
     "selected": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_selected"
     },
     "hiddenAttributes": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_hiddenAttributes"
     },
     "id": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_id"
     },
     "label": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_label"
     },
     "localizationMap": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_localizationMap"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_name"
     },
     "parent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_parent"
     },
     "predefinedValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_predefinedValue"
     },
     "readOnly": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_readOnly"
     },
     "readOnlyAttributes": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_readOnlyAttributes"
     },
     "required": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_required"
     },
     "showLabel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_showLabel"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_strings"
     },
     "tabIndex": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_tabIndex"
     },
     "template": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_template"
     },
     "tip": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_tip"
     },
     "type": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_type"
     },
     "unique": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_unique"
     },
     "zIndex": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_zIndex"
     },
     "dropZoneNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_dropZoneNode"
     },
     "labelNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_labelNode"
     },
     "requiredFlagNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_requiredFlagNode"
     },
     "templateNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_templateNode"
     },
     "tipFlagNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#attribute_tipFlagNode"
     },
     "createField": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#method_createField"
     },
     "getHTML": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.\nTo developer: Implement this",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#method_getHTML"
     },
     "getNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#method_getNode"
     },
     "getAttributesForCloning": {
      "!type": "fn() -> +Object",
      "!doc": "Gets all necessary attributes for cloning this field.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#method_getAttributesForCloning"
     },
     "getProperties": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#method_getProperties"
     },
     "getPropertyModel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#method_getPropertyModel"
     },
     "_getToolbarItems": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderField.html#method__getToolbarItems"
     }
    },
    "FormBuilderField.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.FormBuilderField.html#property_FormBuilderField.UI_ATTRS"
    },
    "FormBuilderField.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderField.html#property_FormBuilderField.EXTENDS"
    },
    "FormBuilderField.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderField.html#property_FormBuilderField.HTML_PARSER"
    }
   },
   "A.FormBuilderButtonField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderButtonField",
    "!proto": "aui_form_builder.A.FormBuilderField",
    "!doc": "A base class for FormBuilderButtonField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html",
    "FormBuilderButtonField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#property_FormBuilderButtonField.NAME"
    },
    "FormBuilderButtonField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilderButtonField.",
     "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#property_FormBuilderButtonField.ATTRS"
    },
    "prototype": {
     "acceptChildren": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#attribute_acceptChildren"
     },
     "buttonType": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#attribute_buttonType"
     },
     "predefinedValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#attribute_predefinedValue"
     },
     "showLabel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#attribute_showLabel"
     },
     "template": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#attribute_template"
     },
     "getHTML": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#method_getHTML"
     },
     "getPropertyModel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#method_getPropertyModel"
     }
    },
    "FormBuilderButtonField.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#property_FormBuilderButtonField.UI_ATTRS"
    },
    "FormBuilderButtonField.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#property_FormBuilderButtonField.CSS_PREFIX"
    },
    "FormBuilderButtonField.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderButtonField.html#property_FormBuilderButtonField.EXTENDS"
    }
   },
   "A.FormBuilderCheckBoxField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderCheckBoxField",
    "!proto": "aui_form_builder.A.FormBuilderField",
    "!doc": "A base class for FormBuilderCheckBoxField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderCheckBoxField.html",
    "FormBuilderCheckBoxField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderCheckBoxField.html#property_FormBuilderCheckBoxField.NAME"
    },
    "FormBuilderCheckBoxField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilderCheckBoxField.",
     "!url": "http://alloyui.com/classes/A.FormBuilderCheckBoxField.html#property_FormBuilderCheckBoxField.ATTRS"
    },
    "prototype": {
     "dataType": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderCheckBoxField.html#attribute_dataType"
     },
     "predefinedValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderCheckBoxField.html#attribute_predefinedValue"
     },
     "template": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderCheckBoxField.html#attribute_template"
     },
     "getPropertyModel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderCheckBoxField.html#method_getPropertyModel"
     },
     "getHTML": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderCheckBoxField.html#method_getHTML"
     }
    },
    "FormBuilderCheckBoxField.CSS_PREFIX": {
     "!type": "?",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderCheckBoxField.html#property_FormBuilderCheckBoxField.CSS_PREFIX"
    },
    "FormBuilderCheckBoxField.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderCheckBoxField.html#property_FormBuilderCheckBoxField.EXTENDS"
    }
   },
   "A.FormBuilderFieldsetField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderFieldsetField",
    "!proto": "aui_form_builder.A.FormBuilderField",
    "!doc": "A base class for FormBuilderFieldsetField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html",
    "FormBuilderFieldsetField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#property_FormBuilderFieldsetField.NAME"
    },
    "FormBuilderFieldsetField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilderFieldsetField.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#property_FormBuilderFieldsetField.ATTRS"
    },
    "prototype": {
     "acceptChildren": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#attribute_acceptChildren"
     },
     "dataType": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#attribute_dataType"
     },
     "labelNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#attribute_labelNode"
     },
     "template": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#attribute_template"
     },
     "getHTML": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#method_getHTML"
     },
     "getPropertyModel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#method_getPropertyModel"
     }
    },
    "FormBuilderFieldsetField.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#property_FormBuilderFieldsetField.UI_ATTRS"
    },
    "FormBuilderFieldsetField.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#property_FormBuilderFieldsetField.CSS_PREFIX"
    },
    "FormBuilderFieldsetField.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFieldsetField.html#property_FormBuilderFieldsetField.EXTENDS"
    }
   },
   "A.FormBuilderFileUploadField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderFileUploadField",
    "!proto": "aui_form_builder.A.FormBuilderField",
    "!doc": "A base class for FormBuilderFileUploadField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderFileUploadField.html",
    "FormBuilderFileUploadField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFileUploadField.html#property_FormBuilderFileUploadField.NAME"
    },
    "FormBuilderFileUploadField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilderFileUploadField.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFileUploadField.html#property_FormBuilderFileUploadField.ATTRS"
    },
    "prototype": {
     "template": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderFileUploadField.html#attribute_template"
     },
     "getHTML": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderFileUploadField.html#method_getHTML"
     }
    },
    "FormBuilderFileUploadField.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFileUploadField.html#property_FormBuilderFileUploadField.CSS_PREFIX"
    },
    "FormBuilderFileUploadField.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderFileUploadField.html#property_FormBuilderFileUploadField.EXTENDS"
    }
   },
   "A.OptionsEditor": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.OptionsEditor",
    "!proto": "aui_datatable.A.RadioCellEditor",
    "!doc": "A base class for OptionsEditor.",
    "!url": "http://alloyui.com/classes/A.OptionsEditor.html",
    "OptionsEditor.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.OptionsEditor.html#property_OptionsEditor.NAME"
    },
    "OptionsEditor.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the OptionsEditor.",
     "!url": "http://alloyui.com/classes/A.OptionsEditor.html#property_OptionsEditor.ATTRS"
    },
    "prototype": {
     "editable": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.OptionsEditor.html#attribute_editable"
     }
    },
    "OptionsEditor.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.OptionsEditor.html#property_OptionsEditor.EXTENDS"
    }
   },
   "A.FormBuilderMultipleChoiceField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderMultipleChoiceField",
    "!proto": "aui_form_builder.A.FormBuilderField",
    "!doc": "A base class for FormBuilderMultipleChoiceField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html",
    "FormBuilderMultipleChoiceField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html#property_FormBuilderMultipleChoiceField.NAME"
    },
    "FormBuilderMultipleChoiceField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilderMultipleChoiceField.",
     "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html#property_FormBuilderMultipleChoiceField.ATTRS"
    },
    "prototype": {
     "acceptChildren": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html#attribute_acceptChildren"
     },
     "options": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html#attribute_options"
     },
     "optionTemplate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html#attribute_optionTemplate"
     },
     "predefinedValue": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html#attribute_predefinedValue"
     },
     "getPropertyModel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html#method_getPropertyModel"
     }
    },
    "FormBuilderMultipleChoiceField.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html#property_FormBuilderMultipleChoiceField.UI_ATTRS"
    },
    "FormBuilderMultipleChoiceField.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html#property_FormBuilderMultipleChoiceField.CSS_PREFIX"
    },
    "FormBuilderMultipleChoiceField.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderMultipleChoiceField.html#property_FormBuilderMultipleChoiceField.EXTENDS"
    }
   },
   "A.FormBuilderRadioField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderRadioField",
    "!proto": "aui_form_builder.A.FormBuilderMultipleChoiceField",
    "!doc": "A base class for FormBuilderRadioField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderRadioField.html",
    "FormBuilderRadioField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderRadioField.html#property_FormBuilderRadioField.NAME"
    },
    "FormBuilderRadioField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilderRadioField.",
     "!url": "http://alloyui.com/classes/A.FormBuilderRadioField.html#property_FormBuilderRadioField.ATTRS"
    },
    "prototype": {
     "predefinedValue": {
      "!type": "fn()",
      "!doc": "The predefined value for the radio fields.",
      "!url": "http://alloyui.com/classes/A.FormBuilderRadioField.html#attribute_predefinedValue"
     },
     "template": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderRadioField.html#attribute_template"
     },
     "getHTML": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderRadioField.html#method_getHTML"
     }
    },
    "FormBuilderRadioField.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderRadioField.html#property_FormBuilderRadioField.CSS_PREFIX"
    },
    "FormBuilderRadioField.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderRadioField.html#property_FormBuilderRadioField.EXTENDS"
    }
   },
   "A.FormBuilderSelectField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderSelectField",
    "!proto": "aui_form_builder.A.FormBuilderMultipleChoiceField",
    "!doc": "A base class for FormBuilderSelectField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderSelectField.html",
    "FormBuilderSelectField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderSelectField.html#property_FormBuilderSelectField.NAME"
    },
    "FormBuilderSelectField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilderSelectField.",
     "!url": "http://alloyui.com/classes/A.FormBuilderSelectField.html#property_FormBuilderSelectField.ATTRS"
    },
    "prototype": {
     "multiple": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderSelectField.html#attribute_multiple"
     },
     "template": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderSelectField.html#attribute_template"
     },
     "getHTML": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderSelectField.html#method_getHTML"
     },
     "getPropertyModel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderSelectField.html#method_getPropertyModel"
     }
    },
    "FormBuilderSelectField.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.FormBuilderSelectField.html#property_FormBuilderSelectField.UI_ATTRS"
    },
    "FormBuilderSelectField.CSS_PREFIX": {
     "!type": "?",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderSelectField.html#property_FormBuilderSelectField.CSS_PREFIX"
    },
    "FormBuilderSelectField.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderSelectField.html#property_FormBuilderSelectField.EXTENDS"
    }
   },
   "A.FormBuilderTextField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderTextField",
    "!proto": "aui_form_builder.A.FormBuilderField",
    "!doc": "A base class for FormBuilderTextField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderTextField.html",
    "FormBuilderTextField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderTextField.html#property_FormBuilderTextField.NAME"
    },
    "FormBuilderTextField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilderTextField.",
     "!url": "http://alloyui.com/classes/A.FormBuilderTextField.html#property_FormBuilderTextField.ATTRS"
    },
    "prototype": {
     "template": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderTextField.html#attribute_template"
     },
     "width": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderTextField.html#attribute_width"
     },
     "getHTML": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderTextField.html#method_getHTML"
     },
     "getPropertyModel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderTextField.html#method_getPropertyModel"
     }
    },
    "FormBuilderTextField.CSS_PREFIX": {
     "!type": "string",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderTextField.html#property_FormBuilderTextField.CSS_PREFIX"
    },
    "FormBuilderTextField.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderTextField.html#property_FormBuilderTextField.EXTENDS"
    }
   },
   "A.FormBuilderTextAreaField": {
    "!type": "fn(config: Object) -> +aui_form_builder.A.FormBuilderTextAreaField",
    "!proto": "aui_form_builder.A.FormBuilderTextField",
    "!doc": "A base class for FormBuilderTextAreaField.",
    "!url": "http://alloyui.com/classes/A.FormBuilderTextAreaField.html",
    "FormBuilderTextAreaField.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormBuilderTextAreaField.html#property_FormBuilderTextAreaField.NAME"
    },
    "FormBuilderTextAreaField.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormBuilderTextAreaField.",
     "!url": "http://alloyui.com/classes/A.FormBuilderTextAreaField.html#property_FormBuilderTextAreaField.ATTRS"
    },
    "prototype": {
     "template": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderTextAreaField.html#attribute_template"
     },
     "getPropertyModel": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormBuilderTextAreaField.html#method_getPropertyModel"
     }
    },
    "FormBuilderTextAreaField.CSS_PREFIX": {
     "!type": "?",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.FormBuilderTextAreaField.html#property_FormBuilderTextAreaField.CSS_PREFIX"
    },
    "FormBuilderTextAreaField.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormBuilderTextAreaField.html#property_FormBuilderTextAreaField.EXTENDS"
    }
   }
  },
  "aui_form_validator": {
   "A.FormValidator": {
    "!type": "fn(config: Object) -> +aui_form_validator.A.FormValidator",
    "!proto": "A.Base",
    "!doc": "A base class for FormValidator.",
    "!url": "http://alloyui.com/classes/A.FormValidator.html",
    "FormValidator.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.FormValidator.html#property_FormValidator.NAME"
    },
    "FormValidator.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the FormValidator.",
     "!url": "http://alloyui.com/classes/A.FormValidator.html#property_FormValidator.ATTRS"
    },
    "prototype": {
     "boundingBox": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_boundingBox"
     },
     "containerErrorClass": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_containerErrorClass"
     },
     "containerValidClass": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_containerValidClass"
     },
     "errorClass": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_errorClass"
     },
     "extractRules": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_extractRules"
     },
     "fieldContainer": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_fieldContainer"
     },
     "fieldStrings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_fieldStrings"
     },
     "labelCssClass": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_labelCssClass"
     },
     "messageContainer": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_messageContainer"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_strings"
     },
     "rules": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_rules"
     },
     "selectText": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_selectText"
     },
     "showMessages": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_showMessages"
     },
     "showAllMessages": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_showAllMessages"
     },
     "stackErrorContainer": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_stackErrorContainer"
     },
     "validateOnBlur": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_validateOnBlur"
     },
     "validateOnInput": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_validateOnInput"
     },
     "validClass": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#attribute_validClass"
     },
     "addFieldError": {
      "!type": "fn(field, ruleName)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_addFieldError"
     },
     "clearFieldError": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_clearFieldError"
     },
     "eachRule": {
      "!type": "fn(fn)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_eachRule"
     },
     "findFieldContainer": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_findFieldContainer"
     },
     "focusInvalidField": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_focusInvalidField"
     },
     "getField": {
      "!type": "fn(fieldOrFieldName)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_getField"
     },
     "getFieldsByName": {
      "!type": "fn(fieldName)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_getFieldsByName"
     },
     "getFieldError": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_getFieldError"
     },
     "getFieldStackErrorContainer": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_getFieldStackErrorContainer"
     },
     "getFieldErrorMessage": {
      "!type": "fn(field, rule)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_getFieldErrorMessage"
     },
     "hasErrors": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_hasErrors"
     },
     "highlight": {
      "!type": "fn(field, valid)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_highlight"
     },
     "normalizeRuleValue": {
      "!type": "fn(ruleValue)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_normalizeRuleValue"
     },
     "unhighlight": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_unhighlight"
     },
     "printStackError": {
      "!type": "fn(field, container, errors)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_printStackError"
     },
     "resetAllFields": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_resetAllFields"
     },
     "resetField": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_resetField"
     },
     "resetFieldCss": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_resetFieldCss"
     },
     "validatable": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_validatable"
     },
     "validate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_validate"
     },
     "validateField": {
      "!type": "fn(field)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.FormValidator.html#method_validateField"
     }
    },
    "FormValidator.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.FormValidator.html#property_FormValidator.EXTENDS"
    }
   },
   "A.ImageCropper": {
    "!type": "fn(config: Object) -> +aui_image_cropper.A.ImageCropper",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for Image Cropper.\n\nCheck the [live demo](http://alloyui.com/examples/image-cropper/).",
    "!url": "http://alloyui.com/classes/A.ImageCropper.html",
    "prototype": {
     "undefined": {
      "!type": "fn()",
      "!doc": "Check if validator nodes render after the input and lable's textNode",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html"
     }
    }
   }
  },
  "aui_image_cropper": {
   "A.ImageCropper": {
    "!type": "fn(config: Object) -> +aui_image_cropper.A.ImageCropper",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for Image Cropper.\n\nCheck the [live demo](http://alloyui.com/examples/image-cropper/).",
    "!url": "http://alloyui.com/classes/A.ImageCropper.html",
    "ImageCropper.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ImageCropper.html#property_ImageCropper.NAME"
    },
    "ImageCropper.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Image Cropper.",
     "!url": "http://alloyui.com/classes/A.ImageCropper.html#property_ImageCropper.ATTRS"
    },
    "prototype": {
     "cropHeight": {
      "!type": "fn()",
      "!doc": "The height of a selected area to crop.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#attribute_cropHeight"
     },
     "cropWidth": {
      "!type": "fn()",
      "!doc": "The width of a selected area to crop.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#attribute_cropWidth"
     },
     "minWidth": {
      "!type": "fn()",
      "!doc": "The minimum width of a selected area to crop.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#attribute_minWidth"
     },
     "minHeight": {
      "!type": "fn()",
      "!doc": "The minimum height of a selected area to crop.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#attribute_minHeight"
     },
     "movable": {
      "!type": "fn()",
      "!doc": "Determine if the crop area should move or not.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#attribute_movable"
     },
     "preserveRatio": {
      "!type": "fn()",
      "!doc": "Determine if the crop area should preserve the\naspect ratio or not.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#attribute_preserveRatio"
     },
     "region": {
      "!type": "fn()",
      "!doc": "Determine the region of a selected area to crop.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#attribute_region"
     },
     "resizable": {
      "!type": "fn()",
      "!doc": "Determine if the crop area should resize or not.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#attribute_resizable"
     },
     "x": {
      "!type": "fn()",
      "!doc": "The X position of a selected area to crop.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#attribute_x"
     },
     "y": {
      "!type": "fn()",
      "!doc": "The Y position of a selected area to crop.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#attribute_y"
     },
     "syncImageUI": {
      "!type": "fn()",
      "!doc": "Sync the image on the UI.",
      "!url": "http://alloyui.com/classes/A.ImageCropper.html#method_syncImageUI"
     }
    },
    "ImageCropper.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.ImageCropper.html#property_ImageCropper.UI_ATTRS"
    }
   }
  },
  "aui_image_viewer": {
   "A.ImageViewer": {
    "!type": "fn(config: Object) -> +aui_image_viewer.A.ImageViewer",
    "!proto": "A.Widget",
    "!doc": "A base class for ImageViewer, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Displays an image in a Overlay</li>\n   <li>Keyboard navigation support</li>\n</ul>\n\nCheck the [live demo](http://alloyui.com/examples/image-viewer/).",
    "!url": "http://alloyui.com/classes/A.ImageViewer.html",
    "prototype": {
     "close": {
      "!type": "fn()",
      "!doc": "Close the ImageViewer.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_close"
     },
     "getLink": {
      "!type": "fn(currentIndex: number) -> +aui_node.Node",
      "!doc": "Get the Node reference to the <code>currentIndex</code> element from\nthe <a href=\"ImageViewer.html#config_links\">links</a>.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_getLink"
     },
     "getCurrentLink": {
      "!type": "fn() -> +aui_node.Node",
      "!doc": "Get the current loaded node link reference.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_getCurrentLink"
     },
     "loadImage": {
      "!type": "fn(src: string)",
      "!doc": "Load an image <code>src</code> on the ImageViewer.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_loadImage"
     },
     "hasLink": {
      "!type": "fn(currentIndex: number) -> bool",
      "!doc": "Check if there is a node reference for the <code>currentIndex</code>.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_hasLink"
     },
     "hasNext": {
      "!type": "fn() -> bool",
      "!doc": "Check if there is a next element to navigate.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_hasNext"
     },
     "hasPrev": {
      "!type": "fn() -> bool",
      "!doc": "Check if there is a previous element to navigate.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_hasPrev"
     },
     "hideControls": {
      "!type": "fn()",
      "!doc": "Hide all UI controls (i.e., arrows, close icon etc).",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_hideControls"
     },
     "next": {
      "!type": "fn()",
      "!doc": "Load the previous image.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_next"
     },
     "preloadAllImages": {
      "!type": "fn()",
      "!doc": "Preload the neighbor image (i.e., the previous and next image based\non the current load one).",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_preloadAllImages"
     },
     "preloadImage": {
      "!type": "fn(currentIndex: number)",
      "!doc": "Preload an image based on its <code>index</code>.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_preloadImage"
     },
     "showLoading": {
      "!type": "fn()",
      "!doc": "Show the loading icon.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_showLoading"
     },
     "show": {
      "!type": "fn()",
      "!doc": "Show the ImageViewer UI.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#method_show"
     },
     "anim": {
      "!type": "fn()",
      "!doc": "If <code>true</code> the navigation is animated.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_anim"
     },
     "bodyContent": {
      "!type": "fn()",
      "!doc": "The content of body.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_bodyContent"
     },
     "caption": {
      "!type": "fn()",
      "!doc": "The caption of the displayed image.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_caption"
     },
     "captionFromTitle": {
      "!type": "fn()",
      "!doc": "If <code>true</code> the <a\nhref=\"ImageViewer.html#config_caption\">caption</a> will be pulled\nfrom the title DOM attribute.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_captionFromTitle"
     },
     "centered": {
      "!type": "fn()",
      "!doc": "If <code>true</code> the Overlay with the image will be positioned\non the center of the viewport.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_centered"
     },
     "currentIndex": {
      "!type": "fn()",
      "!doc": "Index of the current image.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_currentIndex"
     },
     "image": {
      "!type": "fn()",
      "!doc": "Image node element used to load the images.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_image"
     },
     "imageAnim": {
      "!type": "fn()",
      "!doc": "Configuration attributes passed to the <a href=\"Anim.html\">Anim</a>\nclass.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_imageAnim"
     },
     "infoTemplate": {
      "!type": "fn()",
      "!doc": "String template used to display the information.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_infoTemplate"
     },
     "links": {
      "!type": "fn()",
      "!doc": "Selector or NodeList containing the links where the ImageViewer\nextracts the information to generate the thumbnails.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_links"
     },
     "loading": {
      "!type": "fn()",
      "!doc": "Whether the image is during a loading state.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_loading"
     },
     "modal": {
      "!type": "fn()",
      "!doc": "Displays the modal the viewport. Set to <code>false</code> to\ndisable.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_modal"
     },
     "showClose": {
      "!type": "fn()",
      "!doc": "Show close icon control.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_showClose"
     },
     "showControls": {
      "!type": "fn()",
      "!doc": "Show the controls.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_showControls"
     },
     "tabIndex": {
      "!type": "fn()",
      "!doc": "Specify the tab order of elements.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_tabIndex"
     },
     "totalLinks": {
      "!type": "fn()",
      "!doc": "Helper attribute to get the <code>size</code> of the <a\nhref=\"ImageViewer.html#config_links\">links</a> NodeList.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_totalLinks"
     },
     "visible": {
      "!type": "fn()",
      "!doc": "Determine if the ImageViewer should be visible or not.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_visible"
     },
     "zIndex": {
      "!type": "fn()",
      "!doc": "Specify the stack order of elements.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_zIndex"
     },
     "controlLeftEl": {
      "!type": "fn()",
      "!doc": "The element to be used as left control.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_controlLeftEl"
     },
     "controlRightEl": {
      "!type": "fn()",
      "!doc": "The element to be used as right control.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_controlRightEl"
     },
     "captionEl": {
      "!type": "fn()",
      "!doc": "The element to be used as caption.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_captionEl"
     },
     "closeEl": {
      "!type": "fn()",
      "!doc": "The element to be used as close.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_closeEl"
     },
     "infoEl": {
      "!type": "fn()",
      "!doc": "The element to be used as info.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_infoEl"
     },
     "loader": {
      "!type": "fn()",
      "!doc": "HTML element to house the <code>img</code> which is being loaded.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_loader"
     },
     "loadingEl": {
      "!type": "fn()",
      "!doc": "The element to be used as loading.",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_loadingEl"
     },
     "maxHeight": {
      "!type": "fn()",
      "!doc": "The maximum height of the element",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_maxHeight"
     },
     "maxWidth": {
      "!type": "fn()",
      "!doc": "The maximum width of the element",
      "!url": "http://alloyui.com/classes/A.ImageViewer.html#attribute_maxWidth"
     }
    },
    "ImageViewer.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ImageViewer.html#property_ImageViewer.NAME"
    },
    "ImageViewer.CSS_PREFIX": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the CSS prefix.",
     "!url": "http://alloyui.com/classes/A.ImageViewer.html#property_ImageViewer.CSS_PREFIX"
    },
    "ImageViewer.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ImageViewer.",
     "!url": "http://alloyui.com/classes/A.ImageViewer.html#property_ImageViewer.ATTRS"
    }
   },
   "A.ImageGallery": {
    "!type": "fn(config: Object) -> +aui_image_viewer.A.ImageGallery",
    "!proto": "aui_image_viewer.A.ImageViewer",
    "!doc": "A base class for ImageGallery, providing:\n <ul>\n    <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n    <li>Displays an image in a Overlay</li>\n    <li>Displays list of thumbnails of the images as a control</li>\n    <li>Slide show functionalities (i.e., play, pause etc)</li>\n    <li>Keyboard navigation support</li>\n </ul>\nCheck the [live demo](http://alloyui.com/examples/image-viewer/gallery/).",
    "!url": "http://alloyui.com/classes/A.ImageGallery.html",
    "ImageGallery.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ImageGallery.html#property_ImageGallery.NAME"
    },
    "ImageGallery.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ImageGallery.",
     "!url": "http://alloyui.com/classes/A.ImageGallery.html#property_ImageGallery.ATTRS"
    },
    "prototype": {
     "autoPlay": {
      "!type": "fn()",
      "!doc": "If <code>true</code> the slide show will be played when the\nImageGallery is displayed.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_autoPlay"
     },
     "delay": {
      "!type": "fn()",
      "!doc": "Delay in milliseconds to change to the next image.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_delay"
     },
     "pagination": {
      "!type": "fn()",
      "!doc": "<a href=\"Pagination.html\">Pagination</a> configuration Object. The\n<code>Pagination</code> handles the thumbnails control.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_pagination"
     },
     "paginationEl": {
      "!type": "fn()",
      "!doc": "Element which contains the <a href=\"Pagination.html\">Pagination</a>\nwith the thumbnails.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_paginationEl"
     },
     "paginationInstance": {
      "!type": "fn()",
      "!doc": "Stores the <a href=\"Pagination.html\">Pagination</a> instance.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_paginationInstance"
     },
     "paused": {
      "!type": "fn()",
      "!doc": "If <code>true</code> the slide show is paused.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_paused"
     },
     "pausedLabel": {
      "!type": "fn()",
      "!doc": "Label to display when the slide show is paused.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_pausedLabel"
     },
     "playing": {
      "!type": "fn()",
      "!doc": "If <code>true</code> the slide show is playing.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_playing"
     },
     "playingLabel": {
      "!type": "fn()",
      "!doc": "Label to display when the slide show is playing.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_playingLabel"
     },
     "repeat": {
      "!type": "fn()",
      "!doc": "Restart the navigation when reach the last element.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_repeat"
     },
     "showPlayer": {
      "!type": "fn()",
      "!doc": "Show the player controls (i.e., pause and show buttons).",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_showPlayer"
     },
     "toolbar": {
      "!type": "fn()",
      "!doc": "<a href=\"Toolbar.html\">Toolbar</a> with a play, and pause buttons.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_toolbar"
     },
     "useOriginalImage": {
      "!type": "fn()",
      "!doc": "If <code>true</code> will use the original image as thumbnails.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#attribute_useOriginalImage"
     },
     "hidePagination": {
      "!type": "fn()",
      "!doc": "Hide the <a href=\"Pagination.html\">Pagination</a>\nwith the thumbnails list.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#method_hidePagination"
     },
     "pause": {
      "!type": "fn()",
      "!doc": "Pause the slide show.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#method_pause"
     },
     "play": {
      "!type": "fn()",
      "!doc": "Play the slide show.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#method_play"
     },
     "show": {
      "!type": "fn()",
      "!doc": "<p>Show the ImageGallery.</p>\n\n<p><strong>NOTE:</strong>Overloads the <a\nhref=\"ImageViewer.html\">ImageViewer</a> show method to not loadImage, the\nchangeRequest now is responsible to do that if we invoke the superclass\nshow method its loading the image, and the changeRequest loads again,\navoiding double request.</p>",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#method_show"
     },
     "showPagination": {
      "!type": "fn()",
      "!doc": "Show the <a href=\"Pagination.html\">Pagination</a>\nwith the thumbnails list.",
      "!url": "http://alloyui.com/classes/A.ImageGallery.html#method_showPagination"
     }
    },
    "ImageGallery.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.ImageGallery.html#property_ImageGallery.EXTENDS"
    }
   }
  },
  "aui_media_viewer_plugin": {
   "A.MediaViewerPlugin": {
    "!type": "fn(config: Object) -> +aui_media_viewer_plugin.A.MediaViewerPlugin",
    "!proto": "A.Plugin.Base",
    "!doc": "A base class for MediaViewerPlugin.\n\nCheck the [live demo](http://alloyui.com/examples/image-viewer/).",
    "!url": "http://alloyui.com/classes/A.MediaViewerPlugin.html",
    "MediaViewerPlugin.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.MediaViewerPlugin.html#property_MediaViewerPlugin.NAME"
    },
    "MediaViewerPlugin.NS": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the namespace.",
     "!url": "http://alloyui.com/classes/A.MediaViewerPlugin.html#property_MediaViewerPlugin.NS"
    },
    "MediaViewerPlugin.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the MediaViewerPlugin.",
     "!url": "http://alloyui.com/classes/A.MediaViewerPlugin.html#property_MediaViewerPlugin.ATTRS"
    },
    "prototype": {
     "providers": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.MediaViewerPlugin.html#attribute_providers"
     },
     "close": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.MediaViewerPlugin.html#method_close"
     },
     "loadMedia": {
      "!type": "fn(linkHref)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.MediaViewerPlugin.html#method_loadMedia"
     },
     "preloadImage": {
      "!type": "fn(index)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.MediaViewerPlugin.html#method_preloadImage"
     }
    },
    "MediaViewerPlugin.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.MediaViewerPlugin.html#property_MediaViewerPlugin.EXTENDS"
    }
   }
  },
  "aui_io": {
   "A.IORequest": {
    "!type": "fn(config: Object) -> +aui_io.A.IORequest",
    "!proto": "A.Plugin.Base",
    "!doc": "A base class for IORequest, providing:\n<ul>\n   <li>Response data normalization for XML, JSON, JavaScript</li>\n   <li>Cache options</li>\n</ul>\n\nCheck the [live demo](http://alloyui.com/examples/io/).",
    "!url": "http://alloyui.com/classes/A.IORequest.html",
    "IORequest.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.IORequest.html#property_IORequest.NAME"
    },
    "IORequest.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the IORequest.",
     "!url": "http://alloyui.com/classes/A.IORequest.html#property_IORequest.ATTRS"
    },
    "prototype": {
     "autoLoad": {
      "!type": "fn()",
      "!doc": "If <code>true</code> invoke the\n<a href=\"IORequest.html#method_start\">start</a> method\nautomatically, initializing the IO transaction.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_autoLoad"
     },
     "cache": {
      "!type": "fn()",
      "!doc": "If <code>false</code> the current timestamp will be appended to the\nurl, avoiding the url to be cached.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_cache"
     },
     "dataType": {
      "!type": "fn()",
      "!doc": "The type of the request (i.e., could be xml, json, javascript, text).",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_dataType"
     },
     "responseData": {
      "!type": "fn()",
      "!doc": "This is a normalized attribute for the response data. It's useful\nto retrieve the correct type for the\n<a href=\"IORequest.html#config_dataType\">dataType</a> (i.e., in json\nrequests the <code>responseData</code>) is a JSONObject.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_responseData"
     },
     "uri": {
      "!type": "fn()",
      "!doc": "URI to be requested using AJAX.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_uri"
     },
     "active": {
      "!type": "fn()",
      "!doc": "Whether the transaction is active or not.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_active"
     },
     "cfg": {
      "!type": "fn()",
      "!doc": "Object containing all the\n<a href=\"io.html#configattributes\">IO Configuration Attributes</a>.\nThis Object is passed to the <code>A.io</code> internally.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_cfg"
     },
     "transaction": {
      "!type": "fn()",
      "!doc": "Stores the IO Object of the current transaction.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_transaction"
     },
     "arguments": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_arguments"
     },
     "context": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_context"
     },
     "data": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_data"
     },
     "form": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_form"
     },
     "headers": {
      "!type": "fn()",
      "!doc": "Set the correct ACCEPT header based on the dataType.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_headers"
     },
     "method": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_method"
     },
     "selector": {
      "!type": "fn()",
      "!doc": "A selector to be used to query against the response of the\nrequest. Only works if the response is XML or HTML.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_selector"
     },
     "sync": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_sync"
     },
     "timeout": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_timeout"
     },
     "xdr": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#attribute_xdr"
     },
     "getFormattedData": {
      "!type": "fn() -> string",
      "!doc": "Applies the <code>YUI.AUI.defaults.io.dataFormatter</code> if\ndefined and return the formatted data.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#method_getFormattedData"
     },
     "start": {
      "!type": "fn()",
      "!doc": "Starts the IO transaction. Used to refresh the content also.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#method_start"
     },
     "stop": {
      "!type": "fn()",
      "!doc": "Stops the IO transaction.",
      "!url": "http://alloyui.com/classes/A.IORequest.html#method_stop"
     }
    },
    "IORequest.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.IORequest.html#property_IORequest.EXTENDS"
    }
   },
   "A.io": {
    "!type": "fn()",
    "!doc": "Alloy IO extension",
    "!url": "http://alloyui.com/classes/A.io.html",
    "prototype": {
     "A.io.request": {
      "!type": "fn(uri: string, config: Object) -> +aui_io.IORequest",
      "!doc": "Static method to invoke the <a href=\"IORequest.html\">IORequest</a>. Likewise <a href=\"io.html#method_io\">io</a>.",
      "!url": "http://alloyui.com/classes/A.io.html#method_A.io.request"
     }
    }
   },
   "A.Plugin.IO": {
    "!type": "fn(config: Object) -> +aui_io.A.Plugin.IO",
    "!proto": "aui_io.IORequest",
    "!doc": "A base class for IOPlugin, providing:\n<ul>\n   <li>Loads the content of a URI as content of a Node or Widget</li>\n   <li>Use <a href=\"ParseContent.html\">ParseContent</a> to parse the JavaScript tags from the content and evaluate them</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>A.one('#content').plug(A.Plugin.IO, { uri: 'assets/content.html', method: 'GET' });</code></pre>\n\nCheck the list of <a href=\"A.Plugin.IO.html#configattributes\">Configuration Attributes</a> available for\nIOPlugin.",
    "!url": "http://alloyui.com/classes/A.Plugin.IO.html",
    "A.Plugin.IO.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Plugin.IO.html#property_A.Plugin.IO.NAME"
    },
    "A.Plugin.IO.NS": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the namespace.",
     "!url": "http://alloyui.com/classes/A.Plugin.IO.html#property_A.Plugin.IO.NS"
    },
    "A.Plugin.IO.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the A.Plugin.IO.",
     "!url": "http://alloyui.com/classes/A.Plugin.IO.html#property_A.Plugin.IO.ATTRS"
    },
    "prototype": {
     "node": {
      "!type": "fn()",
      "!doc": "Plug IO in any object we want, the setContent will use the node to\nset the content.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#attribute_node"
     },
     "failureMessage": {
      "!type": "fn()",
      "!doc": "Message to be set on the content when the transaction fails.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#attribute_failureMessage"
     },
     "loadingMask": {
      "!type": "fn()",
      "!doc": "Options passed to the <a href=\"LoadingMask.html\">LoadingMask</a>.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#attribute_loadingMask"
     },
     "parseContent": {
      "!type": "fn()",
      "!doc": "If true the <a href=\"ParseContent.html\">ParseContent</a> plugin\nwill be plugged to the <a href=\"A.Plugin.IO.html#config_node\">node</a>.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#attribute_parseContent"
     },
     "showLoading": {
      "!type": "fn()",
      "!doc": "Invoke the <a href=\"OverlayMask.html#method_show\">OverlayMask show</a> method.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#method_showLoading"
     },
     "section": {
      "!type": "fn()",
      "!doc": "Section where the content will be set in case you are plugging it\non a instace of <a href=\"WidgetStdMod.html\">WidgetStdMod</a>.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#attribute_section"
     },
     "type": {
      "!type": "fn()",
      "!doc": "Type of the <code>instance</code> we are pluggin the A.Plugin.IO.\nCould be a Node, or a Widget.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#attribute_type"
     },
     "where": {
      "!type": "fn()",
      "!doc": "Where to insert the content, AFTER, BEFORE or REPLACE. If you're plugging a Node, there is a fourth option called OUTER that will not only replace the entire node itself. This is different from REPLACE, in that REPLACE will replace the *contents* of the node, OUTER will replace the entire Node itself.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#attribute_where"
     },
     "hideLoading": {
      "!type": "fn()",
      "!doc": "Invoke the <a href=\"OverlayMask.html#method_hide\">OverlayMask hide</a> method.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#method_hideLoading"
     },
     "setContent": {
      "!type": "fn()",
      "!doc": "Set the content of the <a href=\"A.Plugin.IO.html#config_node\">node</a>.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#method_setContent"
     },
     "start": {
      "!type": "fn()",
      "!doc": "Overload to the <a href=\"IORequest.html#method_start\">IORequest\nstart</a> method. Check if the <code>host</code> is already rendered,\notherwise wait to after render phase and to show the LoadingMask.",
      "!url": "http://alloyui.com/classes/A.Plugin.IO.html#method_start"
     }
    }
   },
   "IORequest": {
    "!type": "fn(config: Object) -> +aui_io.IORequest",
    "!proto": "Plugin.Base",
    "!doc": "A base class for IORequest, providing:\n<ul>\n   <li>Response data normalization for XML, JSON, JavaScript</li>\n   <li>Cache options</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>A.io.request(uri, config);</code></pre>\n\nCheck the list of <a href=\"IORequest.html#configattributes\">Configuration Attributes</a> available for\nIORequest.",
    "!url": "http://alloyui.com/classes/IORequest.html",
    "IORequest.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/IORequest.html#property_IORequest.NAME"
    },
    "IORequest.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the IORequest.",
     "!url": "http://alloyui.com/classes/IORequest.html#property_IORequest.ATTRS"
    },
    "prototype": {
     "autoLoad": {
      "!type": "fn()",
      "!doc": "If <code>true</code> invoke the\n<a href=\"IORequest.html#method_start\">start</a> method automatically,\ninitializing the IO transaction.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_autoLoad"
     },
     "cache": {
      "!type": "fn()",
      "!doc": "If <code>false</code> the current timestamp will be appended to the\nurl, avoiding the url to be cached.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_cache"
     },
     "dataType": {
      "!type": "fn()",
      "!doc": "The type of the request (i.e., could be xml, json, javascript, text).",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_dataType"
     },
     "responseData": {
      "!type": "fn()",
      "!doc": "This is a normalized attribute for the response data. It's useful\nto retrieve the correct type for the\n<a href=\"IORequest.html#config_dataType\">dataType</a> (i.e., in json\nrequests the <code>responseData</code>) is a JSONObject.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_responseData"
     },
     "uri": {
      "!type": "fn()",
      "!doc": "URI to be requested using AJAX.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_uri"
     },
     "active": {
      "!type": "fn()",
      "!doc": "Whether the transaction is active or not.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_active"
     },
     "cfg": {
      "!type": "fn()",
      "!doc": "Object containing all the\n<a href=\"io.html#configattributes\">IO Configuration Attributes</a>.\nThis Object is passed to the <code>A.io</code> internally.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_cfg"
     },
     "transaction": {
      "!type": "fn()",
      "!doc": "Stores the IO Object of the current transaction.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_transaction"
     },
     "arguments": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_arguments"
     },
     "context": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_context"
     },
     "data": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_data"
     },
     "form": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_form"
     },
     "headers": {
      "!type": "fn()",
      "!doc": "Set the correct ACCEPT header based on the dataType.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_headers"
     },
     "method": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_method"
     },
     "selector": {
      "!type": "fn()",
      "!doc": "A selector to be used to query against the response of the\nrequest. Only works if the response is XML or HTML.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_selector"
     },
     "sync": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_sync"
     },
     "timeout": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_timeout"
     },
     "xdr": {
      "!type": "fn()",
      "!doc": "See <a href=\"http://developer.yahoo.com/yui/3/io/#configuration\">IO\nConfiguration</a>.",
      "!url": "http://alloyui.com/classes/IORequest.html#attribute_xdr"
     },
     "start": {
      "!type": "fn()",
      "!doc": "Starts the IO transaction. Used to refresh the content also.",
      "!url": "http://alloyui.com/classes/IORequest.html#method_start"
     },
     "stop": {
      "!type": "fn()",
      "!doc": "Stops the IO transaction.",
      "!url": "http://alloyui.com/classes/IORequest.html#method_stop"
     }
    }
   }
  },
  "aui_live_search": {
   "LiveSearch": {
    "!type": "fn(config: Object) -> +aui_live_search.LiveSearch",
    "!proto": "Base",
    "!doc": "<p><img src=\"assets/images/aui-live-search/main.png\"/></p>\n\nA base class for LiveSearch, providing:\n<ul>\n   <li>Real-time filtering for DOM elements based on a input query</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var instance = new A.LiveSearch({\n\tinput: '#input',\n\tnodes: '#search .entry'\n});\n</code></pre>\n\nCheck the list of <a href=\"LiveSearch.html#configattributes\">Configuration Attributes</a> available for\nLiveSearch.",
    "!url": "http://alloyui.com/classes/LiveSearch.html",
    "LiveSearch.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/LiveSearch.html#property_LiveSearch.NAME"
    },
    "LiveSearch.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the LiveSearch.",
     "!url": "http://alloyui.com/classes/LiveSearch.html#property_LiveSearch.ATTRS"
    },
    "prototype": {
     "data": {
      "!type": "fn()",
      "!doc": "<p>Function to extract the content from the node for the indexing. The\ndefault uses the <code>node.html()</code>. In case if you need to\nindex the id of the nodes, here goes one example:</p>\n\nExample indexing the id of the node instead of the HTML:\n\n<pre><code>function(node) {\n return node.attr('id');\n}\n</code></pre>",
      "!url": "http://alloyui.com/classes/LiveSearch.html#attribute_data"
     },
     "delay": {
      "!type": "fn()",
      "!doc": "Number of milliseconds the filter will be applied to the node list\nafter the user stop typing.",
      "!url": "http://alloyui.com/classes/LiveSearch.html#attribute_delay"
     },
     "hide": {
      "!type": "fn()",
      "!doc": "Function to be executed to hide the node when the data of that node\nnot matches with the filter.",
      "!url": "http://alloyui.com/classes/LiveSearch.html#attribute_hide"
     },
     "index": {
      "!type": "fn()",
      "!doc": "Index for the nodes content.",
      "!url": "http://alloyui.com/classes/LiveSearch.html#attribute_index"
     },
     "input": {
      "!type": "fn()",
      "!doc": "The <code>value</code> of this input node is used to filter the\nresults.",
      "!url": "http://alloyui.com/classes/LiveSearch.html#attribute_input"
     },
     "matchRegex": {
      "!type": "fn()",
      "!doc": "The input <code>value</code> need to matches with this RegExp to be\naccept as a filter (i.e., in order to accept only digits you\ncould use /\\d+/g).",
      "!url": "http://alloyui.com/classes/LiveSearch.html#attribute_matchRegex"
     },
     "nodes": {
      "!type": "fn()",
      "!doc": "Nodes to be indexed for the filtering.",
      "!url": "http://alloyui.com/classes/LiveSearch.html#attribute_nodes"
     },
     "searchValue": {
      "!type": "fn()",
      "!doc": "The text value to search for",
      "!url": "http://alloyui.com/classes/LiveSearch.html#attribute_searchValue"
     },
     "show": {
      "!type": "fn()",
      "!doc": "Function to be executed to show the node when the data of that node\nmatches with the filter.",
      "!url": "http://alloyui.com/classes/LiveSearch.html#attribute_show"
     },
     "filter": {
      "!type": "fn(query: string) -> +Array",
      "!doc": "Filter the <a href=\"LiveSearch.html#config_nodes\">nodes</a> based on\nthe input value.",
      "!url": "http://alloyui.com/classes/LiveSearch.html#method_filter"
     },
     "refreshIndex": {
      "!type": "fn()",
      "!doc": "Refreshes the <a href=\"LiveSearch.html#config_index\">index</a>.",
      "!url": "http://alloyui.com/classes/LiveSearch.html#method_refreshIndex"
     },
     "search": {
      "!type": "fn(value: string)",
      "!doc": "Searches for the user supplied value.",
      "!url": "http://alloyui.com/classes/LiveSearch.html#method_search"
     }
    }
   }
  },
  "aui_loading_mask": {
   "LoadingMask": {
    "!type": "fn(config: Object) -> +aui_loading_mask.LoadingMask",
    "!proto": "Plugin.Base",
    "!doc": "<p><img src=\"assets/images/aui-loading-mask/main.png\"/></p>\n\nA base class for LoadingMask, providing:\n<ul>\n   <li>Cross browser mask functionality to cover an element or the entire page</li>\n   <li>Customizable mask (i.e., background, opacity)</li>\n   <li>Display a centered \"loading\" message on the masked node</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>node.plug(A.LoadingMask, { background: '#000' });</code></pre>\n\nCheck the list of <a href=\"LoadingMask.html#configattributes\">Configuration Attributes</a> available for\nLoadingMask.",
    "!url": "http://alloyui.com/classes/LoadingMask.html",
    "LoadingMask.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/LoadingMask.html#property_LoadingMask.NAME"
    },
    "LoadingMask.NS": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the namespace.",
     "!url": "http://alloyui.com/classes/LoadingMask.html#property_LoadingMask.NS"
    },
    "LoadingMask.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the LoadingMask.",
     "!url": "http://alloyui.com/classes/LoadingMask.html#property_LoadingMask.ATTRS"
    },
    "prototype": {
     "messageEl": {
      "!type": "fn()",
      "!doc": "Node element to display the message.",
      "!url": "http://alloyui.com/classes/LoadingMask.html#attribute_messageEl"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "Strings used on the LoadingMask. See\n<a href=\"Widget.html#method_strings\">strings</a>.",
      "!url": "http://alloyui.com/classes/LoadingMask.html#attribute_strings"
     },
     "target": {
      "!type": "fn()",
      "!doc": "Node where the mask will be positioned and re-dimensioned.",
      "!url": "http://alloyui.com/classes/LoadingMask.html#attribute_target"
     },
     "centerMessage": {
      "!type": "fn()",
      "!doc": "Center the\n<a href=\"LoadingMask.html#config_messageEl\">messageEl</a> with the\n<a href=\"LoadingMask.html#config_target\">target</a> node.",
      "!url": "http://alloyui.com/classes/LoadingMask.html#method_centerMessage"
     },
     "refreshMask": {
      "!type": "fn()",
      "!doc": "Invoke the\n<a href=\"LoadingMask.html#property_overlayMask\">overlayMask</a>\n<code>refreshMask</code> method.",
      "!url": "http://alloyui.com/classes/LoadingMask.html#method_refreshMask"
     },
     "hide": {
      "!type": "fn()",
      "!doc": "Invoke the\n<a href=\"LoadingMask.html#property_overlayMask\">overlayMask</a>\n<code>hide</code> method.",
      "!url": "http://alloyui.com/classes/LoadingMask.html#method_hide"
     },
     "show": {
      "!type": "fn()",
      "!doc": "Invoke the\n<a href=\"LoadingMask.html#property_overlayMask\">overlayMask</a>\n<code>show</code> method.",
      "!url": "http://alloyui.com/classes/LoadingMask.html#method_show"
     },
     "toggle": {
      "!type": "fn()",
      "!doc": "Invoke the\n<a href=\"LoadingMask.html#property_overlayMask\">overlayMask</a>\n<code>toggle</code> method.",
      "!url": "http://alloyui.com/classes/LoadingMask.html#method_toggle"
     }
    }
   }
  },
  "aui_modal": {
   "A.Modal": {
    "!type": "fn(config: Object) -> +aui_modal.A.Modal",
    "!proto": "A.Widget",
    "!doc": "A base class for Modal.\n\nCheck the [live demo](http://alloyui.com/examples/modal/).",
    "!url": "http://alloyui.com/classes/A.Modal.html",
    "Modal.CSS_PREFIX": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the CSS prefix.",
     "!url": "http://alloyui.com/classes/A.Modal.html#property_Modal.CSS_PREFIX"
    },
    "Modal.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Modal.",
     "!url": "http://alloyui.com/classes/A.Modal.html#property_Modal.ATTRS"
    },
    "prototype": {
     "bodyContent": {
      "!type": "fn()",
      "!doc": "Determine the content of Modal's body section.\n\nTemporary fix for widget-stdmod bug when bodyContent initializes empty.\nthis._currFillNode is never updated if _uiSetFillHeight is not called.",
      "!url": "http://alloyui.com/classes/A.Modal.html#attribute_bodyContent"
     },
     "destroyOnHide": {
      "!type": "fn()",
      "!doc": "Determine if Modal should be destroyed when hidden.",
      "!url": "http://alloyui.com/classes/A.Modal.html#attribute_destroyOnHide"
     },
     "draggable": {
      "!type": "fn()",
      "!doc": "Determine if Modal should be draggable or not.",
      "!url": "http://alloyui.com/classes/A.Modal.html#attribute_draggable"
     },
     "resizable": {
      "!type": "fn()",
      "!doc": "Determine if Modal should be resizable or not.",
      "!url": "http://alloyui.com/classes/A.Modal.html#attribute_resizable"
     },
     "toolbars": {
      "!type": "fn()",
      "!doc": "Determine the content of Modal's header section.",
      "!url": "http://alloyui.com/classes/A.Modal.html#attribute_toolbars"
     }
    },
    "Modal.TEMPLATES": {
     "!type": "+Object",
     "!doc": "Static property provides a set of reusable templates.",
     "!url": "http://alloyui.com/classes/A.Modal.html#property_Modal.TEMPLATES"
    }
   }
  },
  "aui_node": {
   "A.Node": {
    "!type": "fn() -> +aui_node.A.Node",
    "!doc": "Augment the <a href=\"Node.html\">YUI3 Node</a> with more util methods.\n\nCheck the [live demo](http://alloyui.com/examples/node/).",
    "!url": "http://alloyui.com/classes/A.Node.html",
    "prototype": {
     "ancestors": {
      "!type": "fn(selector: string) -> +NodeList",
      "!doc": "Return the current ancestors of the node element. If a selector is\nspecified, the ancestors are filtered to match the selector.\n\nExample:\n\n<pre><code>\nA.one('#nodeId').ancestors('div');\n</code></pre>",
      "!url": "http://alloyui.com/classes/A.Node.html#method_ancestors"
     },
     "ancestorsByClassName": {
      "!type": "fn(className: string) -> +NodeList",
      "!doc": "Return the current ancestors of the node element filtered by a className.\nThis is an optimized method for finding ancestors by a specific CSS class name.\n\nExample:\n\n<pre><code>\nA.one('#nodeId').ancestorsByClassName('aui-hide');\n</code></pre>",
      "!url": "http://alloyui.com/classes/A.Node.html#method_ancestorsByClassName"
     },
     "attr": {
      "!type": "fn(name: string, value: string) -> string",
      "!doc": "Get or Set the value of an attribute for the first element in the\nset of matched elements. If only the <code>name</code> is passed it\nworks as a getter.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.attr('title', 'Setting a new title attribute');\n// Alert the value of the title attribute: 'Setting a new title attribute'\nalert( node.attr('title') );\n</code></pre>",
      "!url": "http://alloyui.com/classes/A.Node.html#method_attr"
     },
     "clone": {
      "!type": "fn() -> +aui_node.Node",
      "!doc": "Normalizes the behavior of cloning a node, which by default should not clone\nthe events that are attached to it.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.clone().appendTo('body');\n</code></pre>",
      "!url": "http://alloyui.com/classes/A.Node.html#method_clone"
     },
     "center": {
      "!type": "fn(val: Array) -> !this",
      "!doc": "Centralize the current Node instance with the passed <code>val</code>\nArray, Node, String, or Region, if not specified, the body will be used.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\n// Center the <code>node</code> with the <code>#container</code>.\nnode.center('#container');\n</code></pre>",
      "!url": "http://alloyui.com/classes/A.Node.html#method_center"
     },
     "empty": {
      "!type": "fn() -> !this",
      "!doc": "This method removes not only child (and other descendant) elements,\nbut also any text within the set of matched elements. This is because,\naccording to the DOM specification, any string of text within an element\nis considered a child node of that element.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.empty();\n</code></pre>",
      "!url": "http://alloyui.com/classes/A.Node.html#method_empty"
     },
     "getDOM": {
      "!type": "fn() -> +HTMLNode",
      "!doc": "Retrieves the DOM node bound to a Node instance. See\n<a href=\"Node.html#method_getDOMNode\">getDOMNode</a>.",
      "!url": "http://alloyui.com/classes/A.Node.html#method_getDOM"
     },
     "getBorderWidth": {
      "!type": "fn(sides: string) -> number",
      "!doc": "Return the combined width of the border for the specified sides.",
      "!url": "http://alloyui.com/classes/A.Node.html#method_getBorderWidth"
     }
    }
   },
   "Node": {
    "!type": "fn()",
    "!url": "http://alloyui.com/classes/Node.html",
    "prototype": {
     "getCenterXY": {
      "!type": "fn() -> +Array",
      "!doc": "Get the current center position of the node in page coordinates.",
      "!url": "http://alloyui.com/classes/Node.html#method_getCenterXY"
     },
     "getMargin": {
      "!type": "fn(sides: string) -> number",
      "!doc": "Return the combined size of the margin for the specified sides.",
      "!url": "http://alloyui.com/classes/Node.html#method_getMargin"
     },
     "getPadding": {
      "!type": "fn(sides: string) -> number",
      "!doc": "Return the combined width of the border for the specified sides.",
      "!url": "http://alloyui.com/classes/Node.html#method_getPadding"
     },
     "guid": {
      "!type": "fn() -> string",
      "!doc": "Set the id of the Node instance if the object does not have one. The\ngenerated id is based on a guid created by the\n<a href=\"YUI.html#method_stamp\">stamp</a> method.",
      "!url": "http://alloyui.com/classes/Node.html#method_guid"
     },
     "hover": {
      "!type": "fn(overFn: string, outFn: string) -> +aui_node.Node",
      "!doc": "Create a hover interaction.",
      "!url": "http://alloyui.com/classes/Node.html#method_hover"
     },
     "html": {
      "!type": "fn(value: string)",
      "!doc": "Get or Set the HTML contents of the node. If the <code>value</code>\nis passed it's set the content of the element, otherwise it works as a\ngetter for the current content.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.html('Setting new HTML');\n// Alert the value of the current content\nalert( node.html() );\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_html"
     },
     "outerHTML": {
      "!type": "fn() -> string",
      "!doc": "Get the outerHTML of a node, which islike innerHTML, except that it\nactually contains the HTML of the node itself.",
      "!url": "http://alloyui.com/classes/Node.html#method_outerHTML"
     },
     "placeAfter": {
      "!type": "fn(newNode: aui_node.Node) -> !this",
      "!doc": "Inserts a <code>newNode</code> after the node instance (i.e., as the next\nsibling). If the reference node has no parent, then does nothing.\n\nExample:\n\n<pre><code>var titleNode = A.one('#titleNode');\nvar descriptionNode = A.one('#descriptionNode');\n// the description is usually shown after the title\ntitleNode.placeAfter(descriptionNode);\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_placeAfter"
     },
     "placeBefore": {
      "!type": "fn(newNode: aui_node.Node) -> !this",
      "!doc": "Inserts a <code>newNode</code> before the node instance (i.e., as the previous\nsibling). If the reference node has no parent, then does nothing.\n\nExample:\n\n<pre><code>var descriptionNode = A.one('#descriptionNode');\nvar titleNode = A.one('#titleNode');\n// the title is usually shown before the description\ndescriptionNode.placeBefore(titleNode);\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_placeBefore"
     },
     "prependTo": {
      "!type": "fn(selector: aui_node.Node) -> !this",
      "!doc": "Inserts the node instance to the begining of the <code>selector</code>\nnode (i.e., insert before the <code>firstChild</code> of the\n<code>selector</code>).\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.prependTo('body');\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_prependTo"
     },
     "radioClass": {
      "!type": "fn(cssClass: string) -> !this",
      "!doc": "Add one or more CSS classes to an element and remove the class(es)\nfrom the siblings of the element.",
      "!url": "http://alloyui.com/classes/Node.html#method_radioClass"
     },
     "resetId": {
      "!type": "fn(prefix: string) -> !this",
      "!doc": "Generate an unique identifier and reset the id attribute of the node\ninstance using the new value. Invokes the\n<a href=\"Node.html#method_guid\">guid</a>.",
      "!url": "http://alloyui.com/classes/Node.html#method_resetId"
     },
     "selectText": {
      "!type": "fn(start: number, end: number)",
      "!doc": "Select a substring of text inside of the input element.",
      "!url": "http://alloyui.com/classes/Node.html#method_selectText"
     },
     "selectable": {
      "!type": "fn(noRecurse) -> !this",
      "!doc": "Enable text selection for this element (normalized across browsers).",
      "!url": "http://alloyui.com/classes/Node.html#method_selectable"
     },
     "swallowEvent": {
      "!type": "fn(eventName: string, preventDefault: bool) -> !this",
      "!doc": "Stop the specified event(s) from bubbling and optionally prevents the\ndefault action.\n\nExample:\n\n<pre><code>var anchor = A.one('a#anchorId');\nanchor.swallowEvent('click');\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_swallowEvent"
     },
     "text": {
      "!type": "fn(text: string)",
      "!doc": "Get or Set the combined text contents of the node instance,\nincluding it's descendants. If the <code>text</code>\nis passed it's set the content of the element, otherwise it works as a\ngetter for the current content.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.text('Setting new text content');\n// Alert the value of the current content\nalert( node.text() );\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_text"
     },
     "toggle": {
      "!type": "fn(on: bool, callback: fn()) -> !this",
      "!doc": "Displays or hide the node instance.\n\nNOTE: This method assume that your node were hidden\nbecause of the 'aui-hide' css class were being used. This won't\nmanipulate the inline <code>style.display</code> property.",
      "!url": "http://alloyui.com/classes/Node.html#method_toggle"
     },
     "unselectable": {
      "!type": "fn(noRecurse) -> !this",
      "!doc": "Disable text selection for this element (normalized across browsers).",
      "!url": "http://alloyui.com/classes/Node.html#method_unselectable"
     },
     "val": {
      "!type": "fn(value: string)",
      "!doc": "Get or Set the value attribute of the node instance. If the\n<code>value</code> is passed it's set the value of the element,\notherwise it works as a getter for the current value.\n\nExample:\n\n<pre><code>var input = A.one('#inputId');\ninput.val('Setting new input value');\n// Alert the value of the input\nalert( input.val() );\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_val"
     },
     "width": {
      "!type": "fn() -> number",
      "!doc": "Return the width of the content, not including\nthe padding, border or margin. If a width is passed,\nthe node's overall width is set to that size.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.width(); //return content width\nnode.width(100); // sets box width\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_width"
     },
     "height": {
      "!type": "fn() -> number",
      "!doc": "Return the height of the content, not including\nthe padding, border or margin. If a height is passed,\nthe node's overall height is set to that size.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.height(); //return content height\nnode.height(100); // sets box height\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_height"
     },
     "innerWidth": {
      "!type": "fn() -> number",
      "!doc": "Return the size of the box from inside of the border,\nwhich is the offsetWidth plus the padding on the left and right.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.innerWidth();\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_innerWidth"
     },
     "innerHeight": {
      "!type": "fn() -> number",
      "!doc": "Return the size of the box from inside of the border,\nwhich is offsetHeight plus the padding on the top and bottom.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.innerHeight();\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_innerHeight"
     },
     "outerWidth": {
      "!type": "fn() -> number",
      "!doc": "Return the outer width of the box including the border,\nif true is passed as the first argument, the margin is included.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.outerWidth();\nnode.outerWidth(true); // includes margin\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_outerWidth"
     },
     "outerHeight": {
      "!type": "fn() -> number",
      "!doc": "Return the outer height of the box including the border,\nif true is passed as the first argument, the margin is included.\n\nExample:\n\n<pre><code>var node = A.one('#nodeId');\nnode.outerHeight();\nnode.outerHeight(true); // includes margin\n</code></pre>",
      "!url": "http://alloyui.com/classes/Node.html#method_outerHeight"
     }
    }
   },
   "A.NodeList": {
    "!type": "fn() -> +aui_node.A.NodeList",
    "!doc": "Augment the <a href=\"NodeList.html\">YUI3 NodeList</a> with more util methods.\n\nCheck the list of <a href=\"NodeList.html#methods\">Methods</a> available for\nAUI NodeList.",
    "!url": "http://alloyui.com/classes/A.NodeList.html",
    "prototype": {
     "all": {
      "!type": "fn()",
      "!doc": "See <a href=\"Node.html#method_all\">Node all</a>.",
      "!url": "http://alloyui.com/classes/A.NodeList.html#method_all"
     },
     "first": {
      "!type": "fn() -> +aui_node.Node",
      "!doc": "Return the first element in the node list collection.",
      "!url": "http://alloyui.com/classes/A.NodeList.html#method_first"
     },
     "getDOM": {
      "!type": "fn()",
      "!doc": "See <a href=\"Node.html#method_getDOM\">Node getDOM</a>.",
      "!url": "http://alloyui.com/classes/A.NodeList.html#method_getDOM"
     },
     "last": {
      "!type": "fn() -> +aui_node.Node",
      "!doc": "Return the last element in the node list collection.",
      "!url": "http://alloyui.com/classes/A.NodeList.html#method_last"
     },
     "one": {
      "!type": "fn()",
      "!doc": "See <a href=\"Node.html#method_one\">Node one</a>.",
      "!url": "http://alloyui.com/classes/A.NodeList.html#method_one"
     },
     "getBody": {
      "!type": "fn()",
      "!doc": "Get the body node. Shortcut to <code>A.one('body')</code>.",
      "!url": "http://alloyui.com/classes/A.NodeList.html#method_getBody"
     },
     "getDoc": {
      "!type": "fn()",
      "!doc": "Get the document node. Shortcut to <code>A.one(document)</code>.",
      "!url": "http://alloyui.com/classes/A.NodeList.html#method_getDoc"
     },
     "getWin": {
      "!type": "fn()",
      "!doc": "Get the window node. Shortcut to <code>A.one(window)</code>.",
      "!url": "http://alloyui.com/classes/A.NodeList.html#method_getWin"
     }
    }
   },
   "A.HTML5": {
    "!type": "fn()",
    "!doc": "<p>An object that encapsulates util methods for HTML5 shiving.</p>\n<h2>What is a \"shiv\"?</h1>\n<p>To the world, a shiv is a slang term for a sharp object used as a\nknife-like weapon. To Internet Explorer, a shiv is a script that, when\nexecuted, forces the browser to recognize HTML5 elements.</p>",
    "!url": "http://alloyui.com/classes/A.HTML5.html",
    "prototype": {
     "onAfterPrint": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HTML5.html#method_onAfterPrint"
     },
     "onBeforePrint": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HTML5.html#method_onBeforePrint"
     },
     "parseCSS": {
      "!type": "fn(cssText)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HTML5.html#method_parseCSS"
     },
     "restoreHTML": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HTML5.html#method_restoreHTML"
     },
     "writeHTML": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.HTML5.html#method_writeHTML"
     },
     "IECreateFix": {
      "!type": "fn(frag: aui_node.Node, content: string) -> +aui_node.Node",
      "!doc": "Receive a <code>frag</code> and a HTML content. This method\nshivs the HTML5 nodes appended to a Node or fragment which is not\non the document yet.",
      "!url": "http://alloyui.com/classes/A.HTML5.html#method_IECreateFix"
     }
    }
   }
  },
  "aui_overlay": {
   "OverlayContext": {
    "!type": "fn(config: Object) -> +aui_overlay.OverlayContext",
    "!proto": "aui_overlay.OverlayBase",
    "!doc": "<p><img src=\"assets/images/aui-overlay-context/main.png\"/></p>\n\nA base class for OverlayContext, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Able to display an <a href=\"Overlay.html\">Overlay</a> at a specified corner of an element <a href=\"OverlayContext.html#config_trigger\">trigger</a></li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var instance = new A.OverlayContext({\n boundingBox: '#OverlayBoundingBox',\n hideOn: 'mouseleave',\n showOn: 'mouseenter',\n\ttrigger: '.menu-trigger'\n}).render();\n</code></pre>\n\nCheck the list of <a href=\"OverlayContext.html#configattributes\">Configuration Attributes</a> available for\nOverlayContext.",
    "!url": "http://alloyui.com/classes/OverlayContext.html",
    "OverlayContext.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/OverlayContext.html#property_OverlayContext.NAME"
    },
    "OverlayContext.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the OverlayContext.",
     "!url": "http://alloyui.com/classes/OverlayContext.html#property_OverlayContext.ATTRS"
    },
    "prototype": {
     "align": {
      "!type": "fn()",
      "!doc": "Inherited from <a href=\"Overlay.html#config_align\">Overlay</a>.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_align"
     },
     "cancellableHide": {
      "!type": "fn()",
      "!doc": "Cancel auto hide delay if the user interact with the Overlay\n(focus, click, mouseover)",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_cancellableHide"
     },
     "currentNode": {
      "!type": "fn()",
      "!doc": "OverlayContext allow multiple elements to be the\n<a href=\"OverlayContext.html#config_trigger\">trigger</a>, the\ncurrentNode stores the current active one.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_currentNode"
     },
     "hideOn": {
      "!type": "fn()",
      "!doc": "The event which is responsible to hide the OverlayContext.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_hideOn"
     },
     "hideOnDocumentClick": {
      "!type": "fn()",
      "!doc": "If true the instance is registered on the\n<a href=\"OverlayContextManager.html\">OverlayContextManager</a> static\nclass and will be hide when the user click on document.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_hideOnDocumentClick"
     },
     "hideDelay": {
      "!type": "fn()",
      "!doc": "Number of milliseconds after the hide method is invoked to hide the\nOverlayContext.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_hideDelay"
     },
     "showOn": {
      "!type": "fn()",
      "!doc": "The event which is responsible to show the OverlayContext.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_showOn"
     },
     "showDelay": {
      "!type": "fn()",
      "!doc": "Number of milliseconds after the show method is invoked to show the\nOverlayContext.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_showDelay"
     },
     "trigger": {
      "!type": "fn()",
      "!doc": "Node, NodeList or Selector which will be used as trigger elements\nto show or hide the OverlayContext.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_trigger"
     },
     "useARIA": {
      "!type": "fn()",
      "!doc": "True if Overlay should use ARIA plugin",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_useARIA"
     },
     "visible": {
      "!type": "fn()",
      "!doc": "If true the OverlayContext is visible by default after the render phase.\nInherited from <a href=\"Overlay.html\">Overlay</a>.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#attribute_visible"
     },
     "hide": {
      "!type": "fn()",
      "!doc": "Shows the OverlayContext.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#method_hide"
     },
     "toggle": {
      "!type": "fn(event: EventFacade)",
      "!doc": "Toggles visibility of the OverlayContext.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#method_toggle"
     },
     "clearIntervals": {
      "!type": "fn()",
      "!doc": "Clear the intervals to show or hide the OverlayContext. See\n<a href=\"OverlayContext.html#config_hideDelay\">hideDelay</a> and\n<a href=\"OverlayContext.html#config_showDelay\">showDelay</a>.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#method_clearIntervals"
     },
     "refreshAlign": {
      "!type": "fn()",
      "!doc": "Refreshes the alignment of the OverlayContext with the\n<a href=\"OverlayContext.html#config_currentNode\">currentNode</a>. See\nalso <a href=\"OverlayContext.html#config_align\">align</a>.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#method_refreshAlign"
     },
     "updateCurrentNode": {
      "!type": "fn(event: EventFacade)",
      "!doc": "Update the\n<a href=\"OverlayContext.html#config_currentNode\">currentNode</a> with the\n<a href=\"OverlayContext.html#config_align\">align</a> node or the\nevent.currentTarget and in last case with the first item of the\n<a href=\"OverlayContext.html#config_trigger\">trigger</a>.",
      "!url": "http://alloyui.com/classes/OverlayContext.html#method_updateCurrentNode"
     }
    }
   },
   "OverlayContextPanel": {
    "!type": "fn(config: Object) -> +aui_overlay.OverlayContextPanel",
    "!proto": "aui_overlay.OverlayContext",
    "!doc": "<p><img src=\"assets/images/aui-overlay-context-panel/main.png\"/></p>\n\nA base class for OverlayContextPanel, providing:\n<ul>\n\t<li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n\t<li>Customizable arrow</li>\n\t<li>Optional animation when show or hide</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var instance = new A.OverlayContextPanel({\n bodyContent: 'Here s a sample OverlayContextPanel.',\n boundingBox: '#overlay-context-panel',\n trigger: '#triggerButton',\n cancellableHide: true,\n hideDelay: 200,\n hideOnDocumentClick: false,\n anim: true\n}).render();\n</code></pre>\n\nCheck the list of <a href=\"OverlayContextPanel.html#configattributes\">Configuration Attributes</a> available for\nOverlayContextPanel.",
    "!url": "http://alloyui.com/classes/OverlayContextPanel.html",
    "OverlayContextPanel.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/OverlayContextPanel.html#property_OverlayContextPanel.NAME"
    },
    "OverlayContextPanel.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the OverlayContextPanel.",
     "!url": "http://alloyui.com/classes/OverlayContextPanel.html#property_OverlayContextPanel.ATTRS"
    },
    "prototype": {
     "anim": {
      "!type": "fn()",
      "!doc": "Enable or disable the animation for hide and show. Used as the\n<a href=\"Anim.html\">Anim</a> configuration attributes.\n\n<pre><code>anim: {\n show: {\n \tduration: .9\n },\n hide: {\n \tduration: .2\n }\n}\n</code></pre>",
      "!url": "http://alloyui.com/classes/OverlayContextPanel.html#attribute_anim"
     },
     "arrow": {
      "!type": "fn()",
      "!doc": "Position where the arrow will be placed. See\n<a href=\"OverlayContextPanel.html#config_showArrow\">showArrow</a>. If it's\nnot set, it will get the value set on the\n<a href=\"OverlayContext.html#config_align\">align</a> point. Here is a\nlist of valid arrows 'bc', 'bl', 'br', 'cc', 'lb', 'lc', 'lt', 'rb',\n'rc', 'rl'.",
      "!url": "http://alloyui.com/classes/OverlayContextPanel.html#attribute_arrow"
     },
     "hideOn": {
      "!type": "fn()",
      "!doc": "See <a href=\"OverlayContext.html#config_hideOn\">hideOn</a>.",
      "!url": "http://alloyui.com/classes/OverlayContextPanel.html#attribute_hideOn"
     },
     "showOn": {
      "!type": "fn()",
      "!doc": "See <a href=\"OverlayContext.html#config_showOn\">showOn</a>.",
      "!url": "http://alloyui.com/classes/OverlayContextPanel.html#attribute_showOn"
     },
     "showArrow": {
      "!type": "fn()",
      "!doc": "If true the OverlayContextPanel will show an arrow positioned on the\n<a href=\"OverlayContextPanel.html#config_arrow\">arrow</a> point.",
      "!url": "http://alloyui.com/classes/OverlayContextPanel.html#attribute_showArrow"
     },
     "stack": {
      "!type": "fn()",
      "!doc": "Gives stacking habilities to the OverlayContextPanel.",
      "!url": "http://alloyui.com/classes/OverlayContextPanel.html#attribute_stack"
     },
     "align": {
      "!type": "fn(node: aui_node.Node, points: [Array])",
      "!doc": "Aligns the OverlayContextPanel to the provided node (or viewport) using the\nprovided points. Inherited from\n<a href=\"Overlay.html#method_align\">Overlay</a>.",
      "!url": "http://alloyui.com/classes/OverlayContextPanel.html#method_align"
     },
     "fixPointerColor": {
      "!type": "fn()",
      "!doc": "OverlayContextPanel uses a imageless arrow, which involves some CSS technics.\nThis method is meant to fix the color of the borders of the arrow.",
      "!url": "http://alloyui.com/classes/OverlayContextPanel.html#method_fixPointerColor"
     },
     "getAlignPoint": {
      "!type": "fn() -> string",
      "!doc": "Normalize the align point value. The align point 'cc' is not a valid\nposition for the arrow and then it's normalized to the 'bc' point.",
      "!url": "http://alloyui.com/classes/OverlayContextPanel.html#method_getAlignPoint"
     },
     "hide": {
      "!type": "fn(event: EventFacade)",
      "!doc": "Hides the OverlayContextPanel.",
      "!url": "http://alloyui.com/classes/OverlayContextPanel.html#method_hide"
     }
    }
   },
   "OverlayManager": {
    "!type": "fn(config: Object) -> +aui_overlay.OverlayManager",
    "!proto": "Base",
    "!doc": "<p><img src=\"assets/images/aui-overlay-manager/main.png\"/></p>\n\nA base class for OverlayManager, providing:\n<ul>\n   <li>Grouping overlays</li>\n   <li>Show or hide the entire group of registered overlays</li>\n   <li>Basic Overlay Stackability (zIndex support)</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var groupOverlayManager = new A.OverlayManager();\ngroupOverlayManager.register([overlay1, overlay2, overlay3]);\ngroupOverlayManager.hideAll();\n</code></pre>\n\nCheck the list of <a href=\"OverlayManager.html#configattributes\">Configuration Attributes</a> available for\nOverlayManager.",
    "!url": "http://alloyui.com/classes/OverlayManager.html",
    "OverlayManager.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/OverlayManager.html#property_OverlayManager.NAME"
    },
    "OverlayManager.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the OverlayManager.",
     "!url": "http://alloyui.com/classes/OverlayManager.html#property_OverlayManager.ATTRS"
    },
    "prototype": {
     "zIndexBase": {
      "!type": "fn()",
      "!doc": "The zIndex base to be used on the stacking for all overlays\nregistered on the OverlayManager.",
      "!url": "http://alloyui.com/classes/OverlayManager.html#attribute_zIndexBase"
     },
     "bringToTop": {
      "!type": "fn(overlay: Overlay)",
      "!doc": "Set the passed overlay zIndex to the highest value.",
      "!url": "http://alloyui.com/classes/OverlayManager.html#method_bringToTop"
     },
     "register": {
      "!type": "fn(overlay: Overlay) -> +Array",
      "!doc": "Register the passed <a href=\"Overlay.html\">Overlay</a> to this\nOverlayManager.",
      "!url": "http://alloyui.com/classes/OverlayManager.html#method_register"
     },
     "remove": {
      "!type": "fn(overlay: Overlay) -> +Null",
      "!doc": "Remove the passed <a href=\"Overlay.html\">Overlay</a> from this\nOverlayManager.",
      "!url": "http://alloyui.com/classes/OverlayManager.html#method_remove"
     },
     "each": {
      "!type": "fn(fn: fn()) -> +Null",
      "!doc": "Loop through all registered <a href=\"Overlay.html\">Overlay</a> and\nexecute a callback.",
      "!url": "http://alloyui.com/classes/OverlayManager.html#method_each"
     },
     "showAll": {
      "!type": "fn()",
      "!doc": "Invoke the <a href=\"Overlay.html#method_show\">show</a> method from\nall registered Overlays.",
      "!url": "http://alloyui.com/classes/OverlayManager.html#method_showAll"
     },
     "hideAll": {
      "!type": "fn()",
      "!doc": "Invoke the <a href=\"Overlay.html#method_hide\">hide</a> method from\nall registered Overlays.",
      "!url": "http://alloyui.com/classes/OverlayManager.html#method_hideAll"
     },
     "sortByZIndexDesc": {
      "!type": "fn(a: Overlay, b: Overlay) -> number",
      "!doc": "zIndex comparator. Used on Array.sort.",
      "!url": "http://alloyui.com/classes/OverlayManager.html#method_sortByZIndexDesc"
     }
    }
   },
   "OverlayMask": {
    "!type": "fn(config: Object) -> +aui_overlay.OverlayMask",
    "!proto": "aui_overlay.OverlayBase",
    "!doc": "A base class for OverlayMask, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Cross browser mask functionality to cover an element or the entire page</li>\n   <li>Customizable mask (i.e., background, opacity)</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var instance = new A.OverlayMask().render();</code></pre>\n\nCheck the list of <a href=\"OverlayMask.html#configattributes\">Configuration Attributes</a> available for\nOverlayMask.",
    "!url": "http://alloyui.com/classes/OverlayMask.html",
    "OverlayMask.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/OverlayMask.html#property_OverlayMask.NAME"
    },
    "OverlayMask.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the OverlayMask.",
     "!url": "http://alloyui.com/classes/OverlayMask.html#property_OverlayMask.ATTRS"
    },
    "prototype": {
     "alignPoints": {
      "!type": "fn()",
      "!doc": "Points to align the <a href=\"Overlay.html\">Overlay</a> used as\nmask.",
      "!url": "http://alloyui.com/classes/OverlayMask.html#attribute_alignPoints"
     },
     "background": {
      "!type": "fn()",
      "!doc": "Background color of the mask.",
      "!url": "http://alloyui.com/classes/OverlayMask.html#attribute_background"
     },
     "target": {
      "!type": "fn()",
      "!doc": "Node where the mask will be positioned and re-dimensioned. The\ndefault is the document, which means that if not specified the mask\ntakes the full screen.",
      "!url": "http://alloyui.com/classes/OverlayMask.html#attribute_target"
     },
     "opacity": {
      "!type": "fn()",
      "!doc": "CSS opacity of the mask.",
      "!url": "http://alloyui.com/classes/OverlayMask.html#attribute_opacity"
     },
     "shim": {
      "!type": "fn()",
      "!doc": "Use shim option.",
      "!url": "http://alloyui.com/classes/OverlayMask.html#attribute_shim"
     },
     "visible": {
      "!type": "fn()",
      "!doc": "If true the Overlay is visible by default after the render phase.\nInherited from <a href=\"Overlay.html\">Overlay</a>.",
      "!url": "http://alloyui.com/classes/OverlayMask.html#attribute_visible"
     },
     "zIndex": {
      "!type": "fn()",
      "!doc": "zIndex of the OverlayMask.",
      "!url": "http://alloyui.com/classes/OverlayMask.html#attribute_zIndex"
     },
     "getTargetSize": {
      "!type": "fn() -> +Object",
      "!doc": "Get the size of the\n<a href=\"OverlayMask.html#config_target\">target</a>. Used to dimension\nthe mask node.",
      "!url": "http://alloyui.com/classes/OverlayMask.html#method_getTargetSize"
     },
     "refreshMask": {
      "!type": "fn()",
      "!doc": "Repaint the OverlayMask UI, respecting the\n<a href=\"OverlayMask.html#config_target\">target</a> size and the\n<a href=\"OverlayMask.html#config_alignPoints\">alignPoints</a>.",
      "!url": "http://alloyui.com/classes/OverlayMask.html#method_refreshMask"
     }
    }
   }
  },
  "aui_pagination": {
   "A.Pagination": {
    "!type": "fn(config: Object) -> +aui_pagination.A.Pagination",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for Pagination, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Set of controls to navigate through paged data</li>\n</ul>\n\nCheck the [live demo](http://alloyui.com/examples/pagination/).",
    "!url": "http://alloyui.com/classes/A.Pagination.html",
    "Pagination.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Pagination.html#property_Pagination.NAME"
    },
    "Pagination.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Pagination.",
     "!url": "http://alloyui.com/classes/A.Pagination.html#property_Pagination.ATTRS"
    },
    "prototype": {
     "circular": {
      "!type": "fn()",
      "!doc": "When enabled this property allows the navigation to go back to\nthe beggining when it reaches the last page, the opposite behavior\nis also true. Incremental page navigation could happen clicking the\ncontrol arrows or invoking <code>.next()</code> and\n<code>.prev()</code> methods.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#attribute_circular"
     },
     "formatter": {
      "!type": "fn()",
      "!doc": "A formatter function to format each pagination item.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#attribute_formatter"
     },
     "items": {
      "!type": "fn()",
      "!doc": "Holds the page items as a NodeList. The list could be queried\nfrom the DOM trough Widget HTML_PARSER or generated if\n<a href=\"Pagination.html#config_total\">total</a> is specified.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#attribute_items"
     },
     "offset": {
      "!type": "fn()",
      "!doc": "Initial page offset.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#attribute_offset"
     },
     "page": {
      "!type": "fn()",
      "!doc": "Page to display on initial paint.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#attribute_page"
     },
     "total": {
      "!type": "fn()",
      "!doc": "Total number of page links available. If set, the new\n<a href=\"Pagination.html#config_items\">items</a> node list will\nbe rendered.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#attribute_total"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "Text used on Pagination.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#attribute_strings"
     },
     "getItem": {
      "!type": "fn(i: aui_node.Node) -> +aui_node.Node",
      "!doc": "Retrieve the item node from the passesed item index parameter.\nIf passed item is a node instead of the index returns itself.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#method_getItem"
     },
     "getOffsetPageNumber": {
      "!type": "fn() -> number",
      "!doc": "Retrieve page number inclusing offset e.g., if offset\nis 100 and active page is 5, this method returns 105.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#method_getOffsetPageNumber"
     },
     "getOffsetTotalPages": {
      "!type": "fn() -> number",
      "!doc": "Retrieve total number of pages including offset e.g., if offset\nis 100 and total 10, this method returns 110.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#method_getOffsetTotalPages"
     },
     "getTotalItems": {
      "!type": "fn() -> number",
      "!doc": "Retrieve total number of dom items representing the links,\nincluding the arrow control items. Do not include the offset.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#method_getTotalItems"
     },
     "next": {
      "!type": "fn()",
      "!doc": "Navigate to the next page.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#method_next"
     },
     "prev": {
      "!type": "fn()",
      "!doc": "Navigate to the previous page.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#method_prev"
     },
     "setState": {
      "!type": "fn(state)",
      "!doc": "Set the new pagination state. The state is a payload object\ncontaining the page number, e.g. <code>{page:1}</code>.",
      "!url": "http://alloyui.com/classes/A.Pagination.html#method_setState"
     }
    },
    "Pagination.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "Object hash, defining how attribute values are to be parsed from\nmarkup contained in the widget's content box.",
     "!url": "http://alloyui.com/classes/A.Pagination.html#property_Pagination.HTML_PARSER"
    },
    "Pagination.BIND_UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the attributes\nfor the bindUI lifecycle phase.",
     "!url": "http://alloyui.com/classes/A.Pagination.html#property_Pagination.BIND_UI_ATTRS"
    },
    "Pagination.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.Pagination.html#property_Pagination.UI_ATTRS"
    }
   }
  },
  "aui_palette": {
   "A.Palette": {
    "!type": "fn(config: Object) -> +aui_palette.A.Palette",
    "!proto": "A.Widget",
    "!doc": "A base class for Palette.",
    "!url": "http://alloyui.com/classes/A.Palette.html",
    "prototype": {
     "getItem": {
      "!type": "fn(row: number, col: number) -> +Object",
      "!doc": "Returns an item in the Palette by row and column.",
      "!url": "http://alloyui.com/classes/A.Palette.html#method_getItem"
     },
     "getItemByIndex": {
      "!type": "fn(index: number) -> +Object",
      "!doc": "Returns an item in the Palette by its index.",
      "!url": "http://alloyui.com/classes/A.Palette.html#method_getItemByIndex"
     },
     "getItemByValue": {
      "!type": "fn(value: Object) -> +Object",
      "!doc": "Returns an item in the Palette by its value.",
      "!url": "http://alloyui.com/classes/A.Palette.html#method_getItemByValue"
     },
     "select": {
      "!type": "fn(valueOrIndex: number)",
      "!doc": "Selects an item in the Palette.",
      "!url": "http://alloyui.com/classes/A.Palette.html#method_select"
     },
     "toggleSelection": {
      "!type": "fn()",
      "!doc": "If true, on user interaction if the user clicks on an already selected element, it will be unselected.",
      "!url": "http://alloyui.com/classes/A.Palette.html#attribute_toggleSelection"
     },
     "unselect": {
      "!type": "fn(valueOrIndex: number)",
      "!doc": "Unselects an item. The item must be specified by its value or index.",
      "!url": "http://alloyui.com/classes/A.Palette.html#method_unselect"
     },
     "columns": {
      "!type": "fn()",
      "!doc": "Specifies how many columns should contain the Palette.\nIf the value is a positive number, the Palette will generate as many columns as specified in this property and it will fit\nthe provided <code>items</code> in these columns.",
      "!url": "http://alloyui.com/classes/A.Palette.html#attribute_columns"
     },
     "containerNode": {
      "!type": "fn()",
      "!doc": "Container node of the palette. If found, palette widget will not\ngenerate content.",
      "!url": "http://alloyui.com/classes/A.Palette.html#attribute_containerNode"
     },
     "formatter": {
      "!type": "fn()",
      "!doc": "Provides a function, which will be used to format the content during Palette creation.",
      "!url": "http://alloyui.com/classes/A.Palette.html#attribute_formatter"
     },
     "items": {
      "!type": "fn()",
      "!doc": "An array of Palette items. These items will be rendered in the Palette according to the specified <code>columns</code>.",
      "!url": "http://alloyui.com/classes/A.Palette.html#attribute_items"
     },
     "selected": {
      "!type": "fn()",
      "!doc": "Provides the index of currently selected item.",
      "!url": "http://alloyui.com/classes/A.Palette.html#attribute_selected"
     }
    },
    "Palette.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "Object hash, defining how attribute values have to be parsed from\nmarkup contained in the Palette's content box.",
     "!url": "http://alloyui.com/classes/A.Palette.html#property_Palette.HTML_PARSER"
    },
    "Palette.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Palette.",
     "!url": "http://alloyui.com/classes/A.Palette.html#property_Palette.ATTRS"
    }
   }
  },
  "aui_parse_content": {
   "A.ParseContent": {
    "!type": "fn(config: Object) -> +aui_parse_content.A.ParseContent",
    "!proto": "A.Plugin.Base",
    "!doc": "A base class for ParseContent, providing:\n<ul>\n   <li>After plug ParseContent on a A.Node instance the javascript chunks will be executed (remote and inline scripts)</li>\n   <li>All the javascripts within a content will be executed according to the order of apparition</li>\n</ul>\n\n<p><strong>NOTE:</strong> For performance reasons on DOM manipulation,\nParseContent only parses the content passed to the\n<a href=\"Node.html#method_setContent\">setContent</a>,\n<a href=\"Node.html#method_prepend\">prepend</a> and\n<a href=\"Node.html#method_append\">append</a> methods.</p>\n\nQuick Example:<br/>\n\n<pre><code>node.plug(A.Plugin.ParseContent);</code></pre>\n\nCheck the list of <a href=\"ParseContent.html#configattributes\">Configuration Attributes</a> available for\nParseContent.",
    "!url": "http://alloyui.com/classes/A.ParseContent.html",
    "ParseContent.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ParseContent.html#property_ParseContent.NAME"
    },
    "ParseContent.NS": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the namespace.",
     "!url": "http://alloyui.com/classes/A.ParseContent.html#property_ParseContent.NS"
    },
    "ParseContent.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ParseContent.",
     "!url": "http://alloyui.com/classes/A.ParseContent.html#property_ParseContent.ATTRS"
    },
    "prototype": {
     "queue": {
      "!type": "fn()",
      "!doc": "A queue of elements to be parsed.",
      "!url": "http://alloyui.com/classes/A.ParseContent.html#attribute_queue"
     },
     "globalEval": {
      "!type": "fn(data: string)",
      "!doc": "Global eval the <data>data</data> passed.",
      "!url": "http://alloyui.com/classes/A.ParseContent.html#method_globalEval"
     },
     "parseContent": {
      "!type": "fn(content: string) -> string",
      "!doc": "Extract the <code>script</code> tags from the string content and\nevaluate the chunks.",
      "!url": "http://alloyui.com/classes/A.ParseContent.html#method_parseContent"
     }
    },
    "ParseContent.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.ParseContent.html#property_ParseContent.EXTENDS"
    }
   }
  },
  "aui_popover": {
   "Popover": {
    "!type": "fn(config: Object) -> +aui_popover.Popover",
    "!proto": "Widget",
    "!doc": "A base class for Popover.\n\nCheck the [live demo](http://alloyui.com/examples/popover/).",
    "!url": "http://alloyui.com/classes/Popover.html",
    "Popover.CSS_PREFIX": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the CSS prefix.",
     "!url": "http://alloyui.com/classes/Popover.html#property_Popover.CSS_PREFIX"
    },
    "A.Popover.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Popover.",
     "!url": "http://alloyui.com/classes/Popover.html#property_A.Popover.ATTRS"
    },
    "prototype": {
     "triggerToggleEvent": {
      "!type": "fn()",
      "!doc": "DOM event to hide the tooltip.",
      "!url": "http://alloyui.com/classes/Popover.html#attribute_triggerToggleEvent"
     }
    },
    "Popover.TEMPLATES": {
     "!type": "+Object",
     "!doc": "Static property provides a set of reusable templates.",
     "!url": "http://alloyui.com/classes/Popover.html#property_Popover.TEMPLATES"
    }
   }
  },
  "aui_progressbar": {
   "A.ProgressBar": {
    "!type": "fn(config: Object) -> +aui_progressbar.A.ProgressBar",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for Progressbar, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>A visual means of showing progress of an ongoing operation</li>\n   <li>Can be enhanced via CSS styles to provide different colors, shapes and textures</li>\n   <li>The bar can move horizontally or vertically</li>\n   <li>The movement can be enhanced by using the Animation utility</li>\n</ul>\n\nCheck the [live demo](http://alloyui.com/examples/progressbar/).",
    "!url": "http://alloyui.com/classes/A.ProgressBar.html",
    "ProgressBar.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ProgressBar.html#property_ProgressBar.NAME"
    },
    "ProgressBar.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ProgressBar.",
     "!url": "http://alloyui.com/classes/A.ProgressBar.html#property_ProgressBar.ATTRS"
    },
    "prototype": {
     "useARIA": {
      "!type": "fn()",
      "!doc": "Boolean indicating if use of the WAI-ARIA Roles and States\nshould be enabled.",
      "!url": "http://alloyui.com/classes/A.ProgressBar.html#attribute_useARIA"
     },
     "height": {
      "!type": "fn()",
      "!doc": "Display height of the progressbar.",
      "!url": "http://alloyui.com/classes/A.ProgressBar.html#attribute_height"
     },
     "label": {
      "!type": "fn()",
      "!doc": "Display label of the progressbar. If not specified try to query\nusing HTML_PARSER an element inside boundingBox which matches\n<code>aui-progressbar-text</code> and get its innerHTML to be\nused as label.",
      "!url": "http://alloyui.com/classes/A.ProgressBar.html#attribute_label"
     },
     "max": {
      "!type": "fn()",
      "!doc": "Represents the top value for the bar. The bar will be fully\nextended when reaching this value. Values higher than this will\nbe ignored.",
      "!url": "http://alloyui.com/classes/A.ProgressBar.html#attribute_max"
     },
     "min": {
      "!type": "fn()",
      "!doc": "Represents the lowest value for the bar. The bar will be\ntotally collapsed when reaching this value. Values lower than\nthis will be ignored.",
      "!url": "http://alloyui.com/classes/A.ProgressBar.html#attribute_min"
     },
     "orientation": {
      "!type": "fn()",
      "!doc": "Display orientation of the progressbar (i.e. vertical or\nhorizontal).",
      "!url": "http://alloyui.com/classes/A.ProgressBar.html#attribute_orientation"
     },
     "ratio": {
      "!type": "fn()",
      "!doc": "Calculate the ratio based on <code>max</code> and\n<code>min</code> values.",
      "!url": "http://alloyui.com/classes/A.ProgressBar.html#attribute_ratio"
     },
     "step": {
      "!type": "fn()",
      "!doc": "Calculate the progressbar step based on <code>ratio</code>\nvalue.",
      "!url": "http://alloyui.com/classes/A.ProgressBar.html#attribute_step"
     },
     "textNode": {
      "!type": "fn()",
      "!doc": "DOM Node to display the text of the progressbar. If not\nspecified try to query using HTML_PARSER an element inside\ncontentBox which matches <code>aui-progressbar-text</code>.",
      "!url": "http://alloyui.com/classes/A.ProgressBar.html#attribute_textNode"
     },
     "value": {
      "!type": "fn()",
      "!doc": "The value for the bar. Valid values are in between the minValue\nand maxValue attributes.",
      "!url": "http://alloyui.com/classes/A.ProgressBar.html#attribute_value"
     }
    },
    "ProgressBar.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "Object hash, defining how attribute values are to be parsed from\nmarkup contained in the widget's bounding box.",
     "!url": "http://alloyui.com/classes/A.ProgressBar.html#property_ProgressBar.HTML_PARSER"
    },
    "ProgressBar.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.ProgressBar.html#property_ProgressBar.UI_ATTRS"
    }
   }
  },
  "aui_rating": {
   "A.Rating": {
    "!type": "fn(config: Object) -> +aui_rating.A.Rating",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for Rating, providing:\n <ul>\n    <li>A non-obstrusive star rating control</li>\n    <li>Could be based on a set of radio input boxes</li>\n </ul>\nCheck the [live demo](http://alloyui.com/examples/rating/).",
    "!url": "http://alloyui.com/classes/A.Rating.html",
    "Rating.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Rating.html#property_Rating.NAME"
    },
    "Rating.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Rating.",
     "!url": "http://alloyui.com/classes/A.Rating.html#property_Rating.ATTRS"
    },
    "prototype": {
     "disabled": {
      "!type": "fn()",
      "!doc": "Whether the Rating is disabled or not.\nDisabled Ratings don't allow hover or click,\njust display selected stars.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_disabled"
     },
     "canReset": {
      "!type": "fn()",
      "!doc": "If <code>true</code> could be reseted\n(i.e., have no values selected).",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_canReset"
     },
     "cssClasses": {
      "!type": "fn()",
      "!doc": "CSS classes applied on Rating.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_cssClasses"
     },
     "defaultSelected": {
      "!type": "fn()",
      "!doc": "The number of selected starts when the Rating render.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_defaultSelected"
     },
     "elements": {
      "!type": "fn()",
      "!doc": "<a href=\"NodeList.html\">NodeList</a> of elements used on the\nRating. Each element is one Star.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_elements"
     },
     "hiddenInput": {
      "!type": "fn()",
      "!doc": "Hidden input to handle the selected value. This hidden input\nreplace the radio elements and keep the same name.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_hiddenInput"
     },
     "inputName": {
      "!type": "fn()",
      "!doc": "Name of the <a\nhref=\"Rating.html#config_hiddenInput\">hiddenInput</a> element. If\nnot specified will use the name of the replaced radio.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_inputName"
     },
     "label": {
      "!type": "fn()",
      "!doc": "Label to be displayed with the Rating elements.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_label"
     },
     "labelNode": {
      "!type": "fn()",
      "!doc": "DOM Node to display the text of the StarRating. If not\nspecified try to query using HTML_PARSER an element inside\nboundingBox which matches <code>aui-rating-label-element</code>.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_labelNode"
     },
     "selectedIndex": {
      "!type": "fn()",
      "!doc": "Stores the index of the selected element.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_selectedIndex"
     },
     "showTitle": {
      "!type": "fn()",
      "!doc": "If <code>true</code> will extract the value of the\n<code>title</code> attribute on the radio, and use it on the\ngenerated Rating elements.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_showTitle"
     },
     "size": {
      "!type": "fn()",
      "!doc": "Number of Rating elements to be displayed.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_size"
     },
     "title": {
      "!type": "fn()",
      "!doc": "If set, will be used when there is no DOM <code>title</code> on the\nradio elements.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_title"
     },
     "value": {
      "!type": "fn()",
      "!doc": "Stores the value of the current selected Rating element.",
      "!url": "http://alloyui.com/classes/A.Rating.html#attribute_value"
     },
     "clearSelection": {
      "!type": "fn()",
      "!doc": "Clear all selected starts to the default state.",
      "!url": "http://alloyui.com/classes/A.Rating.html#method_clearSelection"
     },
     "select": {
      "!type": "fn(index: number)",
      "!doc": "Select the <code>index</code> Rating element.",
      "!url": "http://alloyui.com/classes/A.Rating.html#method_select"
     },
     "fillTo": {
      "!type": "fn(index: number, className: string)",
      "!doc": "Add the <code>className</code> on the the <code>index</code> element\nand all the previous Rating elements.",
      "!url": "http://alloyui.com/classes/A.Rating.html#method_fillTo"
     },
     "indexOf": {
      "!type": "fn(elem: aui_node.Node) -> number",
      "!doc": "Find the index of the <code>elem</code>.",
      "!url": "http://alloyui.com/classes/A.Rating.html#method_indexOf"
     },
     "itemClick": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handle the itemClick event.",
      "!url": "http://alloyui.com/classes/A.Rating.html#event_itemClick"
     },
     "itemSelect": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handle the itemOver event.",
      "!url": "http://alloyui.com/classes/A.Rating.html#event_itemSelect"
     },
     "itemOut": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handle the itemOut event.",
      "!url": "http://alloyui.com/classes/A.Rating.html#event_itemOut"
     }
    },
    "StarRating.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "Object hash, defining how attribute values are to be parsed from\nmarkup contained in the widget's content box.",
     "!url": "http://alloyui.com/classes/A.Rating.html#property_StarRating.HTML_PARSER"
    }
   },
   "A.ThumbRating": {
    "!type": "fn(config: Object) -> +aui_rating.A.ThumbRating",
    "!proto": "aui_rating.A.Rating",
    "!doc": "A base class for ThumbRating, providing:\n <ul>\n    <li>A non-obstrusive star rating control using Thumb up and Thumb down icons</li>\n    <li>Could be based on a set of radio input boxes</li>\n </ul>\nCheck the [live demo](http://alloyui.com/examples/rating/).",
    "!url": "http://alloyui.com/classes/A.ThumbRating.html",
    "ThumbRating.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.ThumbRating.html#property_ThumbRating.NAME"
    },
    "ThumbRating.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the ThumbRating.",
     "!url": "http://alloyui.com/classes/A.ThumbRating.html#property_ThumbRating.ATTRS"
    },
    "prototype": {
     "cssClasses": {
      "!type": "fn()",
      "!doc": "CSS classes applied on ThumbRating.",
      "!url": "http://alloyui.com/classes/A.ThumbRating.html#attribute_cssClasses"
     },
     "size": {
      "!type": "fn()",
      "!doc": "The size on ThumbRating is always 2 (i.e., thumb up and thumb down).",
      "!url": "http://alloyui.com/classes/A.ThumbRating.html#attribute_size"
     },
     "fillTo": {
      "!type": "fn(index: number, className: string)",
      "!doc": "Add the <code>className</code> on the the <code>index</code> element\nand all the previous Rating elements.",
      "!url": "http://alloyui.com/classes/A.ThumbRating.html#method_fillTo"
     }
    },
    "ThumbRating.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.ThumbRating.html#property_ThumbRating.EXTENDS"
    }
   }
  },
  "aui_resize": {
   "Resize": {
    "!type": "fn(config: Object) -> +aui_resize.Resize",
    "!proto": "Base",
    "!doc": "<p><img src=\"assets/images/aui-resize/main.png\"/></p>\n\nA base class for Resize, providing:\n<ul>\n   <li>Basic Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Applies drag handles to an element to make it resizable</li>\n   <li>Here is the list of valid resize handles:\n       <code>[ 't', 'tr', 'r', 'br', 'b', 'bl', 'l', 'tl' ]</code>. You can\n       read this list as top, top-right, right, bottom-right, bottom,\n       bottom-left, left, top-left.</li>\n   <li>The drag handles are inserted into the element and positioned\n       absolute. Some elements, such as a textarea or image, don't support\n       children. To overcome that, set wrap:true in your config and the\n       element willbe wrapped for you automatically.</li>\n</ul>\n\nQuick Example:\n\n<pre><code>var instance = new A.Resize({\n node: '#resize1',\n proxy: true,\n preserveRatio: true,\n wrap: true,\n maxHeight: 170,\n maxWidth: 400,\n handles: 't, tr, r, br, b, bl, l, tl'\n});\n</code></pre>\n\nCheck the list of <a href=\"Resize.html#configattributes\">Configuration Attributes</a> available for\nResize.",
    "!url": "http://alloyui.com/classes/Resize.html",
    "Resize.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/Resize.html#property_Resize.NAME"
    },
    "Resize.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Resize.",
     "!url": "http://alloyui.com/classes/Resize.html#property_Resize.ATTRS"
    },
    "prototype": {
     "autoHide": {
      "!type": "fn()",
      "!doc": "False to ensure that the resize handles are always visible, true to\ndisplay them only when the user mouses over the resizable borders.",
      "!url": "http://alloyui.com/classes/Resize.html#attribute_autoHide"
     },
     "handles": {
      "!type": "fn()",
      "!doc": "The handles to use (any combination of): 't', 'b', 'r', 'l', 'bl',\n'br', 'tl', 'tr'. Can use a shortcut of All.",
      "!url": "http://alloyui.com/classes/Resize.html#attribute_handles"
     },
     "node": {
      "!type": "fn()",
      "!doc": "The selector or element to resize. Required.",
      "!url": "http://alloyui.com/classes/Resize.html#attribute_node"
     },
     "proxy": {
      "!type": "fn()",
      "!doc": "Resize a proxy element instead of the real element.",
      "!url": "http://alloyui.com/classes/Resize.html#attribute_proxy"
     },
     "proxyEl": {
      "!type": "fn()",
      "!doc": "The Resize proxy element.",
      "!url": "http://alloyui.com/classes/Resize.html#attribute_proxyEl"
     },
     "resizing": {
      "!type": "fn()",
      "!doc": "True when the element is being Resized.",
      "!url": "http://alloyui.com/classes/Resize.html#attribute_resizing"
     },
     "wrap": {
      "!type": "fn()",
      "!doc": "True to wrap an element with a div if needed (required for textareas\nand images, defaults to false) in favor of the handles config option.\nThe wrapper element type (default div) could be over-riden passing the\n<code>wrapper</code> attribute.",
      "!url": "http://alloyui.com/classes/Resize.html#attribute_wrap"
     },
     "wrapTypes": {
      "!type": "fn()",
      "!doc": "Elements that requires a wrapper by default. Normally are elements\nwhich cannot have children elements.",
      "!url": "http://alloyui.com/classes/Resize.html#attribute_wrapTypes"
     },
     "wrapper": {
      "!type": "fn()",
      "!doc": "Element to wrap the <code>wrapTypes</code>. This element will house\nthe handles elements.",
      "!url": "http://alloyui.com/classes/Resize.html#attribute_wrapper"
     },
     "changeHeightHandles": {
      "!type": "+boolean",
      "!doc": "Whether the handle being dragged can change the height.",
      "!url": "http://alloyui.com/classes/Resize.html#property_changeHeightHandles"
     },
     "changeLeftHandles": {
      "!type": "+boolean",
      "!doc": "Whether the handle being dragged can change the left.",
      "!url": "http://alloyui.com/classes/Resize.html#property_changeLeftHandles"
     },
     "changeTopHandles": {
      "!type": "+boolean",
      "!doc": "Whether the handle being dragged can change the top.",
      "!url": "http://alloyui.com/classes/Resize.html#property_changeTopHandles"
     },
     "changeWidthHandles": {
      "!type": "+boolean",
      "!doc": "Whether the handle being dragged can change the width.",
      "!url": "http://alloyui.com/classes/Resize.html#property_changeWidthHandles"
     },
     "delegate": {
      "!type": "+Object",
      "!doc": "Store DD.Delegate reference for the respective Resize instance.",
      "!url": "http://alloyui.com/classes/Resize.html#property_delegate"
     },
     "eachHandle": {
      "!type": "fn(fn: fn())",
      "!doc": "<p>Loop through each handle which is being used and executes a callback.</p>\n<p>Example:</p>\n<pre><code>instance.eachHandle(\n     function(handleName, index) { ... }\n );</code></pre>",
      "!url": "http://alloyui.com/classes/Resize.html#method_eachHandle"
     },
     "resize:start": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the resize start event. Fired when a handle starts to be\ndragged.",
      "!url": "http://alloyui.com/classes/Resize.html#event_resize:start"
     },
     "resize:resize": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the resize event. Fired on each pixel when the handle is\nbeing dragged.",
      "!url": "http://alloyui.com/classes/Resize.html#event_resize:resize"
     },
     "resize:align": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the resize align event.",
      "!url": "http://alloyui.com/classes/Resize.html#event_resize:align"
     },
     "resize:end": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the resize end event. Fired when a handle stop to be\ndragged.",
      "!url": "http://alloyui.com/classes/Resize.html#event_resize:end"
     },
     "resize:mouseUp": {
      "!type": "fn(event: Event.Facade)",
      "!doc": "Handles the resize mouseUp event. Fired when a mouseUp event happens on a\nhandle.",
      "!url": "http://alloyui.com/classes/Resize.html#event_resize:mouseUp"
     }
    }
   },
   "A.SchedulerCalendar": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerCalendar",
    "!proto": "A.ModelList",
    "!doc": "A base class for SchedulerCalendar.",
    "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html",
    "prototype": {
     "constrain": {
      "!type": "fn()",
      "!doc": "Will attempt to constrain the resize node to the boundaries. Arguments:<br>\n'view': Contrain to Viewport<br>\n'#selector_string': Constrain to this node<br>\n'{Region Object}': An Object Literal containing a valid region (top, right, bottom, left) of page positions",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_constrain"
     },
     "minHeight": {
      "!type": "fn()",
      "!doc": "The minimum height of the element",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_minHeight"
     },
     "minWidth": {
      "!type": "fn()",
      "!doc": "The minimum width of the element",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_minWidth"
     },
     "maxHeight": {
      "!type": "fn()",
      "!doc": "The maximum height of the element",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_maxHeight"
     },
     "maxWidth": {
      "!type": "fn()",
      "!doc": "The maximum width of the element",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_maxWidth"
     },
     "preserveRatio": {
      "!type": "fn()",
      "!doc": "Maintain the element's ratio when resizing.",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_preserveRatio"
     },
     "tickX": {
      "!type": "fn()",
      "!doc": "The number of x ticks to span the resize to.",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_tickX"
     },
     "tickY": {
      "!type": "fn()",
      "!doc": "The number of y ticks to span the resize to.",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_tickY"
     },
     "constrainBorderInfo": {
      "!type": "+Object",
      "!doc": "Cache the border widths of the contrain node if constrain\noption is being used.",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#property_constrainBorderInfo"
     }
    }
   }
  },
  "aui_scheduler": {
   "A.SchedulerCalendar": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerCalendar",
    "!proto": "A.ModelList",
    "!doc": "A base class for SchedulerCalendar.",
    "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html",
    "SchedulerCalendar.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerCalendar.",
     "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#property_SchedulerCalendar.ATTRS"
    },
    "prototype": {
     "color": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_color"
     },
     "disabled": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_disabled"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_name"
     },
     "palette": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_palette"
     },
     "scheduler": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_scheduler"
     },
     "visible": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerCalendar.html#attribute_visible"
     }
    }
   },
   "A.SchedulerEvent": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerEvent",
    "!proto": "A.Model",
    "!doc": "A base class for SchedulerEvent.",
    "!url": "http://alloyui.com/classes/A.SchedulerEvent.html",
    "SchedulerEvent.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#property_SchedulerEvent.NAME"
    },
    "SchedulerEvent.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerEvent.",
     "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#property_SchedulerEvent.ATTRS"
    },
    "prototype": {
     "allDay": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_allDay"
     },
     "borderColor": {
      "!type": "fn()",
      "!doc": "Determines the CSS border color of a calendar event.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_borderColor"
     },
     "borderStyle": {
      "!type": "fn()",
      "!doc": "Determines the CSS border style of a calendar event.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_borderStyle"
     },
     "borderWidth": {
      "!type": "fn()",
      "!doc": "Determines the CSS border width of a calendar event.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_borderWidth"
     },
     "content": {
      "!type": "fn()",
      "!doc": "Contains the content of Scheduler event's body section.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_content"
     },
     "color": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_color"
     },
     "colorBrightnessFactor": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_colorBrightnessFactor"
     },
     "colorSaturationFactor": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_colorSaturationFactor"
     },
     "titleDateFormat": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_titleDateFormat"
     },
     "endDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_endDate"
     },
     "disabled": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_disabled"
     },
     "meeting": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_meeting"
     },
     "node": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_node"
     },
     "reminder": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_reminder"
     },
     "repeated": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_repeated"
     },
     "scheduler": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_scheduler"
     },
     "startDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_startDate"
     },
     "visible": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#attribute_visible"
     },
     "addPaddingNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_addPaddingNode"
     },
     "clone": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_clone"
     },
     "copyDates": {
      "!type": "fn(evt, options)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_copyDates"
     },
     "copyPropagateAttrValues": {
      "!type": "fn(evt, dontCopyMap, options)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_copyPropagateAttrValues"
     },
     "getDaysDuration": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_getDaysDuration"
     },
     "getHoursDuration": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_getHoursDuration"
     },
     "getMinutesDuration": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_getMinutesDuration"
     },
     "getSecondsDuration": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_getSecondsDuration"
     },
     "sameEndDate": {
      "!type": "fn(evt)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_sameEndDate"
     },
     "sameStartDate": {
      "!type": "fn(evt)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_sameStartDate"
     },
     "isAfter": {
      "!type": "fn(evt)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_isAfter"
     },
     "isBefore": {
      "!type": "fn(evt)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_isBefore"
     },
     "intersects": {
      "!type": "fn(evt)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_intersects"
     },
     "intersectHours": {
      "!type": "fn(evt)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_intersectHours"
     },
     "isDayBoundaryEvent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_isDayBoundaryEvent"
     },
     "isDayOverlapEvent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_isDayOverlapEvent"
     },
     "getClearEndDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_getClearEndDate"
     },
     "getClearStartDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_getClearStartDate"
     },
     "move": {
      "!type": "fn(date, options)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_move"
     },
     "setContent": {
      "!type": "fn(content)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_setContent"
     },
     "setTitle": {
      "!type": "fn(content)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_setTitle"
     },
     "syncNodeContentUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_syncNodeContentUI"
     },
     "syncNodeTitleUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_syncNodeTitleUI"
     },
     "split": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#method_split"
     }
    },
    "SchedulerEvent.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#property_SchedulerEvent.EXTENDS"
    },
    "SchedulerEvent.PROPAGATE_ATTRS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.SchedulerEvent.html#property_SchedulerEvent.PROPAGATE_ATTRS"
    }
   },
   "A.SchedulerView": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerView",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for SchedulerView.",
    "!url": "http://alloyui.com/classes/A.SchedulerView.html",
    "SchedulerView.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SchedulerView.html#property_SchedulerView.NAME"
    },
    "SchedulerView.AUGMENTS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.SchedulerView.html#property_SchedulerView.AUGMENTS"
    },
    "SchedulerView.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerView.",
     "!url": "http://alloyui.com/classes/A.SchedulerView.html#property_SchedulerView.ATTRS"
    },
    "prototype": {
     "bodyContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_bodyContent"
     },
     "filterFn": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_filterFn"
     },
     "height": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_height"
     },
     "isoTime": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_isoTime"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_name"
     },
     "navigationDateFormatter": {
      "!type": "fn()",
      "!doc": "The function to format the navigation header date.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_navigationDateFormatter"
     },
     "nextDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_nextDate"
     },
     "prevDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_prevDate"
     },
     "scheduler": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_scheduler"
     },
     "scrollable": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_scrollable"
     },
     "triggerNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_triggerNode"
     },
     "visible": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#attribute_visible"
     },
     "getAdjustedViewDate": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#method_getAdjustedViewDate"
     },
     "flushViewCache": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#method_flushViewCache"
     },
     "getNextDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#method_getNextDate"
     },
     "getPrevDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#method_getPrevDate"
     },
     "getToday": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#method_getToday"
     },
     "limitDate": {
      "!type": "fn(date, maxDate)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#method_limitDate"
     },
     "plotEvents": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#method_plotEvents"
     },
     "syncStdContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#method_syncStdContent"
     },
     "syncEventUI": {
      "!type": "fn(evt)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerView.html#method_syncEventUI"
     }
    },
    "SchedulerView.BIND_UI_ATTRS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.SchedulerView.html#property_SchedulerView.BIND_UI_ATTRS"
    }
   },
   "A.SchedulerEvents": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerEvents",
    "!proto": "A.ModelList",
    "!doc": "A base class for SchedulerEvents.",
    "!url": "http://alloyui.com/classes/A.SchedulerEvents.html",
    "prototype": {
     "comparator": {
      "!type": "fn(model)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEvents.html#method_comparator"
     }
    },
    "SchedulerEvents.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerEvents.",
     "!url": "http://alloyui.com/classes/A.SchedulerEvents.html#property_SchedulerEvents.ATTRS"
    }
   },
   "A.SchedulerEventSupport": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerEventSupport",
    "!doc": "A base class for SchedulerEventSupport.",
    "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html",
    "SchedulerEventSupport.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerEventSupport.",
     "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html#property_SchedulerEventSupport.ATTRS"
    },
    "prototype": {
     "addEvents": {
      "!type": "fn(models)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html#method_addEvents"
     },
     "eachEvent": {
      "!type": "fn(fn)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html#method_eachEvent"
     },
     "flushEvents": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html#method_flushEvents"
     },
     "getEventByClientId": {
      "!type": "fn(clientId)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html#method_getEventByClientId"
     },
     "getEvents": {
      "!type": "fn(filterFn)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html#method_getEvents"
     },
     "getEventsByDay": {
      "!type": "fn(date, includeOverlap)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html#method_getEventsByDay"
     },
     "getIntersectEvents": {
      "!type": "fn(date)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html#method_getIntersectEvents"
     },
     "removeEvents": {
      "!type": "fn(models)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html#method_removeEvents"
     },
     "resetEvents": {
      "!type": "fn(models)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventSupport.html#method_resetEvents"
     }
    }
   },
   "A.SchedulerBase": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerBase",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for SchedulerBase.",
    "!url": "http://alloyui.com/classes/A.SchedulerBase.html",
    "SchedulerBase.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SchedulerBase.html#property_SchedulerBase.NAME"
    },
    "SchedulerBase.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerBase.",
     "!url": "http://alloyui.com/classes/A.SchedulerBase.html#property_SchedulerBase.ATTRS"
    },
    "prototype": {
     "activeView": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#attribute_activeView"
     },
     "date": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#attribute_date"
     },
     "eventRecorder": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#attribute_eventRecorder"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#attribute_strings"
     },
     "navigationDateFormatter": {
      "!type": "fn()",
      "!doc": "The function to format the navigation header date.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#attribute_navigationDateFormatter"
     },
     "views": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#attribute_views"
     },
     "viewDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#attribute_viewDate"
     },
     "firstDayOfWeek": {
      "!type": "fn()",
      "!doc": "First day of the week: Sunday is 0, Monday is 1.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#attribute_firstDayOfWeek"
     },
     "todayDate": {
      "!type": "fn()",
      "!doc": "Today date representation. This option allows the developer to\nspecify the date he wants to be used as the today date.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#attribute_todayDate"
     },
     "getViewByName": {
      "!type": "fn(name)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#method_getViewByName"
     },
     "getStrings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#method_getStrings"
     },
     "getString": {
      "!type": "fn(key)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#method_getString"
     },
     "renderView": {
      "!type": "fn(view)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#method_renderView"
     },
     "plotViewEvents": {
      "!type": "fn(view)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#method_plotViewEvents"
     },
     "syncEventsUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#method_syncEventsUI"
     },
     "renderButtonGroup": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#method_renderButtonGroup"
     },
     "syncStdContent": {
      "!type": "fn()",
      "!doc": "Sync SchedulerBase StdContent.",
      "!url": "http://alloyui.com/classes/A.SchedulerBase.html#method_syncStdContent"
     }
    },
    "SchedulerBase.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.SchedulerBase.html#property_SchedulerBase.HTML_PARSER"
    },
    "SchedulerBase.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.SchedulerBase.html#property_SchedulerBase.UI_ATTRS"
    },
    "SchedulerBase.AUGMENTS": {
     "!type": "+Array",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.SchedulerBase.html#property_SchedulerBase.AUGMENTS"
    }
   },
   "A.SchedulerEventRecorder": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerEventRecorder",
    "!proto": "aui_scheduler.A.SchedulerEvent",
    "!doc": "A base class for SchedulerEventRecorder.",
    "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html",
    "SchedulerEventRecorder.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#property_SchedulerEventRecorder.NAME"
    },
    "SchedulerEventRecorder.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerEventRecorder.",
     "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#property_SchedulerEventRecorder.ATTRS"
    },
    "prototype": {
     "allDay": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#attribute_allDay"
     },
     "content": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#attribute_content"
     },
     "duration": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#attribute_duration"
     },
     "dateFormat": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#attribute_dateFormat"
     },
     "event": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#attribute_event"
     },
     "eventClass": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#attribute_eventClass"
     },
     "popover": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#attribute_popover"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#attribute_strings"
     },
     "template": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#attribute_template"
     },
     "getFormattedDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#method_getFormattedDate"
     },
     "getTemplateData": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#method_getTemplateData"
     },
     "getUpdatedSchedulerEvent": {
      "!type": "fn(optAttrMap)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#method_getUpdatedSchedulerEvent"
     },
     "hidePopover": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#method_hidePopover"
     },
     "populateForm": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#method_populateForm"
     },
     "serializeForm": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#method_serializeForm"
     }
    },
    "SchedulerEventRecorder.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.SchedulerEventRecorder.html#property_SchedulerEventRecorder.EXTENDS"
    }
   },
   "A.SchedulerAgendaView": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerAgendaView",
    "!proto": "aui_scheduler.A.SchedulerView",
    "!doc": "A base class for SchedulerAgendaView.",
    "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html",
    "SchedulerAgendaView.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#property_SchedulerAgendaView.NAME"
    },
    "SchedulerAgendaView.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerAgendaView.",
     "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#property_SchedulerAgendaView.ATTRS"
    },
    "prototype": {
     "bodyContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#attribute_bodyContent"
     },
     "eventsDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#attribute_eventsDateFormatter"
     },
     "headerDayDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#attribute_headerDayDateFormatter"
     },
     "headerExtraDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#attribute_headerExtraDateFormatter"
     },
     "infoDayDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#attribute_infoDayDateFormatter"
     },
     "infoLabelBigDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#attribute_infoLabelBigDateFormatter"
     },
     "infoLabelSmallDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#attribute_infoLabelSmallDateFormatter"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#attribute_name"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#attribute_strings"
     },
     "getNextDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#method_getNextDate"
     },
     "getPrevDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#method_getPrevDate"
     },
     "plotEvents": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#method_plotEvents"
     }
    },
    "SchedulerAgendaView.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.SchedulerAgendaView.html#property_SchedulerAgendaView.EXTENDS"
    }
   },
   "A.SchedulerDayView": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerDayView",
    "!proto": "aui_scheduler.A.SchedulerView",
    "!doc": "A base class for SchedulerDayView.",
    "!url": "http://alloyui.com/classes/A.SchedulerDayView.html",
    "SchedulerDayView.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#property_SchedulerDayView.NAME"
    },
    "SchedulerDayView.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerDayView.",
     "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#property_SchedulerDayView.ATTRS"
    },
    "prototype": {
     "bodyContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_bodyContent"
     },
     "days": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_days"
     },
     "delegateConfig": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_delegateConfig"
     },
     "eventWidth": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_eventWidth"
     },
     "filterFn": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_filterFn"
     },
     "headerDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_headerDateFormatter"
     },
     "headerView": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_headerView"
     },
     "headerViewConfig": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_headerViewConfig"
     },
     "hourHeight": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_hourHeight"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_name"
     },
     "navigationDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_navigationDateFormatter"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_strings"
     },
     "headerTableNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_headerTableNode"
     },
     "headerViewLabelNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_headerViewLabelNode"
     },
     "resizerNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_resizerNode"
     },
     "tableNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_tableNode"
     },
     "colDaysNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_colDaysNode"
     },
     "colHeaderDaysNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_colHeaderDaysNode"
     },
     "markercellsNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_markercellsNode"
     },
     "timesNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#attribute_timesNode"
     },
     "syncStdContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_syncStdContent"
     },
     "calculateEventHeight": {
      "!type": "fn(duration)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_calculateEventHeight"
     },
     "calculateTop": {
      "!type": "fn(date)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_calculateTop"
     },
     "getNextDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_getNextDate"
     },
     "getPrevDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_getPrevDate"
     },
     "getColumnByDate": {
      "!type": "fn(date)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_getColumnByDate"
     },
     "getColumnShimByDate": {
      "!type": "fn(date)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_getColumnShimByDate"
     },
     "getDateByColumn": {
      "!type": "fn(colNumber)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_getDateByColumn"
     },
     "getDateDaysOffset": {
      "!type": "fn(date)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_getDateDaysOffset"
     },
     "getYCoordTime": {
      "!type": "fn(top)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_getYCoordTime"
     },
     "plotEvent": {
      "!type": "fn(evt)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_plotEvent"
     },
     "plotEvents": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_plotEvents"
     },
     "syncColumnsUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_syncColumnsUI"
     },
     "syncDaysHeaderUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_syncDaysHeaderUI"
     },
     "syncEventsIntersectionUI": {
      "!type": "fn(columnEvents)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_syncEventsIntersectionUI"
     },
     "syncEventHeightUI": {
      "!type": "fn(evt)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_syncEventHeightUI"
     },
     "syncEventTopUI": {
      "!type": "fn(evt)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_syncEventTopUI"
     },
     "syncHeaderViewUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_syncHeaderViewUI"
     },
     "calculateYDelta": {
      "!type": "fn(startXY, xy)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_calculateYDelta"
     },
     "findEventIntersections": {
      "!type": "fn(evt, events)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_findEventIntersections"
     },
     "getXYDelta": {
      "!type": "fn(event)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_getXYDelta"
     },
     "getTickY": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_getTickY"
     },
     "roundToNearestHour": {
      "!type": "fn(date, time)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#method_roundToNearestHour"
     }
    },
    "SchedulerDayView.HTML_PARSER": {
     "!type": "+typeName",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#property_SchedulerDayView.HTML_PARSER"
    },
    "SchedulerDayView.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.SchedulerDayView.html#property_SchedulerDayView.EXTENDS"
    }
   },
   "A.SchedulerMonthView": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerMonthView",
    "!proto": "aui_scheduler.A.SchedulerTableView",
    "!doc": "A base class for SchedulerMonthView.",
    "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html",
    "SchedulerMonthView.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html#property_SchedulerMonthView.NAME"
    },
    "SchedulerMonthView.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerMonthView.",
     "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html#property_SchedulerMonthView.ATTRS"
    },
    "prototype": {
     "displayDaysInterval": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html#attribute_displayDaysInterval"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html#attribute_name"
     },
     "navigationDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html#attribute_navigationDateFormatter"
     },
     "getAdjustedViewDate": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html#method_getAdjustedViewDate"
     },
     "getNextDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html#method_getNextDate"
     },
     "getPrevDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html#method_getPrevDate"
     },
     "plotEvents": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html#method_plotEvents"
     }
    },
    "SchedulerMonthView.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.SchedulerMonthView.html#property_SchedulerMonthView.EXTENDS"
    }
   },
   "A.SchedulerTableViewDD": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerTableViewDD",
    "!doc": "A base class for SchedulerTableViewDD.",
    "!url": "http://alloyui.com/classes/A.SchedulerTableViewDD.html",
    "SchedulerTableViewDD.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerTableViewDD.",
     "!url": "http://alloyui.com/classes/A.SchedulerTableViewDD.html#property_SchedulerTableViewDD.ATTRS"
    },
    "prototype": {
     "delegateConfig": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableViewDD.html#attribute_delegateConfig"
     },
     "viewDDBindUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableViewDD.html#method_viewDDBindUI"
     },
     "viewDDRenderUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableViewDD.html#method_viewDDRenderUI"
     },
     "viewDDSyncUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableViewDD.html#method_viewDDSyncUI"
     },
     "removeLasso": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableViewDD.html#method_removeLasso"
     },
     "removeProxy": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableViewDD.html#method_removeProxy"
     },
     "renderLasso": {
      "!type": "fn(startPos, endPos)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableViewDD.html#method_renderLasso"
     }
    }
   },
   "A.SchedulerTableView": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerTableView",
    "!proto": "aui_scheduler.A.SchedulerView",
    "!doc": "A base class for SchedulerTableView.",
    "!url": "http://alloyui.com/classes/A.SchedulerTableView.html",
    "SchedulerTableView.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#property_SchedulerTableView.NAME"
    },
    "SchedulerTableView.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerTableView.",
     "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#property_SchedulerTableView.ATTRS"
    },
    "prototype": {
     "bodyContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_bodyContent"
     },
     "displayDaysInterval": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_displayDaysInterval"
     },
     "displayRows": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_displayRows"
     },
     "fixedHeight": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_fixedHeight"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_name"
     },
     "headerDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_headerDateFormatter"
     },
     "navigationDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_navigationDateFormatter"
     },
     "scrollable": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_scrollable"
     },
     "strings": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_strings"
     },
     "headerTableNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_headerTableNode"
     },
     "colHeaderDaysNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_colHeaderDaysNode"
     },
     "rowsContainerNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_rowsContainerNode"
     },
     "tableGridNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#attribute_tableGridNode"
     },
     "buildEventsRow": {
      "!type": "fn(rowStartDate, rowEndDate, rowDisplayIndex)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_buildEventsRow"
     },
     "buildEventsTable": {
      "!type": "fn(rowStartDate, rowEndDate)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_buildEventsTable"
     },
     "buildEventsTitleRow": {
      "!type": "fn(tableNode, rowStartDate, rowEndDate)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_buildEventsTitleRow"
     },
     "buildGridRowNode": {
      "!type": "fn(rowIndex)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_buildGridRowNode"
     },
     "flushViewCache": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_flushViewCache"
     },
     "getIntersectEvents": {
      "!type": "fn(date)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_getIntersectEvents"
     },
     "getNextDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_getNextDate"
     },
     "getPrevDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_getPrevDate"
     },
     "hideEventsOverlay": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_hideEventsOverlay"
     },
     "loopDates": {
      "!type": "fn(startDate, endDate, fn, incrementBy, factor)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_loopDates"
     },
     "plotEvents": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_plotEvents"
     },
     "syncDaysHeaderUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_syncDaysHeaderUI"
     },
     "syncGridUI": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_syncGridUI"
     },
     "syncStdContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#method_syncStdContent"
     }
    },
    "SchedulerTableView.HTML_PARSER": {
     "!type": "+Object",
     "!doc": "TODO. Wanna help? Please send a Pull Request.",
     "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#property_SchedulerTableView.HTML_PARSER"
    },
    "SchedulerTableView.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.SchedulerTableView.html#property_SchedulerTableView.EXTENDS"
    }
   },
   "A.SchedulerWeekView": {
    "!type": "fn(config: Object) -> +aui_scheduler.A.SchedulerWeekView",
    "!proto": "aui_scheduler.A.SchedulerDayView",
    "!doc": "A base class for SchedulerWeekView.",
    "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html",
    "SchedulerWeekView.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#property_SchedulerWeekView.NAME"
    },
    "SchedulerWeekView.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SchedulerWeekView.",
     "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#property_SchedulerWeekView.ATTRS"
    },
    "prototype": {
     "bodyContent": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#attribute_bodyContent"
     },
     "days": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#attribute_days"
     },
     "headerViewConfig": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#attribute_headerViewConfig"
     },
     "name": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#attribute_name"
     },
     "navigationDateFormatter": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#attribute_navigationDateFormatter"
     },
     "getAdjustedViewDate": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#method_getAdjustedViewDate"
     },
     "getNextDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#method_getNextDate"
     },
     "getPrevDate": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#method_getPrevDate"
     },
     "getToday": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#method_getToday"
     }
    },
    "SchedulerWeekView.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.SchedulerWeekView.html#property_SchedulerWeekView.EXTENDS"
    }
   }
  },
  "aui_search": {
   "A.TernarySearchNode": {
    "!type": "fn(config: Object) -> +aui_search.A.TernarySearchNode",
    "!proto": "A.Base",
    "!doc": "A base class for TernarySearchNode.",
    "!url": "http://alloyui.com/classes/A.TernarySearchNode.html",
    "TernarySearchNode.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TernarySearchNode.html#property_TernarySearchNode.NAME"
    },
    "TernarySearchNode.NS": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the namespace.",
     "!url": "http://alloyui.com/classes/A.TernarySearchNode.html#property_TernarySearchNode.NS"
    },
    "TernarySearchNode.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TernarySearchNode.",
     "!url": "http://alloyui.com/classes/A.TernarySearchNode.html#property_TernarySearchNode.ATTRS"
    },
    "prototype": {
     "character": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchNode.html#attribute_character"
     },
     "child": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchNode.html#attribute_child"
     },
     "largerNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchNode.html#attribute_largerNode"
     },
     "smallerNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchNode.html#attribute_smallerNode"
     },
     "word": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchNode.html#attribute_word"
     },
     "isEndOfWord": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchNode.html#method_isEndOfWord"
     }
    },
    "TernarySearchNode.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.TernarySearchNode.html#property_TernarySearchNode.EXTENDS"
    }
   },
   "A.TernarySearchTree": {
    "!type": "fn(config: Object) -> +aui_search.A.TernarySearchTree",
    "!proto": "A.Base",
    "!doc": "A base class for TernarySearchTree.",
    "!url": "http://alloyui.com/classes/A.TernarySearchTree.html",
    "TernarySearchTree.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TernarySearchTree.html#property_TernarySearchTree.NAME"
    },
    "TernarySearchTree.NS": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the namespace.",
     "!url": "http://alloyui.com/classes/A.TernarySearchTree.html#property_TernarySearchTree.NS"
    },
    "TernarySearchTree.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.TernarySearchTree.html#property_TernarySearchTree.EXTENDS"
    },
    "prototype": {
     "add": {
      "!type": "fn(word)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchTree.html#method_add"
     },
     "contains": {
      "!type": "fn(word)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchTree.html#method_contains"
     },
     "empty": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchTree.html#method_empty"
     },
     "patternMatch": {
      "!type": "fn(pattern)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchTree.html#method_patternMatch"
     },
     "prefixSearch": {
      "!type": "fn(prefix)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TernarySearchTree.html#method_prefixSearch"
     }
    }
   }
  },
  "aui_selector": {
   "A.Selector": {
    "!type": "fn() -> +aui_selector.A.Selector",
    "!doc": "Augment the <a href=\"Selector.html\">YUI3 Selector</a> with more util methods.",
    "!url": "http://alloyui.com/classes/A.Selector.html",
    "prototype": {
     "button": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_button"
     },
     "checkbox": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_checkbox"
     },
     "checked": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_checked"
     },
     "disabled": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_disabled"
     },
     "empty": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_empty"
     },
     "enabled": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_enabled"
     },
     "file": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_file"
     },
     "header": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_header"
     },
     "hidden": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_hidden"
     },
     "image": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_image"
     },
     "input": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_input"
     },
     "parent": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_parent"
     },
     "password": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_password"
     },
     "radio": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_radio"
     },
     "reset": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_reset"
     },
     "selected": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_selected"
     },
     "submit": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_submit"
     },
     "text": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_text"
     },
     "visible": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Selector.html#method_visible"
     }
    }
   }
  },
  "aui_sortable_layout": {
   "A.SortableLayout": {
    "!type": "fn(config: Object) -> +aui_sortable_layout.A.SortableLayout",
    "!proto": "A.Base",
    "!doc": "A base class for SortableLayout, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>DragDrop utility for drag lists, portal layouts (portlets)</li>\n</ul>\n\nCheck the [live demo](http://alloyui.com/examples/sortable-layout/).",
    "!url": "http://alloyui.com/classes/A.SortableLayout.html",
    "SortableLayout.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SortableLayout.html#property_SortableLayout.NAME"
    },
    "SortableLayout.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SortableLayout.",
     "!url": "http://alloyui.com/classes/A.SortableLayout.html#property_SortableLayout.ATTRS"
    },
    "prototype": {
     "delegateConfig": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#attribute_delegateConfig"
     },
     "proxyNode": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#attribute_proxyNode"
     },
     "dragNodes": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#attribute_dragNodes"
     },
     "dropContainer": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#attribute_dropContainer"
     },
     "dropNodes": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#attribute_dropNodes"
     },
     "groups": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#attribute_groups"
     },
     "lazyStart": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#attribute_lazyStart"
     },
     "placeholder": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#attribute_placeholder"
     },
     "proxy": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#attribute_proxy"
     },
     "addDropNode": {
      "!type": "fn(node, config)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#method_addDropNode"
     },
     "addDropTarget": {
      "!type": "fn(drop)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#method_addDropTarget"
     },
     "alignPlaceholder": {
      "!type": "fn(region, isTarget)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#method_alignPlaceholder"
     },
     "calculateDirections": {
      "!type": "fn(drag)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#method_calculateDirections"
     },
     "calculateQuadrant": {
      "!type": "fn(drag, drop)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#method_calculateQuadrant"
     },
     "getPlaceholderXY": {
      "!type": "fn(region, isTarget)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#method_getPlaceholderXY"
     },
     "removeDropTarget": {
      "!type": "fn(drop)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableLayout.html#method_removeDropTarget"
     }
    },
    "SortableLayout.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.SortableLayout.html#property_SortableLayout.EXTENDS"
    }
   }
  },
  "aui_sortable_list": {
   "A.SortableList": {
    "!type": "fn(config: Object) -> +aui_sortable_list.A.SortableList",
    "!proto": "A.Base",
    "!doc": "A base class for SortableList, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Sortable list utility</li>\n</ul>\n\nCheck the [live demo](http://alloyui.com/examples/sortable-list/).",
    "!url": "http://alloyui.com/classes/A.SortableList.html",
    "SortableList.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.SortableList.html#property_SortableList.NAME"
    },
    "SortableList.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the SortableList.",
     "!url": "http://alloyui.com/classes/A.SortableList.html#property_SortableList.ATTRS"
    },
    "prototype": {
     "dd": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#attribute_dd"
     },
     "dropCondition": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#attribute_dropCondition"
     },
     "dropContainer": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#attribute_dropContainer"
     },
     "dropOn": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#attribute_dropOn"
     },
     "helper": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#attribute_helper"
     },
     "nodes": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#attribute_nodes"
     },
     "placeholder": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#attribute_placeholder"
     },
     "proxy": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#attribute_proxy"
     },
     "sortCondition": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#attribute_sortCondition"
     },
     "add": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#method_add"
     },
     "addAll": {
      "!type": "fn(nodes)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.SortableList.html#method_addAll"
     }
    },
    "SortableList.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.SortableList.html#property_SortableList.EXTENDS"
    }
   }
  },
  "aui_tabview": {
   "A.Tab": {
    "!type": "fn(config: Object) -> +aui_tabview.A.Tab",
    "!doc": "A base class for Tab.\n\nCheck the [live demo](http://alloyui.com/examples/tabview/).",
    "!url": "http://alloyui.com/classes/A.Tab.html",
    "Tab.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Tab.html#property_Tab.NAME"
    },
    "prototype": {
     "disabled": {
      "!type": "fn()",
      "!url": "http://alloyui.com/classes/A.Tab.html#attribute_disabled"
     }
    },
    "Tab.CSS_PREFIX": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the CSS prefix.",
     "!url": "http://alloyui.com/classes/A.Tab.html#property_Tab.CSS_PREFIX"
    },
    "Tab.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.Tab.html#property_Tab.EXTENDS"
    }
   },
   "A.TabView": {
    "!type": "fn(config: Object) -> +aui_tabview.A.TabView",
    "!proto": "TabView",
    "!doc": "A base class for TabView.\n\nCheck the [live demo](http://alloyui.com/examples/tabview/).",
    "!url": "http://alloyui.com/classes/A.TabView.html",
    "TabView.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TabView.html#property_TabView.NAME"
    },
    "TabView.CSS_PREFIX": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the CSS prefix.",
     "!url": "http://alloyui.com/classes/A.TabView.html#property_TabView.CSS_PREFIX"
    },
    "TabView.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TabView.",
     "!url": "http://alloyui.com/classes/A.TabView.html#property_TabView.ATTRS"
    },
    "prototype": {
     "stacked": {
      "!type": "fn()",
      "!doc": "Determine the orientation of tabs.\nCan be stacked (vertical) or not (horizontal).",
      "!url": "http://alloyui.com/classes/A.TabView.html#attribute_stacked"
     },
     "type": {
      "!type": "fn()",
      "!doc": "Determine the type of tabs.",
      "!url": "http://alloyui.com/classes/A.TabView.html#attribute_type"
     },
     "disableTab": {
      "!type": "fn(i)",
      "!doc": "Disable tab based on its index.",
      "!url": "http://alloyui.com/classes/A.TabView.html#method_disableTab"
     },
     "enableTab": {
      "!type": "fn(i)",
      "!doc": "Enable tab based on its index.",
      "!url": "http://alloyui.com/classes/A.TabView.html#method_enableTab"
     },
     "getActiveTab": {
      "!type": "fn()",
      "!doc": "Get the tabs.",
      "!url": "http://alloyui.com/classes/A.TabView.html#method_getActiveTab"
     }
    },
    "TabView.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.TabView.html#property_TabView.UI_ATTRS"
    },
    "TabView.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.TabView.html#property_TabView.EXTENDS"
    }
   },
   "Textboxlist": {
    "!type": "fn(config: Object) -> +aui_textboxlist.Textboxlist",
    "!proto": "aui_autocomplete.AutoComplete",
    "!doc": "A base class for Textboxlist, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Text box list</li>\n</ul>\n\nCheck the list of <a href=\"Textboxlist.html#configattributes\">Configuration Attributes</a> available for\nTextboxlist.",
    "!url": "http://alloyui.com/classes/Textboxlist.html",
    "prototype": {
     "undefined": {
      "!type": "fn()",
      "!doc": "Mapping UTF-8 groups of characters. Based on Steven Levithan's XRegExp\nproject (http://xregexp.com)",
      "!url": "http://alloyui.com/classes/Textboxlist.html"
     }
    }
   }
  },
  "aui_text": {
   "Textboxlist": {
    "!type": "fn(config: Object) -> +aui_textboxlist.Textboxlist",
    "!proto": "aui_autocomplete.AutoComplete",
    "!doc": "A base class for Textboxlist, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Text box list</li>\n</ul>\n\nCheck the list of <a href=\"Textboxlist.html#configattributes\">Configuration Attributes</a> available for\nTextboxlist.",
    "!url": "http://alloyui.com/classes/Textboxlist.html",
    "prototype": {
     "match": {
      "!type": "fn(str: string, group: string, flags: string)",
      "!doc": "Tests a string against an Unicode pattern. Returns the first match.",
      "!url": "http://alloyui.com/classes/Textboxlist.html#method_match"
     },
     "test": {
      "!type": "fn(str: string, group: string, flags: string)",
      "!doc": "Tests a string against an Unicode pattern. Returns true or false.",
      "!url": "http://alloyui.com/classes/Textboxlist.html#method_test"
     }
    }
   }
  },
  "aui_textboxlist": {
   "Textboxlist": {
    "!type": "fn(config: Object) -> +aui_textboxlist.Textboxlist",
    "!proto": "aui_autocomplete.AutoComplete",
    "!doc": "A base class for Textboxlist, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Text box list</li>\n</ul>\n\nCheck the list of <a href=\"Textboxlist.html#configattributes\">Configuration Attributes</a> available for\nTextboxlist.",
    "!url": "http://alloyui.com/classes/Textboxlist.html",
    "Textboxlist.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/Textboxlist.html#property_Textboxlist.NAME"
    },
    "Textboxlist.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Textboxlist.",
     "!url": "http://alloyui.com/classes/Textboxlist.html#property_Textboxlist.ATTRS"
    }
   }
  },
  "aui_timepicker": {
   "A.TimePickerBase": {
    "!type": "fn(config: Object) -> +aui_timepicker.A.TimePickerBase",
    "!doc": "A base class for TimePickerBase.",
    "!url": "http://alloyui.com/classes/A.TimePickerBase.html",
    "TimePickerBase.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TimePickerBase.",
     "!url": "http://alloyui.com/classes/A.TimePickerBase.html#property_TimePickerBase.ATTRS"
    },
    "prototype": {
     "autocomplete": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TimePickerBase.html#attribute_autocomplete"
     },
     "dateSeparator": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TimePickerBase.html#attribute_dateSeparator"
     },
     "mask": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TimePickerBase.html#attribute_mask"
     },
     "popoverCssClass": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TimePickerBase.html#attribute_popoverCssClass"
     },
     "values": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TimePickerBase.html#attribute_values"
     },
     "clearSelection": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TimePickerBase.html#method_clearSelection"
     },
     "getAutoComplete": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TimePickerBase.html#method_getAutoComplete"
     },
     "selectDates": {
      "!type": "fn(dates)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TimePickerBase.html#method_selectDates"
     },
     "useInputNode": {
      "!type": "fn(node)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.TimePickerBase.html#method_useInputNode"
     }
    }
   }
  },
  "aui_timer": {
   "A.Toggler": {
    "!type": "fn(config: Object) -> +aui_toggler.A.Toggler",
    "!proto": "A.Base",
    "!doc": "A base class for Toggler.\n\nCheck the [live demo](http://alloyui.com/examples/toggler/).",
    "!url": "http://alloyui.com/classes/A.Toggler.html",
    "prototype": {
     "clearInterval": {
      "!type": "fn(id)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_clearInterval"
     },
     "clearTimeout": {
      "!type": "fn(id)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_clearTimeout"
     },
     "intervalTime": {
      "!type": "fn(newInterval)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_intervalTime"
     },
     "isRepeatable": {
      "!type": "fn(task)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_isRepeatable"
     },
     "setTimeout": {
      "!type": "fn(fn, ms, context)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_setTimeout"
     },
     "setInterval": {
      "!type": "fn(fn, ms, context)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_setInterval"
     },
     "register": {
      "!type": "fn(repeats, fn, ms, context, args)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_register"
     },
     "run": {
      "!type": "fn(task)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_run"
     },
     "unregister": {
      "!type": "fn(repeats, id)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_unregister"
     }
    }
   }
  },
  "aui_toggler": {
   "A.Toggler": {
    "!type": "fn(config: Object) -> +aui_toggler.A.Toggler",
    "!proto": "A.Base",
    "!doc": "A base class for Toggler.\n\nCheck the [live demo](http://alloyui.com/examples/toggler/).",
    "!url": "http://alloyui.com/classes/A.Toggler.html",
    "Toggler.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Toggler.html#property_Toggler.NAME"
    },
    "Toggler.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Toggler.",
     "!url": "http://alloyui.com/classes/A.Toggler.html#property_Toggler.ATTRS"
    },
    "prototype": {
     "animated": {
      "!type": "fn()",
      "!doc": "Determine if the Toggler transitions will animate.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#attribute_animated"
     },
     "animating": {
      "!type": "fn()",
      "!doc": "Determine if the Toggler transitions are being animated in that moment.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#attribute_animating"
     },
     "bindDOMEvents": {
      "!type": "fn()",
      "!doc": "Determine if the Toggler should bind DOM events or not.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#attribute_bindDOMEvents"
     },
     "content": {
      "!type": "fn()",
      "!doc": "The content of a Toogler instance.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#attribute_content"
     },
     "expanded": {
      "!type": "fn()",
      "!doc": "Determine if the content starts as toggled on/off on page load.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#attribute_expanded"
     },
     "header": {
      "!type": "fn()",
      "!doc": "The header of a Toogler instance.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#attribute_header"
     },
     "transition": {
      "!type": "fn()",
      "!doc": "Transition definitions such as duration and type of easing effect.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#attribute_transition"
     },
     "headerEventHandler": {
      "!type": "fn(event, instance)",
      "!doc": "Handle header events.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_headerEventHandler"
     },
     "animate": {
      "!type": "fn(config, fn)",
      "!doc": "Expand Toggler with an animation.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_animate"
     },
     "collapse": {
      "!type": "fn()",
      "!doc": "Hide Toggler content.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_collapse"
     },
     "expand": {
      "!type": "fn()",
      "!doc": "Show Toggler content.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_expand"
     },
     "getContentHeight": {
      "!type": "fn() -> number",
      "!doc": "Return the height of content.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_getContentHeight"
     },
     "toggle": {
      "!type": "fn(expand)",
      "!doc": "Show or hide content.",
      "!url": "http://alloyui.com/classes/A.Toggler.html#method_toggle"
     }
    },
    "Toggler.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.Toggler.html#property_Toggler.EXTENDS"
    }
   },
   "A.TogglerDelegate": {
    "!type": "fn(config: Object) -> +aui_toggler.A.TogglerDelegate",
    "!proto": "A.Base",
    "!doc": "A base class for Toggler Delegate.\n\nCheck the [live demo](http://alloyui.com/examples/toggler/).",
    "!url": "http://alloyui.com/classes/A.TogglerDelegate.html",
    "TogglerDelegate.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#property_TogglerDelegate.NAME"
    },
    "TogglerDelegate.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Toggler Delegate.",
     "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#property_TogglerDelegate.ATTRS"
    },
    "prototype": {
     "animated": {
      "!type": "fn()",
      "!doc": "Determine if the Toggler Delegate transitions will animate.",
      "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#attribute_animated"
     },
     "closeAllOnExpand": {
      "!type": "fn()",
      "!doc": "Determine if the Toggler Delegate switches\nwill be set to off when one switch is toggled on.",
      "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#attribute_closeAllOnExpand"
     },
     "container": {
      "!type": "fn()",
      "!doc": "The container of Toggler Delegate instance.",
      "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#attribute_container"
     },
     "content": {
      "!type": "fn()",
      "!doc": "The content of a Toogler Delegate instance.",
      "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#attribute_content"
     },
     "expanded": {
      "!type": "fn()",
      "!doc": "Determine if the content starts as toggled on/off on page load.",
      "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#attribute_expanded"
     },
     "header": {
      "!type": "fn()",
      "!doc": "The header of a Toogler Delegate instance.",
      "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#attribute_header"
     },
     "transition": {
      "!type": "fn()",
      "!doc": "Transition definitions such as duration and type of easing effect.",
      "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#attribute_transition"
     },
     "collapseAll": {
      "!type": "fn()",
      "!doc": "Expand all items.",
      "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#method_collapseAll"
     },
     "createAll": {
      "!type": "fn()",
      "!doc": "Forces toggler creation on delegated header elements.",
      "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#method_createAll"
     },
     "headerEventHandler": {
      "!type": "fn(event)",
      "!doc": "Handle header events.",
      "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#method_headerEventHandler"
     }
    },
    "TogglerDelegate.EXTENDS": {
     "!type": "+Object",
     "!doc": "Static property used to define which component it extends.",
     "!url": "http://alloyui.com/classes/A.TogglerDelegate.html#property_TogglerDelegate.EXTENDS"
    }
   },
   "A.Toolbar": {
    "!type": "fn(config: Object) -> +aui_toolbar.A.Toolbar",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for Toolbar.\n\nCheck the [live demo](http://alloyui.com/examples/toolbar/).",
    "!url": "http://alloyui.com/classes/A.Toolbar.html",
    "prototype": {
     "undefined": {
      "!type": "fn()",
      "!doc": "Checks if the path to the node is fully expanded. A path to a node\nshould typically include all its toggler-content ancestors.",
      "!url": "http://alloyui.com/classes/A.Toolbar.html"
     }
    }
   }
  },
  "aui_toolbar": {
   "A.Toolbar": {
    "!type": "fn(config: Object) -> +aui_toolbar.A.Toolbar",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for Toolbar.\n\nCheck the [live demo](http://alloyui.com/examples/toolbar/).",
    "!url": "http://alloyui.com/classes/A.Toolbar.html",
    "Toolbar.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Toolbar.html#property_Toolbar.NAME"
    },
    "Toolbar.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Toolbar.",
     "!url": "http://alloyui.com/classes/A.Toolbar.html#property_Toolbar.ATTRS"
    },
    "prototype": {
     "children": {
      "!type": "fn()",
      "!doc": "A list of child elements.",
      "!url": "http://alloyui.com/classes/A.Toolbar.html#attribute_children"
     },
     "toolbarRenderer": {
      "!type": "fn()",
      "!doc": "Define a new <code>ToolbarRenderer</code>.",
      "!url": "http://alloyui.com/classes/A.Toolbar.html#attribute_toolbarRenderer"
     },
     "add": {
      "!type": "fn(children, where)",
      "!doc": "Insert children on Toolbar.",
      "!url": "http://alloyui.com/classes/A.Toolbar.html#method_add"
     },
     "clear": {
      "!type": "fn()",
      "!doc": "Clear children from Toolbar.",
      "!url": "http://alloyui.com/classes/A.Toolbar.html#method_clear"
     },
     "getEnclosingWidget": {
      "!type": "fn(seed)",
      "!doc": "Find the first ancestor node that is a widget bounding box.",
      "!url": "http://alloyui.com/classes/A.Toolbar.html#method_getEnclosingWidget"
     },
     "item": {
      "!type": "fn(index)",
      "!doc": "Get a certain item based on its index.",
      "!url": "http://alloyui.com/classes/A.Toolbar.html#method_item"
     },
     "remove": {
      "!type": "fn(where)",
      "!doc": "Remove children from Toolbar.",
      "!url": "http://alloyui.com/classes/A.Toolbar.html#method_remove"
     }
    },
    "Toolbar.UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the UI attributes.",
     "!url": "http://alloyui.com/classes/A.Toolbar.html#property_Toolbar.UI_ATTRS"
    },
    "A.Toolbar.isSupportedWidget": {
     "!type": "fn(o)",
     "!doc": "Check if type is supported.",
     "!url": "http://alloyui.com/classes/A.Toolbar.html#method_A.Toolbar.isSupportedWidget"
    },
    "CONTENT_TEMPLATE": {
     "!type": "?",
     "!doc": "Static property provide a content template.",
     "!url": "http://alloyui.com/classes/A.Toolbar.html#property_CONTENT_TEMPLATE"
    },
    "TEMPLATES": {
     "!type": "+Object",
     "!doc": "Static property provide a group of templates.",
     "!url": "http://alloyui.com/classes/A.Toolbar.html#property_TEMPLATES"
    }
   },
   "A.ToolbarRenderer": {
    "!type": "fn(config: Object) -> +aui_toolbar.A.ToolbarRenderer",
    "!doc": "A base class for ToolbarRenderer.\n\nCheck the [live demo](http://alloyui.com/examples/toolbar/).",
    "!url": "http://alloyui.com/classes/A.ToolbarRenderer.html",
    "ToolbarRenderer.TEMPLATES": {
     "!type": "+Object",
     "!doc": "Static property provides a set of templates.",
     "!url": "http://alloyui.com/classes/A.ToolbarRenderer.html#property_ToolbarRenderer.TEMPLATES"
    },
    "ToolbarRenderer.RENDERER": {
     "!type": "+Object",
     "!doc": "Static property used to define how\nthings are going to be rendered.",
     "!url": "http://alloyui.com/classes/A.ToolbarRenderer.html#property_ToolbarRenderer.RENDERER"
    },
    "prototype": {
     "button": {
      "!type": "fn(childRenderHints)",
      "!doc": "Define how a button should be rendered.",
      "!url": "http://alloyui.com/classes/A.ToolbarRenderer.html#method_button"
     },
     "group": {
      "!type": "fn(childRenderHints)",
      "!doc": "Define how a group should be rendered.",
      "!url": "http://alloyui.com/classes/A.ToolbarRenderer.html#method_group"
     },
     "render": {
      "!type": "fn(children)",
      "!doc": "Render children in a document fragment.",
      "!url": "http://alloyui.com/classes/A.ToolbarRenderer.html#method_render"
     },
     "renderNode": {
      "!type": "fn(child)",
      "!doc": "Render node.",
      "!url": "http://alloyui.com/classes/A.ToolbarRenderer.html#method_renderNode"
     }
    }
   }
  },
  "aui_tooltip": {
   "Tooltip": {
    "!type": "fn(config: Object) -> +aui_tooltip.Tooltip",
    "!proto": "Widget",
    "!doc": "<p><img src=\"assets/images/aui-tooltip/main.png\"/></p>\n\nA base class for Tooltip, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Additional information when hovering over a target element</li>\n</ul>\n\nQuick Example:<br/>\n\n<pre><code>var instance = new A.Tooltip({\n\ttrigger: '#element',\n\talign: { points: [ 'lc', 'rc' ] },\n\tbodyContent: 'Simple tooltip'\n}).render();\n</code></pre>\n\nCheck the list of <a href=\"Tooltip.html#configattributes\">Configuration Attributes</a> available for\nTooltip.",
    "!url": "http://alloyui.com/classes/Tooltip.html",
    "Tooltip.CSS_PREFIX": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the CSS prefix.",
     "!url": "http://alloyui.com/classes/Tooltip.html#property_Tooltip.CSS_PREFIX"
    },
    "A.Tooltip.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Tooltip.",
     "!url": "http://alloyui.com/classes/Tooltip.html#property_A.Tooltip.ATTRS"
    },
    "prototype": {
     "bodyContent": {
      "!type": "fn()",
      "!doc": "Determine the bodyContent",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_bodyContent"
     },
     "constrain": {
      "!type": "fn()",
      "!doc": "Determine the tooltip constrain node.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_constrain"
     },
     "duration": {
      "!type": "fn()",
      "!doc": "Determine the duration of the tooltip animation.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_duration"
     },
     "footerContent": {
      "!type": "fn()",
      "!doc": "Determine the footerContent",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_footerContent"
     },
     "formatter": {
      "!type": "fn()",
      "!doc": "Format the title attribute before set the content of the tooltip.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_formatter"
     },
     "headerContent": {
      "!type": "fn()",
      "!doc": "Determine the headerContent",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_headerContent"
     },
     "html": {
      "!type": "fn()",
      "!doc": "Determines if the tooltip allows arbitary HTML or is plain text.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_html"
     },
     "opacity": {
      "!type": "fn()",
      "!doc": "Determine the opacity of the tooltip.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_opacity"
     },
     "stickDuration": {
      "!type": "fn()",
      "!doc": "Determine the duration for the tooltip to stick visibility after\nthe mouse leaves the trigger element. By default the stick duration\nis not specified, therefore the tooltip starts the hide transition\nsynchronously.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_stickDuration"
     },
     "triggerShowEvent": {
      "!type": "fn()",
      "!doc": "DOM event to show the tooltip.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_triggerShowEvent"
     },
     "undefined": {
      "!type": "fn()",
      "!doc": "Prevents display:none from being applied to the tooltip when it is hidden because we\ncannot properly align a hidden tooltip with display:none since we can't accurately\nget its computed x and y position.",
      "!url": "http://alloyui.com/classes/Tooltip.html"
     },
     "anim": {
      "!type": "fn()",
      "!doc": "See <a href=\"OverlayContextPanel.html#config_anim\">OverlayContextPanel anim</a>.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_anim"
     },
     "align": {
      "!type": "fn()",
      "!doc": "See <a href=\"Overlay.html#config_align\">OverlayContextPanel align</a>.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_align"
     },
     "showOn": {
      "!type": "fn()",
      "!doc": "See <a href=\"OverlayContext.html#config_showOn\">OverlayContext showOn</a>.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_showOn"
     },
     "hideOn": {
      "!type": "fn()",
      "!doc": "See <a href=\"OverlayContext.html#config_showOn\">OverlayContext showOn</a>.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_hideOn"
     },
     "hideDelay": {
      "!type": "fn()",
      "!doc": "See <a href=\"OverlayContext.html#config_hideDelay\">OverlayContext hideDelay</a>.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_hideDelay"
     },
     "title": {
      "!type": "fn()",
      "!doc": "Use the content of the <code>title</code> attribute as the Tooltip\ncontent.",
      "!url": "http://alloyui.com/classes/Tooltip.html#attribute_title"
     },
     "show": {
      "!type": "fn()",
      "!doc": "Over-ride the <code>show</code> to invoke the\n<a href=\"Tooltip.html#method__loadBodyContentFromTitle\">_loadBodyContentFromTitle</a>.\nSee <a href=\"OverlayContext.html#config_show\">OverlayContext show</a>.",
      "!url": "http://alloyui.com/classes/Tooltip.html#method_show"
     }
    },
    "Tooltip.TEMPLATES": {
     "!type": "+Object",
     "!doc": "Static property provides a set of reusable templates.",
     "!url": "http://alloyui.com/classes/Tooltip.html#property_Tooltip.TEMPLATES"
    },
    "Tooltip.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/Tooltip.html#property_Tooltip.NAME"
    },
    "Tooltip.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Tooltip.",
     "!url": "http://alloyui.com/classes/Tooltip.html#property_Tooltip.ATTRS"
    }
   },
   "A.TooltipDelegate": {
    "!type": "fn(config: Object) -> +aui_tooltip.A.TooltipDelegate",
    "!proto": "A.Base",
    "!doc": "A base class for Toggler Delegate.\n\nCheck the [live demo](http://alloyui.com/examples/tooltip/).",
    "!url": "http://alloyui.com/classes/A.TooltipDelegate.html",
    "prototype": {
     "_onUserHideInteraction": {
      "!type": "fn(event)",
      "!doc": "Show tooltip on user interaction.",
      "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#method__onUserHideInteraction"
     },
     "_onUserShowInteraction": {
      "!type": "fn(event)",
      "!doc": "Show tooltip on user interaction.",
      "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#method__onUserShowInteraction"
     },
     "align": {
      "!type": "fn()",
      "!doc": "The alignment configuration for this widget.",
      "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#attribute_align"
     },
     "container": {
      "!type": "fn()",
      "!doc": "The container of Toggler Delegate instance.",
      "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#attribute_container"
     },
     "duration": {
      "!type": "fn()",
      "!doc": "Determine the duration of the tooltip animation.",
      "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#attribute_duration"
     },
     "html": {
      "!type": "fn()",
      "!doc": "Determines if the tooltip allows arbitary HTML or is plain text.",
      "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#attribute_html"
     },
     "opacity": {
      "!type": "fn()",
      "!doc": "Determine the opacity of the tooltip.",
      "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#attribute_opacity"
     },
     "triggerHideEvent": {
      "!type": "fn()",
      "!doc": "DOM event to hide the tooltip.",
      "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#attribute_triggerHideEvent"
     },
     "triggerShowEvent": {
      "!type": "fn()",
      "!doc": "DOM event to show the tooltip.",
      "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#attribute_triggerShowEvent"
     },
     "zIndex": {
      "!type": "fn()",
      "!doc": "Specify the zIndex for the tooltips.",
      "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#attribute_zIndex"
     }
    },
    "TooltipDelegate.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Toggler Delegate.",
     "!url": "http://alloyui.com/classes/A.TooltipDelegate.html#property_TooltipDelegate.ATTRS"
    }
   }
  },
  "aui_tree": {
   "A.TreeData": {
    "!type": "fn(config: Object) -> +aui_tree.A.TreeData",
    "!proto": "A.Base",
    "!doc": "A base class for TreeData, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>Handle the data of the tree</li>\n   <li>Basic DOM implementation (append/remove/insert)</li>\n   <li>Indexing management to handle the children nodes</li>\n</ul>",
    "!url": "http://alloyui.com/classes/A.TreeData.html",
    "TreeData.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TreeData.",
     "!url": "http://alloyui.com/classes/A.TreeData.html#property_TreeData.ATTRS"
    },
    "prototype": {
     "container": {
      "!type": "fn()",
      "!doc": "Container to nest children nodes. If it has a container it's not a leaf.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#attribute_container"
     },
     "children": {
      "!type": "fn()",
      "!doc": "Array of children (i.e. could be a JSON metadata object or a TreeNode instance).",
      "!url": "http://alloyui.com/classes/A.TreeData.html#attribute_children"
     },
     "index": {
      "!type": "fn()",
      "!doc": "Index the nodes.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#attribute_index"
     },
     "getNodeById": {
      "!type": "fn(uid: string) -> +aui_tree.TreeNode",
      "!doc": "Get a TreeNode by id.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_getNodeById"
     },
     "isRegistered": {
      "!type": "fn(node: aui_tree.TreeNode) -> bool",
      "!doc": "Whether the TreeNode is registered on this TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_isRegistered"
     },
     "updateReferences": {
      "!type": "fn(TreeNode: aui_node.Node, TreeNode: ParentNode, TreeView: OwnerTree)",
      "!doc": "Update the references of the passed TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_updateReferences"
     },
     "refreshIndex": {
      "!type": "fn()",
      "!doc": "Refresh the index (i.e. re-index all nodes).",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_refreshIndex"
     },
     "registerNode": {
      "!type": "fn(node: aui_tree.TreeNode)",
      "!doc": "Register the passed TreeNode on this TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_registerNode"
     },
     "updateIndex": {
      "!type": "fn(index: Object)",
      "!doc": "Update the <a href=\"TreeData.html#config_index\">index</a> attribute value.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_updateIndex"
     },
     "unregisterNode": {
      "!type": "fn(node: aui_tree.TreeNode)",
      "!doc": "Unregister the passed TreeNode from this TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_unregisterNode"
     },
     "collapseAll": {
      "!type": "fn()",
      "!doc": "Collapse all children of the TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_collapseAll"
     },
     "expandAll": {
      "!type": "fn()",
      "!doc": "Expand all children of the TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_expandAll"
     },
     "selectAll": {
      "!type": "fn()",
      "!doc": "Select all children of the TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_selectAll"
     },
     "unselectAll": {
      "!type": "fn()",
      "!doc": "Unselect all children of the TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_unselectAll"
     },
     "eachChildren": {
      "!type": "fn(fn: fn(), fn: bool)",
      "!doc": "Loop each children and execute the <code>fn</code> callback.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_eachChildren"
     },
     "eachParent": {
      "!type": "fn(fn: fn())",
      "!doc": "Loop each parent node and execute the <code>fn</code> callback.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_eachParent"
     },
     "bubbleEvent": {
      "!type": "fn(eventType: string, args: Array, cancelBubbling: bool, stopActionPropagation: bool)",
      "!doc": "Bubble event to all parent nodes.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_bubbleEvent"
     },
     "createNode": {
      "!type": "fn(options: Object) -> +aui_tree.TreeNode",
      "!doc": "Create a TreeNode instance.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_createNode"
     },
     "appendChild": {
      "!type": "fn(node: aui_tree.TreeNode, cancelBubbling: bool)",
      "!doc": "Append a child node to the TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_appendChild"
     },
     "item": {
      "!type": "fn(index: number) -> +aui_tree.TreeNode",
      "!doc": "Get a TreeNode children by index.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_item"
     },
     "indexOf": {
      "!type": "fn(node: aui_tree.TreeNode) -> number",
      "!doc": "Index of the passed TreeNode on the <a\nhref=\"TreeData.html#config_children\">children</a> attribute.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_indexOf"
     },
     "hasChildNodes": {
      "!type": "fn() -> bool",
      "!doc": "Whether the TreeData contains children or not.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_hasChildNodes"
     },
     "getChildren": {
      "!type": "fn(deep: bool) -> +Array",
      "!doc": "Get an Array of the children nodes of the current TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_getChildren"
     },
     "getEventOutputMap": {
      "!type": "fn(node: TreeData) -> +Object",
      "!doc": "Get an object containing metadata for the custom events.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_getEventOutputMap"
     },
     "removeChild": {
      "!type": "fn(node: TreeData)",
      "!doc": "Remove the passed <code>node</code> from the current TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_removeChild"
     },
     "_removeChild": {
      "!type": "fn(node: TreeData)",
      "!doc": "Remove the passed <code>node</code> from the current TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method__removeChild"
     },
     "empty": {
      "!type": "fn()",
      "!doc": "Delete all children of the current TreeData.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_empty"
     },
     "insert": {
      "!type": "fn(treeNode: aui_tree.TreeNode, refTreeNode: aui_tree.TreeNode, where: aui_tree.TreeNode)",
      "!doc": "Insert <code>treeNode</code> before or after the <code>refTreeNode</code>.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_insert"
     },
     "insertAfter": {
      "!type": "fn(treeNode: aui_tree.TreeNode, refTreeNode: aui_tree.TreeNode)",
      "!doc": "Insert <code>treeNode</code> after the <code>refTreeNode</code>.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_insertAfter"
     },
     "insertBefore": {
      "!type": "fn(treeNode: aui_tree.TreeNode, refTreeNode: aui_tree.TreeNode)",
      "!doc": "Insert <code>treeNode</code> before the <code>refTreeNode</code>.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_insertBefore"
     },
     "getNodeByChild": {
      "!type": "fn(child: aui_node.Node) -> +aui_tree.TreeNode",
      "!doc": "Get a TreeNode instance by a child DOM Node.",
      "!url": "http://alloyui.com/classes/A.TreeData.html#method_getNodeByChild"
     }
    }
   },
   "A.TreeViewIO": {
    "!type": "fn(config: Object) -> +aui_tree.A.TreeViewIO",
    "!doc": "A base class for TreeViewIO.",
    "!url": "http://alloyui.com/classes/A.TreeViewIO.html",
    "TreeViewIO.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TreeViewIO.",
     "!url": "http://alloyui.com/classes/A.TreeViewIO.html#property_TreeViewIO.ATTRS"
    },
    "prototype": {
     "io": {
      "!type": "fn()",
      "!doc": "IO options for the current TreeNode load the children.",
      "!url": "http://alloyui.com/classes/A.TreeViewIO.html#attribute_io"
     },
     "createNodes": {
      "!type": "fn(nodes)",
      "!doc": "Create nodes.",
      "!url": "http://alloyui.com/classes/A.TreeViewIO.html#method_createNodes"
     },
     "initIO": {
      "!type": "fn()",
      "!doc": "Initialize the IO transaction setup on the\n[io](A.TreeViewIO.html#attr_io) attribute.",
      "!url": "http://alloyui.com/classes/A.TreeViewIO.html#method_initIO"
     },
     "ioStartHandler": {
      "!type": "fn()",
      "!doc": "IO Start handler.",
      "!url": "http://alloyui.com/classes/A.TreeViewIO.html#method_ioStartHandler"
     },
     "ioCompleteHandler": {
      "!type": "fn()",
      "!doc": "IO Complete handler.",
      "!url": "http://alloyui.com/classes/A.TreeViewIO.html#method_ioCompleteHandler"
     },
     "ioSuccessHandler": {
      "!type": "fn()",
      "!doc": "IO Success handler.",
      "!url": "http://alloyui.com/classes/A.TreeViewIO.html#method_ioSuccessHandler"
     },
     "ioFailureHandler": {
      "!type": "fn()",
      "!doc": "IO Failure handler.",
      "!url": "http://alloyui.com/classes/A.TreeViewIO.html#method_ioFailureHandler"
     }
    }
   },
   "A.TreeNode": {
    "!type": "fn(config: Object) -> +aui_tree.A.TreeNode",
    "!proto": "A.Base",
    "!doc": "A base class for TreeNode, providing:\n<ul>\n\t<li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n\t<li>The node for the TreeView component</li>\n</ul>\n\nCheck the [live demo](http://alloyui.com/examples/tree/).",
    "!url": "http://alloyui.com/classes/A.TreeNode.html",
    "TreeNode.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TreeNode.html#property_TreeNode.NAME"
    },
    "TreeNode.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TreeNode.",
     "!url": "http://alloyui.com/classes/A.TreeNode.html#property_TreeNode.ATTRS"
    },
    "prototype": {
     "boundingBox": {
      "!type": "fn()",
      "!doc": "The widget's outermost node, used for sizing and positioning.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_boundingBox"
     },
     "contentBox": {
      "!type": "fn()",
      "!doc": "The direct descendant of a widget's\nbounding box and houses its content.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_contentBox"
     },
     "cssClasses": {
      "!type": "fn()",
      "!doc": "CSS classes used on TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_cssClasses"
     },
     "draggable": {
      "!type": "fn()",
      "!doc": "If true the TreeNode is draggable.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_draggable"
     },
     "ownerTree": {
      "!type": "fn()",
      "!doc": "TreeView which contains the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_ownerTree"
     },
     "label": {
      "!type": "fn()",
      "!doc": "Label of the TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_label"
     },
     "expanded": {
      "!type": "fn()",
      "!doc": "Whether the TreeNode is expanded by default.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_expanded"
     },
     "id": {
      "!type": "fn()",
      "!doc": "Id of the TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_id"
     },
     "leaf": {
      "!type": "fn()",
      "!doc": "Whether the TreeNode could have children or not (i.e. if any\nchildren is present the TreeNode is a leaf).",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_leaf"
     },
     "nextSibling": {
      "!type": "fn()",
      "!doc": "Next sibling of the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_nextSibling"
     },
     "prevSibling": {
      "!type": "fn()",
      "!doc": "Previous sibling of the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_prevSibling"
     },
     "parentNode": {
      "!type": "fn()",
      "!doc": "Parent node of the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_parentNode"
     },
     "labelEl": {
      "!type": "fn()",
      "!doc": "Label element to house the <code>label</code> attribute.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_labelEl"
     },
     "hitAreaEl": {
      "!type": "fn()",
      "!doc": "Hitarea element.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_hitAreaEl"
     },
     "alwaysShowHitArea": {
      "!type": "fn()",
      "!doc": "Always show the hitarea icon.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_alwaysShowHitArea"
     },
     "iconEl": {
      "!type": "fn()",
      "!doc": "Icon element.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_iconEl"
     },
     "tabIndex": {
      "!type": "fn()",
      "!doc": "Specify the tab order.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_tabIndex"
     },
     "rendered": {
      "!type": "fn()",
      "!doc": "If true the TreeNode is rendered.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#attribute_rendered"
     },
     "render": {
      "!type": "fn(container)",
      "!doc": "Render TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_render"
     },
     "appendChild": {
      "!type": "fn()",
      "!doc": "Append child on TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_appendChild"
     },
     "collapse": {
      "!type": "fn()",
      "!doc": "Collapse the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_collapse"
     },
     "collapseAll": {
      "!type": "fn()",
      "!doc": "Collapse all TreeNodes.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_collapseAll"
     },
     "contains": {
      "!type": "fn(node: aui_tree.TreeNode) -> bool",
      "!doc": "Check if the current TreeNode contains the passed <code>node</code>.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_contains"
     },
     "expand": {
      "!type": "fn()",
      "!doc": "Expand the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_expand"
     },
     "expandAll": {
      "!type": "fn()",
      "!doc": "Expand all TreeNodes.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_expandAll"
     },
     "getDepth": {
      "!type": "fn() -> number",
      "!doc": "Get the depth of the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_getDepth"
     },
     "hasChildNodes": {
      "!type": "fn()",
      "!doc": "Check if it has child nodes.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_hasChildNodes"
     },
     "isSelected": {
      "!type": "fn() -> bool",
      "!doc": "Whether the current TreeNode is selected or not.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_isSelected"
     },
     "isLeaf": {
      "!type": "fn() -> bool",
      "!doc": "Whether the current TreeNode is ancestor of the passed <code>node</code> or not.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_isLeaf"
     },
     "toggle": {
      "!type": "fn()",
      "!doc": "Toggle the current TreeNode, <code>collapsed</code> or <code>expanded</code>.",
      "!url": "http://alloyui.com/classes/A.TreeNode.html#method_toggle"
     }
    }
   },
   "A.TreeNodeIO": {
    "!type": "fn(config: Object) -> +aui_tree.A.TreeNodeIO",
    "!proto": "aui_tree.A.TreeNode",
    "!doc": "A base class for TreeNodeIO, providing:\n<ul>\n\t<li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n\t<li>Ajax support to load the children of the current TreeNode</li>\n</ul>",
    "!url": "http://alloyui.com/classes/A.TreeNodeIO.html",
    "TreeNode.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TreeNodeIO.html#property_TreeNode.NAME"
    },
    "TreeNode.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TreeNode.",
     "!url": "http://alloyui.com/classes/A.TreeNodeIO.html#property_TreeNode.ATTRS"
    },
    "prototype": {
     "loading": {
      "!type": "fn()",
      "!doc": "Whether the current TreeNode IO transaction is loading.",
      "!url": "http://alloyui.com/classes/A.TreeNodeIO.html#attribute_loading"
     },
     "loaded": {
      "!type": "fn()",
      "!doc": "Whether the current TreeNode has loaded the content.",
      "!url": "http://alloyui.com/classes/A.TreeNodeIO.html#attribute_loaded"
     },
     "cache": {
      "!type": "fn()",
      "!doc": "Whether the current TreeNode should cache the loaded content or not.",
      "!url": "http://alloyui.com/classes/A.TreeNodeIO.html#attribute_cache"
     },
     "leaf": {
      "!type": "fn()",
      "!doc": "Whether the TreeNode could have children or not (i.e. if any\nchildren is present the TreeNode is a leaf).",
      "!url": "http://alloyui.com/classes/A.TreeNodeIO.html#attribute_leaf"
     },
     "expand": {
      "!type": "fn()",
      "!doc": "Expand the current TreeNodeIO.",
      "!url": "http://alloyui.com/classes/A.TreeNodeIO.html#method_expand"
     },
     "_onIOSuccess": {
      "!type": "fn(event)",
      "!doc": "Fire when IO success.",
      "!url": "http://alloyui.com/classes/A.TreeNodeIO.html#method__onIOSuccess"
     }
    }
   },
   "A.TreeNodeCheck": {
    "!type": "fn(config: Object) -> +aui_tree.A.TreeNodeCheck",
    "!proto": "aui_tree.A.TreeNodeIO",
    "!doc": "A base class for TreeNodeCheck, providing:\n<ul>\n\t<li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n\t<li>Checkbox support for the TreeNode</li>\n</ul>",
    "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html",
    "TreeNode.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html#property_TreeNode.NAME"
    },
    "TreeNode.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TreeNode.",
     "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html#property_TreeNode.ATTRS"
    },
    "prototype": {
     "checked": {
      "!type": "fn()",
      "!doc": "Whether the TreeNode is checked or not.",
      "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html#attribute_checked"
     },
     "checkName": {
      "!type": "fn()",
      "!doc": "Name of the checkbox element used on the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html#attribute_checkName"
     },
     "checkContainerEl": {
      "!type": "fn()",
      "!doc": "Container element for the checkbox.",
      "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html#attribute_checkContainerEl"
     },
     "checkEl": {
      "!type": "fn()",
      "!doc": "Checkbox element.",
      "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html#attribute_checkEl"
     },
     "check": {
      "!type": "fn()",
      "!doc": "Check the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html#method_check"
     },
     "uncheck": {
      "!type": "fn()",
      "!doc": "Uncheck the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html#method_uncheck"
     },
     "toggleCheck": {
      "!type": "fn()",
      "!doc": "Toggle the check status of the current TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html#method_toggleCheck"
     },
     "isChecked": {
      "!type": "fn() -> ?",
      "!doc": "Whether the current TreeNodeCheck is checked.",
      "!url": "http://alloyui.com/classes/A.TreeNodeCheck.html#method_isChecked"
     }
    }
   },
   "A.TreeNodeTask": {
    "!type": "fn(config: Object) -> +aui_tree.A.TreeNodeTask",
    "!proto": "aui_tree.A.TreeNodeCheck",
    "!doc": "A base class for TreeNodeTask, providing:\n<ul>\n\t<li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n\t<li>3 states checkbox support</li>\n\t<li>Automatic check/uncheck the parent status based on the children checked status</li>\n</ul>",
    "!url": "http://alloyui.com/classes/A.TreeNodeTask.html",
    "TreeNode.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TreeNodeTask.html#property_TreeNode.NAME"
    },
    "prototype": {
     "check": {
      "!type": "fn(originalTarget)",
      "!doc": "Check the current TreeNodeTask.",
      "!url": "http://alloyui.com/classes/A.TreeNodeTask.html#method_check"
     },
     "uncheck": {
      "!type": "fn(originalTarget)",
      "!doc": "Uncheck the current TreeNodeTask.",
      "!url": "http://alloyui.com/classes/A.TreeNodeTask.html#method_uncheck"
     }
    }
   },
   "A.TreeNodeRadio": {
    "!type": "fn(config: Object) -> +aui_tree.A.TreeNodeRadio",
    "!proto": "aui_tree.A.TreeNodeTask",
    "!doc": "A base class for TreeNodeRadio, providing:\n<ul>\n\t<li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n\t<li>3 states checkbox support</li>\n\t<li>Automatic check/uncheck the parent status based on the children checked status</li>\n</ul>",
    "!url": "http://alloyui.com/classes/A.TreeNodeRadio.html",
    "TreeNodeRadio.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TreeNodeRadio.html#property_TreeNodeRadio.NAME"
    },
    "TreeNodeRadio.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TreeNodeRadio.",
     "!url": "http://alloyui.com/classes/A.TreeNodeRadio.html#property_TreeNodeRadio.ATTRS"
    },
    "prototype": {
     "cssClasses": {
      "!type": "fn()",
      "!doc": "CSS classes used on TreeNodeRadio.",
      "!url": "http://alloyui.com/classes/A.TreeNodeRadio.html#attribute_cssClasses"
     },
     "check": {
      "!type": "fn()",
      "!doc": "Check the current TreeNodeRadio.",
      "!url": "http://alloyui.com/classes/A.TreeNodeRadio.html#method_check"
     }
    }
   },
   "TreeNode": {
    "!type": "fn()",
    "!url": "http://alloyui.com/classes/TreeNode.html",
    "prototype": {
     "A.TreeNode.nodeTypes": {
      "!type": "+Object",
      "!doc": "TreeNode types hash map.\n\n<pre><code>A.TreeNode.nodeTypes = {\n radio: A.TreeNodeRadio,\n task: A.TreeNodeTask,\n check: A.TreeNodeCheck,\n node: A.TreeNode,\n io: A.TreeNodeIO\n};</code></pre>",
      "!url": "http://alloyui.com/classes/TreeNode.html#property_A.TreeNode.nodeTypes"
     }
    }
   },
   "A.TreeViewPaginator": {
    "!type": "fn(config: Object) -> +aui_tree.A.TreeViewPaginator",
    "!doc": "A base class for TreeViewPaginator.",
    "!url": "http://alloyui.com/classes/A.TreeViewPaginator.html",
    "TreeViewPaginator.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TreeView.",
     "!url": "http://alloyui.com/classes/A.TreeViewPaginator.html#property_TreeViewPaginator.ATTRS"
    },
    "prototype": {
     "paginator": {
      "!type": "fn()",
      "!doc": "Paginator.",
      "!url": "http://alloyui.com/classes/A.TreeViewPaginator.html#attribute_paginator"
     }
    }
   },
   "A.TreeView": {
    "!type": "fn(config: Object) -> +aui_tree.A.TreeView",
    "!proto": "aui_tree.A.TreeData",
    "!doc": "A base class for TreeView, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n</ul>\n\nCheck the [live demo](http://alloyui.com/examples/tree/).",
    "!url": "http://alloyui.com/classes/A.TreeView.html",
    "TreeView.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TreeView.html#property_TreeView.NAME"
    },
    "TreeView.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TreeView.",
     "!url": "http://alloyui.com/classes/A.TreeView.html#property_TreeView.ATTRS"
    },
    "prototype": {
     "type": {
      "!type": "fn()",
      "!doc": "Type of the treeview (i.e. could be 'file' or 'normal').",
      "!url": "http://alloyui.com/classes/A.TreeView.html#attribute_type"
     },
     "lastSelected": {
      "!type": "fn()",
      "!doc": "Last selected TreeNode.",
      "!url": "http://alloyui.com/classes/A.TreeView.html#attribute_lastSelected"
     },
     "lazyLoad": {
      "!type": "fn()",
      "!doc": "Determine if its going to be lazy loaded or not.",
      "!url": "http://alloyui.com/classes/A.TreeView.html#attribute_lazyLoad"
     },
     "selectOnToggle": {
      "!type": "fn()",
      "!doc": "Determine if its going to be selected on toggle.",
      "!url": "http://alloyui.com/classes/A.TreeView.html#attribute_selectOnToggle"
     }
    }
   },
   "A.TreeViewDD": {
    "!type": "fn(config: Object) -> +aui_tree.A.TreeViewDD",
    "!proto": "aui_tree.A.TreeView",
    "!doc": "A base class for TreeViewDD, providing:\n<ul>\n   <li>Widget Lifecycle (initializer, renderUI, bindUI, syncUI, destructor)</li>\n   <li>DragDrop support for the TreeNodes</li>\n</ul>",
    "!url": "http://alloyui.com/classes/A.TreeViewDD.html",
    "TreeViewDD.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.TreeViewDD.html#property_TreeViewDD.NAME"
    },
    "TreeViewDD.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the TreeViewDD.",
     "!url": "http://alloyui.com/classes/A.TreeViewDD.html#property_TreeViewDD.ATTRS"
    },
    "prototype": {
     "helper": {
      "!type": "fn()",
      "!doc": "Dragdrop helper element.",
      "!url": "http://alloyui.com/classes/A.TreeViewDD.html#attribute_helper"
     },
     "scrollDelay": {
      "!type": "fn()",
      "!doc": "Delay of the scroll while dragging the TreeNodes.",
      "!url": "http://alloyui.com/classes/A.TreeViewDD.html#attribute_scrollDelay"
     },
     "dropAction": {
      "!type": "fn()",
      "!doc": "Drop action (i.e. could be 'append', 'below' or 'above').",
      "!url": "http://alloyui.com/classes/A.TreeViewDD.html#attribute_dropAction"
     },
     "lastY": {
      "!type": "fn()",
      "!doc": "Last Y.",
      "!url": "http://alloyui.com/classes/A.TreeViewDD.html#attribute_lastY"
     },
     "node": {
      "!type": "fn()",
      "!doc": "Node.",
      "!url": "http://alloyui.com/classes/A.TreeViewDD.html#attribute_node"
     },
     "nodeContent": {
      "!type": "fn()",
      "!doc": "Reference for the current drop node.",
      "!url": "http://alloyui.com/classes/A.TreeViewDD.html#attribute_nodeContent"
     }
    }
   },
   "A.Url": {
    "!type": "fn(config: Object) -> +aui_url.A.Url",
    "!doc": "A base class for Url.",
    "!url": "http://alloyui.com/classes/A.Url.html",
    "prototype": {
     "undefined": {
      "!type": "fn()",
      "!url": "http://alloyui.com/classes/A.Url.html"
     }
    }
   }
  },
  "aui_url": {
   "A.Url": {
    "!type": "fn(config: Object) -> +aui_url.A.Url",
    "!doc": "A base class for Url.",
    "!url": "http://alloyui.com/classes/A.Url.html",
    "prototype": {
     "addParameter": {
      "!type": "fn(key, values)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_addParameter"
     },
     "addParameters": {
      "!type": "fn(parameters)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_addParameters"
     },
     "hasParameter": {
      "!type": "fn(key)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_hasParameter"
     },
     "getParameter": {
      "!type": "fn(key)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getParameter"
     },
     "getParameters": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getParameters"
     },
     "getAnchor": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getAnchor"
     },
     "getAuthority": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getAuthority"
     },
     "getDirectory": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getDirectory"
     },
     "getFile": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getFile"
     },
     "getHost": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getHost"
     },
     "getPassword": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getPassword"
     },
     "getPath": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getPath"
     },
     "getPort": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getPort"
     },
     "getProtocol": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getProtocol"
     },
     "getQuery": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getQuery"
     },
     "getRelative": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getRelative"
     },
     "getSource": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getSource"
     },
     "getUser": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getUser"
     },
     "getUserInfo": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_getUserInfo"
     },
     "removeParameter": {
      "!type": "fn(key)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_removeParameter"
     },
     "removeParameters": {
      "!type": "fn(parameters)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_removeParameters"
     },
     "setParameter": {
      "!type": "fn(key, opt_values)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setParameter"
     },
     "setParameters": {
      "!type": "fn(parameters)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setParameters"
     },
     "setAnchor": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setAnchor"
     },
     "setAuthority": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setAuthority"
     },
     "setDirectory": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setDirectory"
     },
     "setFile": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setFile"
     },
     "setHost": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setHost"
     },
     "setPassword": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setPassword"
     },
     "setPath": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setPath"
     },
     "setPort": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setPort"
     },
     "setProtocol": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setProtocol"
     },
     "setRelative": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setRelative"
     },
     "setSource": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setSource"
     },
     "setUser": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setUser"
     },
     "setUserInfo": {
      "!type": "fn(val)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_setUserInfo"
     },
     "toString": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/A.Url.html#method_toString"
     }
    }
   }
  },
  "aui_video": {
   "A.Video": {
    "!type": "fn(config: Object) -> +aui_video.A.Video",
    "!proto": "aui_component.A.Component",
    "!doc": "A base class for Video.\n\nCheck the [live demo](http://alloyui.com/examples/video/).",
    "!url": "http://alloyui.com/classes/A.Video.html",
    "Video.NAME": {
     "!type": "string",
     "!doc": "Static property provides a string to identify the class.",
     "!url": "http://alloyui.com/classes/A.Video.html#property_Video.NAME"
    },
    "Video.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Video.",
     "!url": "http://alloyui.com/classes/A.Video.html#property_Video.ATTRS"
    },
    "prototype": {
     "url": {
      "!type": "fn()",
      "!doc": "URL used by Video to play.",
      "!url": "http://alloyui.com/classes/A.Video.html#attribute_url"
     },
     "ogvUrl": {
      "!type": "fn()",
      "!doc": "URL (on .ogv format) used by Video to play.",
      "!url": "http://alloyui.com/classes/A.Video.html#attribute_ogvUrl"
     },
     "swfUrl": {
      "!type": "fn()",
      "!doc": "URL (on .swf format) used by Video to create\na fallback player with Flash.",
      "!url": "http://alloyui.com/classes/A.Video.html#attribute_swfUrl"
     },
     "poster": {
      "!type": "fn()",
      "!doc": "Image displayed before playback starts.",
      "!url": "http://alloyui.com/classes/A.Video.html#attribute_poster"
     },
     "fixedAttributes": {
      "!type": "fn()",
      "!doc": "An additional list of attributes.",
      "!url": "http://alloyui.com/classes/A.Video.html#attribute_fixedAttributes"
     },
     "flashPlayerVersion": {
      "!type": "fn()",
      "!doc": "The required Flash version for the swf player",
      "!url": "http://alloyui.com/classes/A.Video.html#attribute_flashPlayerVersion"
     },
     "flashVars": {
      "!type": "fn()",
      "!doc": "Variables used by Flash player.",
      "!url": "http://alloyui.com/classes/A.Video.html#attribute_flashVars"
     },
     "render": {
      "!type": "fn()",
      "!doc": "If <code>true</code> the render phase will be automatically invoked\npreventing the <code>.render()</code> manual call.",
      "!url": "http://alloyui.com/classes/A.Video.html#attribute_render"
     },
     "load": {
      "!type": "fn()",
      "!doc": "Load video track.",
      "!url": "http://alloyui.com/classes/A.Video.html#method_load"
     },
     "pause": {
      "!type": "fn()",
      "!doc": "Pause video track.",
      "!url": "http://alloyui.com/classes/A.Video.html#method_pause"
     },
     "play": {
      "!type": "fn()",
      "!doc": "Play video track.",
      "!url": "http://alloyui.com/classes/A.Video.html#method_play"
     }
    },
    "Video.BIND_UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the attributes\nfor the bindUI lifecycle phase.",
     "!url": "http://alloyui.com/classes/A.Video.html#property_Video.BIND_UI_ATTRS"
    },
    "Video.SYNC_UI_ATTRS": {
     "!type": "+Array",
     "!doc": "Static property used to define the attributes\nfor the syncUI lifecycle phase.",
     "!url": "http://alloyui.com/classes/A.Video.html#property_Video.SYNC_UI_ATTRS"
    }
   }
  },
  "aui_widget_cssclass": {
   "A.WidgetCssClass": {
    "!type": "fn(The: Object)",
    "!doc": "Widget extension, which can be used to add cssClass support to the\nbase Widget class, through the <a href=\"Base.html#method_build\">Base.build</a>\nmethod.",
    "!url": "http://alloyui.com/classes/A.WidgetCssClass.html",
    "WidgetCssClass.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration for the Component.",
     "!url": "http://alloyui.com/classes/A.WidgetCssClass.html#property_WidgetCssClass.ATTRS"
    },
    "prototype": {
     "cssClass": {
      "!type": "fn()",
      "!doc": "CSS class to be automatically added to the <code>boundingBox</code>.",
      "!url": "http://alloyui.com/classes/A.WidgetCssClass.html#attribute_cssClass"
     }
    },
    "WidgetCssClass.CSS_CLASS_CONTENT_SUFFIX": {
     "!type": "string",
     "!doc": "Static property used to define the default suffix for cssClass attribute value\napplied on <code>contentBox</code> node.",
     "!url": "http://alloyui.com/classes/A.WidgetCssClass.html#property_WidgetCssClass.CSS_CLASS_CONTENT_SUFFIX"
    }
   },
   "A.WidgetPositionAlignSuggestion": {
    "!type": "fn(The: Object)",
    "!doc": "Widget extension, which can be used to suggest alignment points based on\nposition attribute to base Widget class, through the\n<a href=\"Base.html#method_build\">Base.build</a> method. It also tries to find\nthe best position in case the widget doesn't fit it's constrainment node.",
    "!url": "http://alloyui.com/classes/A.WidgetPositionAlignSuggestion.html",
    "WidgetPositionAlignSuggestion.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration.",
     "!url": "http://alloyui.com/classes/A.WidgetPositionAlignSuggestion.html#property_WidgetPositionAlignSuggestion.ATTRS"
    },
    "prototype": {
     "position": {
      "!type": "fn()",
      "!doc": "Determine the position of the tooltip.",
      "!url": "http://alloyui.com/classes/A.WidgetPositionAlignSuggestion.html#attribute_position"
     },
     "POSITION_ALIGN_SUGGESTION": {
      "!type": "+",
      "!doc": "Property defining the align points based on the suggested\n<code>position</code>.",
      "!url": "http://alloyui.com/classes/A.WidgetPositionAlignSuggestion.html#property_POSITION_ALIGN_SUGGESTION"
     },
     "initializer": {
      "!type": "fn()",
      "!doc": "Construction logic executed during WidgetPositionAlignSuggestion\ninstantiation. Lifecycle.",
      "!url": "http://alloyui.com/classes/A.WidgetPositionAlignSuggestion.html#method_initializer"
     },
     "alignNode": {
      "!type": "fn()",
      "!doc": "Suggest alignment for the node based on the <code>position</code> suggestion.",
      "!url": "http://alloyui.com/classes/A.WidgetPositionAlignSuggestion.html#attribute_alignNode"
     }
    }
   }
  },
  "aui_widget_toggle": {
   "A.WidgetToggle": {
    "!type": "fn(The: Object)",
    "!doc": "Widget extension, which can be used to add toggle visibility support to the\nbase Widget class, through the <a href=\"Base.html#method_build\">Base.build</a>\nmethod.",
    "!url": "http://alloyui.com/classes/A.WidgetToggle.html",
    "prototype": {
     "toggle": {
      "!type": "fn(visible: bool)",
      "!doc": "Toggles widget visibility.",
      "!url": "http://alloyui.com/classes/A.WidgetToggle.html#method_toggle"
     }
    }
   }
  },
  "aui_widget_toolbars": {
   "WidgetToolbars": {
    "!type": "fn() -> +aui_widget_toolbars.WidgetToolbars",
    "!doc": "A base class for Widget Toolbars.",
    "!url": "http://alloyui.com/classes/WidgetToolbars.html",
    "WidgetToolbars.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration.",
     "!url": "http://alloyui.com/classes/WidgetToolbars.html#property_WidgetToolbars.ATTRS"
    },
    "prototype": {
     "toolbars": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/WidgetToolbars.html#attribute_toolbars"
     },
     "toolbarPosition": {
      "!type": "fn()",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/WidgetToolbars.html#attribute_toolbarPosition"
     },
     "addToolbar": {
      "!type": "fn(toolbar, section)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/WidgetToolbars.html#method_addToolbar"
     },
     "getToolbar": {
      "!type": "fn(section)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/WidgetToolbars.html#method_getToolbar"
     },
     "getToolbarSection": {
      "!type": "fn(section)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/WidgetToolbars.html#method_getToolbarSection"
     },
     "removeToolbar": {
      "!type": "fn(section)",
      "!doc": "TODO. Wanna help? Please send a Pull Request.",
      "!url": "http://alloyui.com/classes/WidgetToolbars.html#method_removeToolbar"
     }
    }
   },
   "A.WidgetTrigger": {
    "!type": "fn(The: Object)",
    "!doc": "Widget extension, which can be used to add trigger support to the\nbase Widget class, through the <a href=\"Base.html#method_build\">Base.build</a>\nmethod.",
    "!url": "http://alloyui.com/classes/A.WidgetTrigger.html",
    "WidgetTrigger.ATTRS": {
     "!type": "+Object",
     "!doc": "Static property used to define the default attribute\nconfiguration.",
     "!url": "http://alloyui.com/classes/A.WidgetTrigger.html#property_WidgetTrigger.ATTRS"
    },
    "prototype": {
     "bindDOMEvents": {
      "!type": "fn()",
      "!doc": "Determine if the Toggler should bind DOM events or not.",
      "!url": "http://alloyui.com/classes/A.WidgetTrigger.html#attribute_bindDOMEvents"
     },
     "trigger": {
      "!type": "fn()",
      "!doc": "Trigger node to change widget visibility state.",
      "!url": "http://alloyui.com/classes/A.WidgetTrigger.html#attribute_trigger"
     },
     "triggerHideEvent": {
      "!type": "fn()",
      "!doc": "DOM event to hide the tooltip.",
      "!url": "http://alloyui.com/classes/A.WidgetTrigger.html#attribute_triggerHideEvent"
     },
     "triggerShowEvent": {
      "!type": "fn()",
      "!doc": "DOM event to show the tooltip.",
      "!url": "http://alloyui.com/classes/A.WidgetTrigger.html#attribute_triggerShowEvent"
     },
     "triggerToggleEvent": {
      "!type": "fn()",
      "!doc": "DOM event to toggle the tooltip.",
      "!url": "http://alloyui.com/classes/A.WidgetTrigger.html#attribute_triggerToggleEvent"
     },
     "initializer": {
      "!type": "fn()",
      "!doc": "Construction logic executed during WidgetTrigger\ninstantiation. Lifecycle.",
      "!url": "http://alloyui.com/classes/A.WidgetTrigger.html#method_initializer"
     }
    }
   }
  }
 },
 "AUI": {
  "!type": "fn(config?: aui.Object) -> +AUI",
  "!doc": "The AUI global namespace object. This is the constructor for all AUI instances.\n\nThis is a self-instantiable factory function, meaning you don't need to precede\nit with the `new` operator. You can invoke it directly like this:\n\n    AUI().use('*', function (A) {\n        // A is a new AUI instance.\n    });\n\nBut it also works like this:\n\n    var A = AUI();\n\nThe `AUI` constructor accepts an optional config object, like this:\n\n    AUI({\n        debug: true,\n        combine: false\n    }).use('node', function (A) {\n        // A.Node is ready to use.\n    });\n\nSee the API docs for the <a href=\"config.html\">Config</a> class for the complete\nlist of supported configuration properties accepted by the AUI constuctor.\n\nIf a global `AUI` object is already defined, the existing AUI object will not be\noverwritten, to ensure that defined namespaces are preserved.\n\nEach AUI instance has full custom event support, but only if the event system is\navailable.",
  "!url": "http://alloyui.com/classes/AUI.html",
  "prototype": {
   "cached": {
    "!type": "fn(source: fn(), cache?: yui.Object, refetch?: Any) -> fn()",
    "!doc": "Returns a wrapper for a function which caches the return value of that function,\nkeyed off of the combined string representation of the argument values provided\nwhen the wrapper is called.\n\nCalling this function again with the same arguments will return the cached value\nrather than executing the wrapped function.\n\nNote that since the cache is keyed off of the string representation of arguments\npassed to the wrapper function, arguments that aren't strings and don't provide\na meaningful `toString()` method may result in unexpected caching behavior. For\nexample, the objects `{}` and `{foo: 'bar'}` would both be converted to the\nstring `[object Object]` when used as a cache key.",
    "!url": "http://alloyui.com/classes/AUI.html#method_cached"
   },
   "getLocation": {
    "!type": "fn() -> +Location",
    "!doc": "Returns the `location` object from the window/frame in which this AUI instance\noperates, or `undefined` when executing in a non-browser environment\n(e.g. Node.js).\n\nIt is _not_ recommended to hold references to the `window.location` object\noutside of the scope of a function in which its properties are being accessed or\nits methods are being called. This is because of a nasty bug/issue that exists\nin both Safari and MobileSafari browsers:\n[WebKit Bug 34679](https://bugs.webkit.org/show_bug.cgi?id=34679).",
    "!url": "http://alloyui.com/classes/AUI.html#method_getLocation"
   },
   "merge": {
    "!type": "fn(objects: yui.Object) -> +yui.Object",
    "!doc": "Returns a new object containing all of the properties of all the supplied\nobjects. The properties from later objects will overwrite those in earlier\nobjects.\n\nPassing in a single object will create a shallow copy of it. For a deep copy,\nuse `clone()`.",
    "!url": "http://alloyui.com/classes/AUI.html#method_merge"
   },
   "mix": {
    "!type": "fn(receiver: fn(), supplier: fn(), overwrite?: bool, whitelist?: [string], mode?: number, merge?: bool) -> fn()",
    "!doc": "Mixes _supplier_'s properties into _receiver_.\n\nProperties on _receiver_ or _receiver_'s prototype will not be overwritten or\nshadowed unless the _overwrite_ parameter is `true`, and will not be merged\nunless the _merge_ parameter is `true`.\n\nIn the default mode (0), only properties the supplier owns are copied (prototype\nproperties are not copied). The following copying modes are available:\n\n  * `0`: _Default_. Object to object.\n  * `1`: Prototype to prototype.\n  * `2`: Prototype to prototype and object to object.\n  * `3`: Prototype to object.\n  * `4`: Object to prototype.",
    "!url": "http://alloyui.com/classes/AUI.html#method_mix"
   },
   "later": {
    "!type": "fn(when: number, o, fn: fn(), data, periodic: bool) -> +yui.Object",
    "!doc": "Executes the supplied function in the context of the supplied\nobject 'when' milliseconds later.  Executes the function a\nsingle time unless periodic is set to true.",
    "!url": "http://alloyui.com/classes/AUI.html#method_later"
   },
   "log": {
    "!type": "fn(msg: string, cat: string, src: string, silent: bool) -> +AUI",
    "!doc": "If the 'debug' config is true, a 'yui:log' event will be\ndispatched, which the Console widget and anything else\ncan consume.  If the 'useBrowserConsole' config is true, it will\nwrite to the browser console if available.  AUI-specific log\nmessages will only be present in the -debug versions of the\nJS files.  The build system is supposed to remove log statements\nfrom the raw and minified versions of the files.",
    "!url": "http://alloyui.com/classes/AUI.html#method_log"
   },
   "message": {
    "!type": "fn(msg: string, cat: string, src: string, silent: bool) -> +AUI",
    "!doc": "Write a system message.  This message will be preserved in the\nminified and raw versions of the AUI files, unlike log statements.",
    "!url": "http://alloyui.com/classes/AUI.html#method_message"
   },
   "YUI_config": {
    "!type": "+yui.Object",
    "!doc": "Page-level config applied to all YUI instances created on the\ncurrent page. This is applied after `YUI.GlobalConfig` and before\nany instance-level configuration.",
    "!url": "http://alloyui.com/classes/YUI.html#property_YUI_config"
   },
   "applyConfig": {
    "!type": "fn(o: yui.Object)",
    "!doc": "Applies a new configuration object to the config of this YUI instance. This\nwill merge new group/module definitions, and will also update the loader\ncache if necessary. Updating `Y.config` directly will not update the cache.",
    "!url": "http://alloyui.com/classes/YUI.html#method_applyConfig"
   },
   "version": {
    "!type": "string",
    "!doc": "The version number of this YUI instance.\n\nThis value is typically updated by a script when a YUI release is built,\nso it may not reflect the correct version number when YUI is run from\nthe development source tree.",
    "!url": "http://alloyui.com/classes/YUI.html#property_version"
   },
   "applyTo": {
    "!type": "fn(id: string, method: string, args: yui.Array) -> +Mixed",
    "!doc": "Executes the named method on the specified YUI instance if that method is\nwhitelisted.",
    "!url": "http://alloyui.com/classes/YUI.html#method_applyTo"
   },
   "add": {
    "!type": "fn(name: string, fn: fn(), version: string, config?: yui.Object) -> +YUI",
    "!effects": [
     "custom yui_add"
    ],
    "!doc": "Registers a AUI module and makes it available for use in a `AUI().use()` call or\nas a dependency for other modules.\n\nThe easiest way to create a first-class AUI module is to use\n<a href=\"http://yui.github.com/shifter/\">Shifter</a>, the YUI component build\ntool.\n\nShifter will automatically wrap your module code in a `AUI.add()` call along\nwith any configuration info required for the module.",
    "!url": "http://alloyui.com/classes/AUI.html#method_add"
   },
   "use": {
    "!type": "fn(modules: string, callback?: fn()) -> !this",
    "!effects": [
     "custom yui_use"
    ],
    "!doc": "Attaches one or more modules to this AUI instance. When this is executed,\nthe requirements of the desired modules are analyzed, and one of several\nthings can happen:\n\n\n  * All required modules have already been loaded, and just need to be\n    attached to this AUI instance. In this case, the `use()` callback will\n    be executed synchronously after the modules are attached.\n\n  * One or more modules have not yet been loaded, or the Get utility is not\n    available, or the `bootstrap` config option is `false`. In this case,\n    a warning is issued indicating that modules are missing, but all\n    available modules will still be attached and the `use()` callback will\n    be executed synchronously.\n\n  * One or more modules are missing and the Loader is not available but the\n    Get utility is, and `bootstrap` is not `false`. In this case, the Get\n    utility will be used to load the Loader, and we will then proceed to\n    the following state:\n\n  * One or more modules are missing and the Loader is available. In this\n    case, the Loader will be used to resolve the dependency tree for the\n    missing modules and load them and their dependencies. When the Loader is\n    finished loading modules, the `use()` callback will be executed\n    asynchronously.",
    "!url": "http://alloyui.com/classes/AUI.html#method_use"
   },
   "require": {
    "!type": "fn(modules?: string, callback: fn())",
    "!doc": "Sugar for loading both legacy and ES6-based AUI modules.",
    "!url": "http://alloyui.com/classes/AUI.html#method_require"
   },
   "namespace": {
    "!type": "fn(namespace: string) -> +yui.Object",
    "!doc": "Utility method for safely creating namespaces if they don't already exist.\nMay be called statically on the AUI global object or as a method on a AUI\ninstance.\n\nWhen called statically, a namespace will be created on the AUI global\nobject:\n\n    // Create `AUI.your.namespace.here` as nested objects, preserving any\n    // objects that already exist instead of overwriting them.\n    AUI.namespace('your.namespace.here');\n\nWhen called as a method on a AUI instance, a namespace will be created on\nthat instance:\n\n    // Creates `Y.property.package`.\n    Y.namespace('property.package');\n\nDots in the input string cause `namespace` to create nested objects for each\ntoken. If any part of the requested namespace already exists, the current\nobject will be left in place and will not be overwritten. This allows\nmultiple calls to `namespace` to preserve existing namespaced properties.\n\nIf the first token in the namespace string is \"YAHOO\", that token is\ndiscarded. This is legacy behavior for backwards compatibility with AUI 2.\n\nBe careful with namespace tokens. Reserved words may work in some browsers\nand not others. For instance, the following will fail in some browsers\nbecause the supported version of JavaScript reserves the word \"long\":\n\n    Y.namespace('really.long.nested.namespace');\n\nNote: If you pass multiple arguments to create multiple namespaces, only the\nlast one created is returned from this function.",
    "!url": "http://alloyui.com/classes/AUI.html#method_namespace"
   },
   "error": {
    "!type": "fn(msg: string, e?: Error, src?: string) -> !this",
    "!doc": "Reports an error.\n\nThe reporting mechanism is controlled by the `throwFail` configuration\nattribute. If `throwFail` is falsy, the message is logged. If `throwFail` is\ntruthy, a JS exception is thrown.\n\nIf an `errorFn` is specified in the config it must return `true` to indicate\nthat the exception was handled and keep it from being thrown.",
    "!url": "http://alloyui.com/classes/AUI.html#method_error"
   },
   "guid": {
    "!type": "fn(pre?: string) -> string",
    "!doc": "Generates an id string that is unique among all AUI instances in this\nexecution context.",
    "!url": "http://alloyui.com/classes/AUI.html#method_guid"
   },
   "stamp": {
    "!type": "fn(o: yui.Object, readOnly: bool) -> string",
    "!doc": "Returns a unique id associated with the given object and (if *readOnly* is\nfalsy) stamps the object with that id so it can be identified in the future.\n\nStamping an object involves adding a `_yuid` property to it that contains\nthe object's id. One exception to this is that in Internet Explorer, DOM\nnodes have a `uniqueID` property that contains a browser-generated unique\nid, which will be used instead of a AUI-generated id when available.",
    "!url": "http://alloyui.com/classes/AUI.html#method_stamp"
   },
   "destroy": {
    "!type": "fn()",
    "!doc": "Destroys this AUI instance.",
    "!url": "http://alloyui.com/classes/AUI.html#method_destroy"
   },
   "instanceOf": {
    "!type": "fn(o: yui.Object, type: yui.Object)",
    "!doc": "Safe `instanceof` wrapper that works around a memory leak in IE when the\nobject being tested is `window` or `document`.\n\nUnless you are testing objects that may be `window` or `document`, you\nshould use the native `instanceof` operator instead of this method.",
    "!url": "http://alloyui.com/classes/AUI.html#method_instanceOf"
   },
   "throttle": {
    "!type": "fn(fn: fn(), ms: number) -> fn()",
    "!doc": "Throttles a call to a method based on the time between calls.",
    "!url": "http://alloyui.com/classes/AUI.html#method_throttle"
   }
  },
  "GlobalConfig": {
   "!type": "+yui.Object",
   "!doc": "Master configuration that might span multiple contexts in a non-\nbrowser environment. It is applied first to all instances in all\ncontexts.",
   "!url": "http://alloyui.com/classes/AUI.html#property_GlobalConfig"
  },
  "applyConfig": {
   "!type": "fn(o: yui.Object)",
   "!doc": "Applies a configuration to all AUI instances in this execution context.\n\nThe main use case for this method is in \"mashups\" where several third-party\nscripts need to write to a global AUI config, but cannot share a single\ncentrally-managed config object. This way they can all call\n`AUI.applyConfig({})` instead of overwriting the single global config.",
   "!url": "http://alloyui.com/classes/AUI.html#method_applyConfig"
  },
  "setLoadHook": {
   "!type": "fn(fn: fn())",
   "!doc": "Set a method to be called when `Get.script` is called in Node.js\n`Get` will open the file, then pass it's content and it's path\nto this method before attaching it. Commonly used for code coverage\ninstrumentation. <strong>Calling this multiple times will only\nattach the last hook method</strong>. This method is only\navailable in Node.js.",
   "!url": "http://alloyui.com/classes/AUI.html#method_setLoadHook"
  }
 }
}

 });
